import { FileUploadModule } from 'primeng/fileupload';
import { TreeTableModule } from 'primeng/treetable';
import { HighchartsChartModule } from 'highcharts-angular';
import { HttpClient } from '@angular/common/http';
import { DomSanitizer } from '@angular/platform-browser';
import { map } from 'rxjs/operators';
import { animate, state, style, transition, trigger } from '@angular/animations';
import { Guid } from 'guid-typescript';
import { DataSource } from '@angular/cdk/table';
import { MatSort, MatPaginator, MatIconModule, MatButtonModule, MatCardModule, MatMenuModule, MatTabsModule, MatFormFieldModule, MatInputModule, MatDatepickerModule, MatNativeDateModule, MatSelectModule, MatBadgeModule, MatCheckboxModule, MatPaginatorModule, MatTableModule, MatSortModule, MatProgressSpinnerModule, MatChipsModule } from '@angular/material';
import * as Highcharts from 'highcharts/highstock';
import { Subject, BehaviorSubject, of } from 'rxjs';
import { UIWorkItemModel, WorkGetNextService, UiWorkItemService, ListSearchService, E5ConfigurationService, ConfigurationScopeService, UiDocumentService, TaxonomyFieldDefinitionService, MonitorsSlaInventoryMonitorModel, MonitorsSlaInventoryMonitorService, UiSearchDefinitionService, WorkSearchFoundationService, MonitorsSlaInflowsMonitorModel, MonitorsSlaInflowsMonitorService, MonitorsSlaCompletionMonitorModel, MonitorsSlaCompletionMonitorService, MonitorsSlaMonitorService, WorkItemFoundationService, WorkAttachmentTypeFoundationService, WorkDocumentFoundationService, WorkItemService, WorkMenuItemFoundationService, MonitorsSlaTeamProductivityCompletionMonitorModel, MonitorsSlaTeamProductivityFacetimeMonitorModel, MonitorsSlaTeamProductivityCompletionMonitorService, MonitorsSlaTeamProductivityFacetimeMonitorService, E5coreAngularServicesModule } from 'e5core-angular-services';
import { CurrencyPipe, DatePipe, CommonModule } from '@angular/common';
import { FormControl, Validators, NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { Injectable, Input, Output, EventEmitter, Pipe, Component, ChangeDetectionStrategy, ChangeDetectorRef, ViewChildren, forwardRef, ViewChild, Inject, LOCALE_ID, ViewEncapsulation, NgModule, defineInjectable, inject } from '@angular/core';
import { NgxMaterialTimepickerModule } from 'ngx-material-timepicker';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This class implements a
 * UIWorkItemModel {
 * fieldsets: UIFieldSetModel[] | undefined ;
 * menus: UIMenuModel[] | undefined ;
 * properties: UIPropertyModel[] | undefined ;
 * tabs: UITabModel[] | undefined ;
 * workId: string | undefined
 * }
 */
class WorkItemModel extends UIWorkItemModel {
    constructor() {
        super();
        this.menus = null;
        this.tabs = null;
        this.workId = null;
        this.fieldsets = null;
        this.properties = null;
    }
}
/**
 * DEPRECATED, use FieldValue
 * @param {?} model
 * @param {?} propertyId
 * @param {?=} defaultValue
 * @return {?}
 */
function PropertyValue(model, propertyId, defaultValue) {
    /** @type {?} */
    let value = undefined;
    if (model && propertyId && model.properties) {
        /** @type {?} */
        const property = model.properties.find(p => p.propertyId == propertyId);
        value = (property) ? property.value : undefined;
    }
    return (value == undefined && defaultValue) ? defaultValue : value;
}
/**
 * @param {?} model
 * @param {?} fieldId
 * @param {?=} defaultValue
 * @return {?}
 */
function FieldValue(model, fieldId, defaultValue) {
    return PropertyValue(model, fieldId, defaultValue);
}
/**
 * DEPRECATED, use ResolvedFieldValue
 * @param {?} model
 * @param {?} propertyId
 * @param {?=} defaultValue
 * @return {?}
 */
function ResolvedPropertyValue(model, propertyId, defaultValue) {
    /** @type {?} */
    let value = undefined;
    if (model && propertyId && model.properties) {
        /** @type {?} */
        const property = model.properties.find(p => p.propertyId == propertyId);
        value = (property) ? property.resolvedValue : undefined;
    }
    return (value == undefined && defaultValue) ? defaultValue : value;
}
/**
 * @param {?} model
 * @param {?} fieldId
 * @param {?=} defaultValue
 * @return {?}
 */
function ResolvedFieldValue(model, fieldId, defaultValue) {
    return ResolvedPropertyValue(model, fieldId, defaultValue);
}
/**
 * @return {?}
 */
function CreateBlankWorkItem() {
    return new WorkItemModel();
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This service is used to provide work into the work item Subject/
 */
class WorkDeliveryService {
    /**
     * @param {?} getNextService
     * @param {?} uiWorkItemService
     */
    constructor(getNextService, uiWorkItemService) {
        this.getNextService = getNextService;
        this.uiWorkItemService = uiWorkItemService;
    }
    /**
     * @param {?} workItem$
     * @param {?=} lock
     * @return {?}
     */
    getNextWorkItem(workItem$, lock) {
        /** @type {?} */
        const subject$ = new Subject();
        this.getNextService.getNextWorkItem({ lockWorkItem: lock }).subscribe(response => {
            /** @type {?} */
            const wi = response.workItem;
            if (wi && wi.id && !wi.id.isEmpty) {
                this.uiWorkItemService.getAll(wi.id).subscribe(wim => {
                    /** @type {?} */
                    const current = workItem$.getValue();
                    /** @type {?} */
                    const updated = Object.assign({}, current, wim);
                    workItem$.next(updated);
                    subject$.next(updated);
                }, error => { subject$.error(error); }, () => { subject$.complete(); });
            }
            else {
                /** @type {?} */
                let blank = CreateBlankWorkItem();
                workItem$.next(blank);
                subject$.next(blank);
            }
        }, error => subject$.error(error));
        return (subject$);
    }
    /**
     * @param {?} workId
     * @param {?} workItem$
     * @param {?=} lock
     * @return {?}
     */
    getWorkItem(workId, workItem$, lock) {
        /** @type {?} */
        const subject$ = new Subject();
        this.uiWorkItemService.getAll(workId).subscribe(wim => {
            /** @type {?} */
            const updated = Object.assign({}, workItem$.getValue(), wim);
            workItem$.next(updated);
            subject$.next(updated);
        }, error => { subject$.error(error); }, () => { subject$.complete(); });
        return (subject$);
    }
}
WorkDeliveryService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
WorkDeliveryService.ctorParameters = () => [
    { type: WorkGetNextService },
    { type: UiWorkItemService }
];
/** @nocollapse */ WorkDeliveryService.ngInjectableDef = defineInjectable({ factory: function WorkDeliveryService_Factory() { return new WorkDeliveryService(inject(WorkGetNextService), inject(UiWorkItemService)); }, token: WorkDeliveryService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreAngularUiGetNextComponent {
    /**
     * @param {?} workDelivery
     */
    constructor(workDelivery) {
        this.workDelivery = workDelivery;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-angular-ui-get-next [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
    }
    /**
     * @return {?}
     */
    getNext() {
        this.workDelivery.getNextWorkItem(this.workItem$, this.lock ? true : false).subscribe(wim => { }, error => console.error(error));
    }
}
E5coreAngularUiGetNextComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-get-next',
                template: "<p>\n  <button mat-raised-button (click)=\"getNext()\">Get Next</button>\n</p>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreAngularUiGetNextComponent.ctorParameters = () => [
    { type: WorkDeliveryService }
];
E5coreAngularUiGetNextComponent.propDecorators = {
    workItem$: [{ type: Input }],
    lock: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const UiStyle = {
    Box: 0,
    Bootstrap: 1,
    Material: 2,
};
UiStyle[UiStyle.Box] = 'Box';
UiStyle[UiStyle.Bootstrap] = 'Bootstrap';
UiStyle[UiStyle.Material] = 'Material';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UiStyleService {
    /**
     * @return {?}
     */
    current() {
        return (UiStyle.Material);
    }
    ;
}
UiStyleService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */ UiStyleService.ngInjectableDef = defineInjectable({ factory: function UiStyleService_Factory() { return new UiStyleService(); }, token: UiStyleService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkMenuItemComponent {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        this.style = style$$1;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-menu-item [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        this.workItem$.subscribe(wi => {
            this.workItemModel = wi;
        });
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onClick($event) {
        alert('You clicked ' + $event.menuCode);
    }
}
E5coreUiWorkMenuItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-menu-item',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-work-menu-item-box (clickEvent)='onClick($event)' *ngSwitchCase='0' [workItem$]='workItem$' [menuItem]='menuItem'></e5core-ui-work-menu-item-box>
    <e5core-ui-work-menu-item-bootstrap (clickEvent)='onClick($event)' *ngSwitchCase='1' [workItem$]='workItem$' [menuItem]='menuItem'></e5core-ui-work-menu-item-bootstrap>
    <e5core-ui-work-menu-item-material (clickEvent)='onClick($event)' *ngSwitchCase='2' [workItem$]='workItem$' [menuItem]='menuItem'></e5core-ui-work-menu-item-material>
  </span>
  `,
                changeDetection: ChangeDetectionStrategy.Default
            }] }
];
/** @nocollapse */
E5coreUiWorkMenuItemComponent.ctorParameters = () => [
    { type: UiStyleService }
];
E5coreUiWorkMenuItemComponent.propDecorators = {
    workItem$: [{ type: Input }],
    menuItem: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkMenuItemBoxComponent {
    constructor() {
        this.clickEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @param {?} menuCode
     * @return {?}
     */
    onClick($event, menuCode) {
        this.clickEvent.emit({ $event: $event, menuCode: menuCode });
    }
}
E5coreUiWorkMenuItemBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-menu-item-box',
                template: "<div class='e5-component'>\n    <div class='e5-title'>e5core-ui-work-menu-item</div>\n    <div class='e5-content'>\n      <code>{{menuItem | json}}</code>\n    </div>\n  </div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkMenuItemBoxComponent.ctorParameters = () => [];
E5coreUiWorkMenuItemBoxComponent.propDecorators = {
    workItem$: [{ type: Input }],
    menuItem: [{ type: Input }],
    clickEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkMenuItemMaterialComponent {
    constructor() {
        this.clickEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @param {?} menuCode
     * @return {?}
     */
    onClick($event, menuCode) {
        this.clickEvent.emit({ $event: $event, menuCode: menuCode });
    }
    /**
     * @param {?} code
     * @return {?}
     */
    mapIcon(code) {
        switch (code.toLowerCase()) {
            case 'saveandclose': return 'close';
            case 'diarise': return 'date_range';
            case 'complete': return 'assignment_turned_in';
            case 'endgetnext': return 'stop';
            case 'clonewithoptions': return 'file_copy';
            case 'reject': return 'highlight_off';
        }
        return (code);
    }
}
E5coreUiWorkMenuItemMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-menu-item-material',
                template: "<button (click)='onClick($event,menuItem.code)' mat-menu-item>\n  <mat-icon>{{mapIcon(menuItem.code)}}</mat-icon>\n  <span>{{menuItem.label}}</span>\n</button>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkMenuItemMaterialComponent.ctorParameters = () => [];
E5coreUiWorkMenuItemMaterialComponent.propDecorators = {
    workItem$: [{ type: Input }],
    menuItem: [{ type: Input }],
    clickEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkMenuItemBootstrapComponent {
    constructor() {
        this.clickEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @param {?} menuCode
     * @return {?}
     */
    onClick($event, menuCode) {
        this.clickEvent.emit({ $event: $event, menuCode: menuCode });
    }
}
E5coreUiWorkMenuItemBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-menu-item-bootstrap',
                template: "<button (click)='onClick($event,menuItem.code)' type=\"button\" class=\"btn btn-secondary\" >{{menuItem.label}}</button>&nbsp;",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkMenuItemBootstrapComponent.ctorParameters = () => [];
E5coreUiWorkMenuItemBootstrapComponent.propDecorators = {
    workItem$: [{ type: Input }],
    menuItem: [{ type: Input }],
    clickEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5CoreUiWorkMenuBoxComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5CoreUiWorkMenuBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-menu-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <div class='e5-title'>e5core-ui-work-menu {{(workItem$ | async).workId}}</div>\n    <div class='e5-content' *ngIf='menuItems'>\n      <div *ngFor='let menuItem of menuItems'>\n       <e5core-ui-work-menu-item [workItem$]='workItem$' [menuItem]='menuItem'></e5core-ui-work-menu-item>\n    </div>\n  </div>\n</div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5CoreUiWorkMenuBoxComponent.ctorParameters = () => [];
E5CoreUiWorkMenuBoxComponent.propDecorators = {
    workItem$: [{ type: Input }],
    menuItems: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5CoreUiWorkMenuBootstrapComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5CoreUiWorkMenuBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-menu-bootstrap',
                template: "<div>\n    <e5core-ui-work-menu-item *ngFor='let menuItem of menuItems' [workItem$]='workItem$' [menuItem]='menuItem'></e5core-ui-work-menu-item>\n</div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5CoreUiWorkMenuBootstrapComponent.ctorParameters = () => [];
E5CoreUiWorkMenuBootstrapComponent.propDecorators = {
    workItem$: [{ type: Input }],
    menuItems: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5CoreUiWorkMenuMaterialComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5CoreUiWorkMenuMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-menu-material',
                template: "<button mat-icon-button [matMenuTriggerFor]=\"menu\">\n<mat-icon>more_vert</mat-icon>\n</button>\n<mat-menu #menu=\"matMenu\">\n    <e5core-ui-work-menu-item\n        *ngFor='let menuItem of menuItems'\n        [workItem$]='workItem$'\n        [menuItem]='menuItem'>\n    </e5core-ui-work-menu-item>\n</mat-menu>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5CoreUiWorkMenuMaterialComponent.ctorParameters = () => [];
E5CoreUiWorkMenuMaterialComponent.propDecorators = {
    workItem$: [{ type: Input }],
    menuItems: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkMenuComponent {
    /**
     * @param {?} style
     * @param {?} cd
     */
    constructor(style$$1, cd) {
        this.style = style$$1;
        this.cd = cd;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-menu [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        this.workItem$.subscribe(wi => {
            this.workItemModel = wi;
            this.menuItems = [];
            if (this.workItemModel && this.workItemModel.menus) {
                this.menuItems = this.workItemModel.menus;
            }
            this.cd.markForCheck();
        }, e => this.menuItems = null);
    }
}
E5coreUiWorkMenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-menu',
                template: `
    <span [ngSwitch]="style.current()">
      <e5core-ui-work-menu-box       *ngSwitchCase='0' [workItem$]='workItem$' [menuItems]='menuItems'></e5core-ui-work-menu-box>
      <e5core-ui-work-menu-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [menuItems]='menuItems'></e5core-ui-work-menu-bootstrap>
      <e5core-ui-work-menu-material  *ngSwitchCase='2' [workItem$]='workItem$' [menuItems]='menuItems'></e5core-ui-work-menu-material>
    </span>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkMenuComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: ChangeDetectorRef }
];
E5coreUiWorkMenuComponent.propDecorators = {
    workItem$: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkItemComponent {
    /**
     * @param {?} style
     * @param {?} cd
     */
    constructor(style$$1, cd) {
        this.style = style$$1;
        this.cd = cd;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-item [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        this.workItem$.subscribe(n => {
            this.workItem = n;
            this.cd.markForCheck();
        }, e => this.workItem = null);
    }
}
E5coreUiWorkItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-item',
                // templateUrl: './components/e5core-ui-work-item.component.html',
                template: `
    <span [ngSwitch]="style.current()">
      <e5core-ui-work-item-box       *ngSwitchCase='0'  [workItem$]='workItem$' [workItem]='workItem'></e5core-ui-work-item-box>
      <e5core-ui-work-item-bootstrap *ngSwitchCase='1'  [workItem$]='workItem$' [workItem]='workItem'></e5core-ui-work-item-bootstrap>
      <e5core-ui-work-item-material  *ngSwitchCase='2'  [workItem$]='workItem$' [workItem]='workItem'></e5core-ui-work-item-material>
    </span>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkItemComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: ChangeDetectorRef }
];
E5coreUiWorkItemComponent.propDecorators = {
    workItem$: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabComponent {
    /**
     * @param {?} style
     * @param {?} cd
     */
    constructor(style$$1, cd) {
        this.style = style$$1;
        this.cd = cd;
    }
    /**
     * @private
     * @param {?} tabId
     * @return {?}
     */
    updateTabModel(tabId) {
        this.tab = null;
        this.fieldSetIds = [];
        if (this.workItemModel && this.workItemModel.tabs && this.workItemModel.tabs) {
            /** @type {?} */
            const tab = this.workItemModel.tabs.find(t => t.tabId == this.tabId);
            if (tab) {
                this.tab = tab;
                this.fieldSetIds = tab.fieldSetIds;
            }
            else {
                console.warn(`tabId ${this.tabId} is not in parent e5core-ui-work-tab-set`);
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-tab [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (this.tabId == null) {
            console.error('e5core-ui-work-tab [tabId] must have a number value');
            return;
        }
        this.workItem$.subscribe(wi => {
            this.workItemModel = wi;
            this.updateTabModel(this.tabId);
            this.cd.markForCheck();
        });
    }
}
E5coreUiWorkTabComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-tab',
                template: `
  <span *ngIf="workItem$ && tabId" [ngSwitch]="style.current()">
    <e5core-ui-work-tab-box *ngSwitchCase='0' [workItem$]='workItem$' [tab]='tab' [fieldSetIds]='fieldSetIds' ></e5core-ui-work-tab-box>
    <e5core-ui-work-tab-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [tab]='tab' [fieldSetIds]='fieldSetIds' ></e5core-ui-work-tab-bootstrap>
    <e5core-ui-work-tab-material *ngSwitchCase='2' [workItem$]='workItem$' [tab]='tab' [fieldSetIds]='fieldSetIds' ></e5core-ui-work-tab-material>
  </span>
  <div *ngIf="!(workItem$ && tabId)" class="e5core-component-error">&lt;e5core-ui-work-tab&gt; [tabId] must be > 0 and [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkTabComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: ChangeDetectorRef }
];
E5coreUiWorkTabComponent.propDecorators = {
    workItem$: [{ type: Input }],
    tabId: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldSetComponent {
    /**
     * @param {?} style
     * @param {?} cd
     */
    constructor(style$$1, cd) {
        this.style = style$$1;
        this.cd = cd;
    }
    /**
     * @private
     * @param {?} fieldSetId
     * @return {?}
     */
    updateFieldSetModel(fieldSetId) {
        this.fieldSet = null;
        this.fields = [];
        if (this.workItemModel && this.workItemModel.fieldsets) {
            /** @type {?} */
            const fieldSet = this.workItemModel.fieldsets.find(fs => fs.fieldSetId == this.fieldSetId);
            if (fieldSet) {
                this.fieldSet = fieldSet;
                this.fields = fieldSet.fields;
            }
            else {
                console.error(`fieldSetId ${this.fieldSetId} not found in workItem$`);
            }
        }
        else {
            console.error(`No fieldsets in workItem$`);
        }
        this.cd.markForCheck();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-field-set [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (this.fieldSetId == null) {
            console.error('e5core-ui-work-field-set [fieldSetId] must have a number value');
            return;
        }
        this.workItem$.subscribe(wi => {
            this.workItemModel = wi;
            this.updateFieldSetModel(this.fieldSetId);
            this.cd.markForCheck();
        });
    }
}
E5coreUiWorkFieldSetComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-set',
                template: `
  <span *ngIf="workItem$ && fieldSetId" [ngSwitch]="style.current()">
    <e5core-ui-work-field-set-box *ngSwitchCase='0' [workItem$]='workItem$' [fieldSet]='fieldSet' [fields]='fields' [readonly]='readonly'></e5core-ui-work-field-set-box>
    <e5core-ui-work-field-set-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [fieldSet]='fieldSet' [fields]='fields' [readonly]='readonly'></e5core-ui-work-field-set-bootstrap>
    <e5core-ui-work-field-set-material *ngSwitchCase='2' [workItem$]='workItem$' [fieldSet]='fieldSet' [fields]='fields' [readonly]='readonly'></e5core-ui-work-field-set-material>
  </span>
  <div *ngIf="!(workItem$ && fieldSetId)" class="e5core-component-error">&lt;e5core-ui-work-field-set&gt; [fieldSetId] must be > 0 and [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>`
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldSetComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: ChangeDetectorRef }
];
E5coreUiWorkFieldSetComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fieldSetId: [{ type: Input }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldComponent {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        this.style = style$$1;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-field [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (this.fieldSetId === null || this.propertyId === '') {
            console.error('e5core-ui-work-field [propertyId] and [fieldSetId] must have a value');
            return;
        }
        this.workItem$.subscribe(n => {
            this.workItemModel = n;
            this.field = null;
            this.property = null;
            if (!(this.workItemModel && this.workItemModel.fieldsets && this.workItemModel.properties)) {
                return;
            }
            /** @type {?} */
            const fieldset = this.workItemModel.fieldsets.find(fs => fs.fieldSetId == this.fieldSetId);
            if (!fieldset) {
                console.warn(`fieldSetId ${this.fieldSetId} not found in workItem$`);
                return;
            }
            /** @type {?} */
            const field = fieldset.fields.find(f => f.propertyId == this.propertyId);
            if (!field) {
                console.warn(`propertyId ${this.propertyId} from found in workItem$ fields`);
                return;
            }
            /** @type {?} */
            const property = this.workItemModel.properties.find(p => p.propertyId == this.propertyId);
            if (!property) {
                console.warn(`propertyId ${this.propertyId} from found in workItem$ properties`);
                return;
            }
            this.field = field;
            this.property = property;
        });
    }
}
E5coreUiWorkFieldComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field',
                template: `
  <span *ngIf="workItem$ && fieldSetId && propertyId && property && field" [ngSwitch]="style.current()">
    <e5core-ui-work-field-box *ngSwitchCase='0' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly' ></e5core-ui-work-field-box>
    <e5core-ui-work-field-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly' ></e5core-ui-work-field-bootstrap>
    <e5core-ui-work-field-material *ngSwitchCase='2' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly' ></e5core-ui-work-field-material>
  </span>
  <div *ngIf="!(workItem$ && fieldSetId && propertyId)" class="e5core-component-error">&lt;e5core-ui-work-field-set&gt; missing [fieldSetId], [propertyId] and [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>`
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldComponent.ctorParameters = () => [
    { type: UiStyleService }
];
E5coreUiWorkFieldComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fieldSetId: [{ type: Input }],
    propertyId: [{ type: Input }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabSetComponent {
    /**
     * @param {?} style
     * @param {?} cd
     */
    constructor(style$$1, cd) {
        this.style = style$$1;
        this.cd = cd;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-tab-set [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        this.workItem$.subscribe(workItem => {
            this.workItem = workItem;
            // convert tabs associative array to a standard array
            this.tabs = workItem.tabs;
            // if (this.workItem && this.workItem.tabs) {
            //   const tabList = this.workItem.tabs ;
            //   for (const tab of Object.values(tabList)) {
            //     //tab.errorCount = this.errorCount(tab.fieldSetRefs) ;
            //     this.tabs.push(tab) ;
            //   }
            // }
            this.cd.markForCheck();
        }, e => this.workItem = null);
    }
    /**
     * @param {?} fieldSetIds
     * @return {?}
     */
    errorCount(fieldSetIds) {
        if (!(this.workItem && this.workItem.fieldsets)) {
            return (0);
        }
        /** @type {?} */
        const fieldSets = this.workItem.fieldsets;
        if (!fieldSets) {
            return (0);
        }
        return (0);
    }
}
E5coreUiWorkTabSetComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-tab-set',
                template: `
    <span [ngSwitch]="style.current()">
      <e5core-ui-work-tab-set-box *ngSwitchCase='0' [workItem$]='workItem$' [tabs]='tabs'></e5core-ui-work-tab-set-box>
      <e5core-ui-work-tab-set-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [tabs]='tabs'></e5core-ui-work-tab-set-bootstrap>
      <e5core-ui-work-tab-set-material *ngSwitchCase='2' [workItem$]='workItem$' [tabs]='tabs'></e5core-ui-work-tab-set-material>
    </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkTabSetComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: ChangeDetectorRef }
];
E5coreUiWorkTabSetComponent.propDecorators = {
    workItem$: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkAttachmentsBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkAttachmentsBaseComponent.propDecorators = {
    workItem$: [{ type: Input }],
    readonly: [{ type: Input }],
    pagesizes: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkAttachmentsFrameModel {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AttachmentsOdataService {
    /**
     * @param {?} http
     * @param {?} config
     */
    constructor(http, config) {
        this.http = http;
        this.config = config;
    }
    // apiServer: {
    //   baseUrl: 'http://vlane5dev2016:84',
    //   scope: 'test'
    // }
    // e.g. http://localhost:12661/site/odata/Ui/Attachments/8b50f520-cac0-11e8-a32f-00155d2a720c?$count=true&$top=2&$skip=2
    //
    // {
    //   "$id": "1",
    //   "metaData": null,
    //   "id": 1117,
    //   "attachmentId": "630",
    //   "workId": "84ef573a-d293-11e8-967f-005056ba65e4",
    //   "documentName": "20181030133835358_test.pdf",
    //   "parentId": 0,
    //   "attachmentTypeId": 0
    // },
    /**
     * @param {?} workId
     * @param {?} page
     * @param {?} pagesize
     * @param {?=} options
     * @return {?}
     */
    getWorkAttachments(workId, page, pagesize, options) {
        /** @type {?} */
        let subject$ = new BehaviorSubject(new WorkAttachmentsFrameModel());
        /** @type {?} */
        let baseUrl = this.config.settings.apiServer.baseUrl;
        /** @type {?} */
        let scope = this.config.settings.apiServer.scope;
        /** @type {?} */
        let offset = page * pagesize;
        /** @type {?} */
        let url = `${baseUrl}/${scope}/odata/Ui/Attachments/${workId.toString()}?$count=true&$top=${pagesize || 10}&$skip=${offset || 0}`;
        // Append orderby
        if (options && options.orderby && options.orderby !== "")
            url += `&$orderby=${encodeURIComponent(options.orderby)}`;
        this.http.get(url).subscribe(result => {
            /** @type {?} */
            let whf = new WorkAttachmentsFrameModel();
            whf.count = result["@odata.count"];
            whf.page = page;
            whf.pagesize = pagesize;
            whf.data = result.value;
            subject$.next(whf);
        }, error => {
            console.error(error);
            subject$.error(error);
        });
        return (subject$);
    }
}
AttachmentsOdataService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
AttachmentsOdataService.ctorParameters = () => [
    { type: HttpClient },
    { type: E5ConfigurationService }
];
/** @nocollapse */ AttachmentsOdataService.ngInjectableDef = defineInjectable({ factory: function AttachmentsOdataService_Factory() { return new AttachmentsOdataService(inject(HttpClient), inject(E5ConfigurationService)); }, token: AttachmentsOdataService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OdataMatTableDataSource extends DataSource {
    /**
     * @param {?} workId
     * @param {?} workAttachmentsService
     */
    constructor(workId, workAttachmentsService) {
        super();
        this.workId = workId;
        this.workAttachmentsService = workAttachmentsService;
        this.subject$ = new BehaviorSubject([]);
        this.orderby = { active: "Id", direction: "desc" };
        this.loading$ = new BehaviorSubject(false);
    }
    /**
     * @param {?} paginator
     * @return {?}
     */
    set paginator(paginator) {
        this._paginator = paginator;
        this._paginator.page.subscribe(x => {
            // {"previousPageIndex":0,"pageIndex":1,"pageSize":10,"length":100}
            this.update();
        });
    }
    /**
     * @param {?} sort
     * @return {?}
     */
    set sort(sort) {
        this._sort = sort;
        this._sort.sortChange.subscribe(ob => {
            // {active: "detail", direction: ""}
            this.orderby = ob;
            this.update();
        });
    }
    /**
     * @param {?} id
     * @return {?}
     */
    setWorkId(id) {
        this.workId = id;
        this.update();
    }
    /**
     * @return {?}
     */
    get loadingEvents() {
        return this.loading$;
    }
    /**
     * @return {?}
     */
    update() {
        if (!this.workId || !Guid.isGuid(this.workId) || this.workId.toString() === Guid.EMPTY) {
            this.subject$.next([]);
            return;
        }
        /** @type {?} */
        let page = (this._paginator) ? this._paginator.pageIndex : 0;
        /** @type {?} */
        let pagesize = (this._paginator) ? this._paginator.pageSize : 10;
        /** @type {?} */
        let options = {};
        // Setup orderby option if it's available
        /** @type {?} */
        let orderby = this.orderby;
        if (orderby && orderby.direction && orderby.active) {
            options.orderby = `${orderby.active} ${orderby.direction}`;
        }
        // Go get the data
        this.loading$.next(true);
        this.workAttachmentsService.getWorkAttachments(this.workId, page, pagesize, options).subscribe(frame => {
            this._paginator.length = frame.count;
            this.subject$.next(frame.data);
            this.loading$.next(false);
        }, error => {
            console.error(error);
            this.loading$.next(false);
        });
    }
    /**
     * @return {?}
     */
    connect() {
        this.update();
        return (this.subject$);
    }
    /**
     * @return {?}
     */
    disconnect() { }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkAttachmentsMaterialComponent extends E5coreUiWorkAttachmentsBaseComponent {
    /**
     * @param {?} workAttachments
     */
    constructor(workAttachments) {
        super();
        this.workAttachments = workAttachments;
        this.attachmentDownloadEvent = new EventEmitter();
        this.attachmentSelectEvent = new EventEmitter();
        this.displayedColumns = ['Select', 'Menu', 'Name', 'Type'];
        this.isLoading = true;
        this.length = 0;
        this.pageSize = 10;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.pageSizeOptions = (this.pagesizes && this.pagesizes.length > 0) ? this.pagesizes : [5, 10, 25, 50];
        this.dataSource = new OdataMatTableDataSource(Guid.EMPTY, this.workAttachments); // this.history.getHistory(id, 0, 10) ;
        this.dataSource.sort = this.sort;
        this.dataSource.paginator = this.paginator;
        this.dataSource.loadingEvents.subscribe(isLoading => {
            this.isLoading = isLoading;
        });
        if (typeof this.workItem$ != 'undefined') {
            this.workItem$.subscribe(wim => {
                this.dataSource.setWorkId(wim.workId);
            });
        }
        if (typeof this.fileUpload$ != 'undefined') {
            this.fileUpload$.subscribe(fum => {
                this.dataSource.setWorkId(fum.workId);
            });
        }
    }
    /**
     * @return {?}
     */
    refresh() {
        this.dataSource.update();
    }
    /**
     * @param {?} event
     * @param {?} element
     * @return {?}
     */
    onAttachmentDownload(event, element) {
        this.attachmentDownloadEvent.emit({ event: event, element: element });
    }
    /**
     * @param {?} event
     * @param {?} element
     * @return {?}
     */
    onAttachmentSelect(event, element) {
        this.attachmentSelectEvent.emit({ workId: element.WorkId, type: "E5SharepointAttachment", attachmentId: element.Id, fullUrl: null, name: null });
    }
    /**
     * @param {?} setPageSizeOptionsInput
     * @return {?}
     */
    setPageSizeOptions(setPageSizeOptionsInput) {
        this.pageSizeOptions = setPageSizeOptionsInput.split(',').map(str => +str);
    }
}
E5coreUiWorkAttachmentsMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-attachments-material',
                template: "<div class=\"e5core-ui-work-attachments\">\n\n  <div *ngIf=\"isLoading\" class=\"mat-spinner-holder\" align=\"center\">\n      <mat-spinner></mat-spinner>\n  </div>\n\n  <table mat-table [dataSource]=\"dataSource\" matSort class=\"e5core-ui-work-attachments\">\n\n\n    <!-- Select -->\n    <ng-container matColumnDef=\"Select\">\n      <th mat-header-cell *matHeaderCellDef> </th>\n      <td mat-cell *matCellDef=\"let element\"> \n          <button (click)='onAttachmentSelect($event, element)' mat-icon-button>\n            <mat-icon>attach_file</mat-icon>\n          </button>\n      </td>\n    </ng-container>\n\n    <!-- Menu -->\n    <ng-container matColumnDef=\"Menu\">\n      <th mat-header-cell *matHeaderCellDef> </th>\n      <td mat-cell *matCellDef=\"let element\"> \n          <button mat-icon-button [matMenuTriggerFor]=\"menu\">\n            <mat-icon>more_vert</mat-icon>\n          </button>\n          <mat-menu #menu=\"matMenu\">\n            <button (click)='onAttachmentDownload($event, element)' mat-menu-item>\n              <mat-icon>cloud_download</mat-icon>\n              <span>Download</span>\n            </button>\n          </mat-menu>\n      </td>\n    </ng-container>\n\n    <!-- Name -->\n    <ng-container matColumnDef=\"Name\">\n      <th mat-header-cell *matHeaderCellDef mat-sort-header> Name </th>\n      <td mat-cell *matCellDef=\"let element\"> {{element.Name}} </td>\n    </ng-container>\n\n    <!-- Type -->\n    <ng-container matColumnDef=\"Type\">\n      <th mat-header-cell *matHeaderCellDef mat-sort-header> Type </th>\n      <td mat-cell *matCellDef=\"let element\"> {{element.Type}} </td>\n    </ng-container>\n\n    <tr mat-header-row *matHeaderRowDef=\"displayedColumns\"></tr>\n    <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\n  </table>\n\n  <mat-paginator [length]=\"length\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"pageSizeOptions\" (page)=\"pageEvent = $event\" showFirstLastButtons></mat-paginator>\n</div>",
                styles: ["table.e5core-ui-work-attachments{width:100%}table.e5core-ui-work-attachments tr th:nth-child(1),table.e5core-ui-work-attachments tr th:nth-child(2){width:50pt}table.e5core-ui-work-attachments tr th:nth-child(3){width:220pt}.e5core-ui-work-attachments .mat-spinner-holder{width:100%;padding:20pt;position:relative;top:30px;height:1px}.e5core-ui-work-attachments .mat-paginator{margin-top:0;background:0 0}"]
            }] }
];
/** @nocollapse */
E5coreUiWorkAttachmentsMaterialComponent.ctorParameters = () => [
    { type: AttachmentsOdataService }
];
E5coreUiWorkAttachmentsMaterialComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fileUpload$: [{ type: Input }],
    attachmentDownloadEvent: [{ type: Output }],
    attachmentSelectEvent: [{ type: Output }],
    sort: [{ type: ViewChild, args: [MatSort,] }],
    paginator: [{ type: ViewChild, args: [MatPaginator,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// <e5core-ui-work-attachments-box *ngSwitchCase='0' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes'></e5core-ui-work-attachments-box>
// <e5core-ui-work-attachments-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes'></e5core-ui-work-attachments-bootstrap>
class E5coreUiWorkAttachmentsComponent {
    /**
     * @param {?} style
     * @param {?} config
     * @param {?} changeDetectorRef
     */
    constructor(style$$1, config, changeDetectorRef) {
        this.style = style$$1;
        this.config = config;
        this.changeDetectorRef = changeDetectorRef;
        this.attachmentDownloadEvent = new EventEmitter();
        this.attachmentSelectEvent = new EventEmitter();
        this.downloadUrl = '';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.workItem$ == 'undefined') {
            console.error('e5core-ui-work-attachments [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (typeof this.workItem$ != 'undefined') {
            this.workItem$.subscribe(w => {
                this.updateData();
            });
        }
        if (typeof this.fileUpload$ != 'undefined') {
            this.fileUpload$.subscribe(w => {
                this.updateData();
            });
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @return {?}
     */
    refresh() {
        this.workAttachmentsMaterialComponent.refresh();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onAttachmentDownload(event) {
        /** @type {?} */
        var baseUrl = this.config.settings.apiServer.baseUrl;
        /** @type {?} */
        var scope = this.config.settings.apiServer.scope;
        /** @type {?} */
        var w = this.workItem$.getValue();
        this.downloadUrl = `${baseUrl}/${scope}/api/ui/Attachment/Download/${w.workId}/${event.element.Id}`;
        this.changeDetectorRef.detectChanges();
        setTimeout(() => { this.downloadUrl = ""; }, 200);
        this.attachmentDownloadEvent.emit(event);
    }
    /**
     * @param {?} viewerDisplayEvent
     * @return {?}
     */
    onAttachmentSelect(viewerDisplayEvent) {
        this.attachmentSelectEvent.emit(viewerDisplayEvent);
    }
    /**
     * @private
     * @return {?}
     */
    updateData() {
    }
}
E5coreUiWorkAttachmentsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-attachments',
                template: `
  <span *ngIf="workItem$" [ngSwitch]="style.current()">
    <e5core-ui-work-attachments-material *ngSwitchCase='2' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes' (attachmentDownloadEvent)='onAttachmentDownload($event)' (attachmentSelectEvent)='onAttachmentSelect($event)' ></e5core-ui-work-attachments-material>
  </span>
  <div *ngIf="!(workItem$)" class="e5core-component-error">&lt;e5core-ui-work-attachments&gt; [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>
  <iframe width="0" height="0" *ngIf="!(downloadUrl == '')" [src]="downloadUrl | safe" style="width:0;height:0;border:0; border:none; position: absolute;"></iframe>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkAttachmentsComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: E5ConfigurationService },
    { type: ChangeDetectorRef }
];
E5coreUiWorkAttachmentsComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fileUpload$: [{ type: Input }],
    readonly: [{ type: Input }],
    pagesizes: [{ type: Input }],
    attachmentDownloadEvent: [{ type: Output }],
    attachmentSelectEvent: [{ type: Output }],
    workAttachmentsMaterialComponent: [{ type: ViewChild, args: [E5coreUiWorkAttachmentsMaterialComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class E5coreUiWorkFieldTypeBase {
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-field-type-input [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        this.workItem$.subscribe(n => {
            this.workItemModel = n;
        });
    }
    /**
     * @param {?} propertyId
     * @param {?} value
     * @param {?=} error
     * @return {?}
     */
    dispatchPropertyChange(propertyId, value, error) {
        /** @type {?} */
        const wi = Object.assign({}, this.workItem$.getValue());
        // Clone
        // const prop = wi.propertyList.properties[propertyId] ;
        /** @type {?} */
        const prop = wi.properties.find(p => p.propertyId == propertyId);
        prop.resolvedValue = value;
        prop.value = value;
        // prop.hasError = error ;
        this.workItem$.next(wi);
    }
}
E5coreUiWorkFieldTypeBase.propDecorators = {
    workItem$: [{ type: Input }],
    field: [{ type: Input }],
    property: [{ type: Input }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeInputComponent extends E5coreUiWorkFieldTypeBase {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        super();
        this.style = style$$1;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    valueChange($event) {
        this.dispatchPropertyChange(this.property.propertyId, $event.value, $event.error);
        return;
    }
}
E5coreUiWorkFieldTypeInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-input',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-work-field-type-input-box *ngSwitchCase='0' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='pattern' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-input-box>
    <e5core-ui-work-field-type-input-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='pattern' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-input-bootstrap>
    <e5core-ui-work-field-type-input-material *ngSwitchCase='2' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='pattern' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-input-material>
  </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeInputComponent.ctorParameters = () => [
    { type: UiStyleService }
];
E5coreUiWorkFieldTypeInputComponent.propDecorators = {
    pattern: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeIntegerComponent extends E5coreUiWorkFieldTypeBase {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        super();
        this.style = style$$1;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    valueChange($event) {
        this.dispatchPropertyChange(this.property.propertyId, $event.value, $event.error);
    }
}
E5coreUiWorkFieldTypeIntegerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-integer',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-work-field-type-integer-box *ngSwitchCase='0' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-integer-box>
    <e5core-ui-work-field-type-integer-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-integer-bootstrap>
    <e5core-ui-work-field-type-integer-material *ngSwitchCase='2' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-integer-material>
  </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeIntegerComponent.ctorParameters = () => [
    { type: UiStyleService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5CoreUiWorkItemBoxComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5CoreUiWorkItemBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-item-box',
                template: "<div class='e5-component' *ngIf=\"workItem$\">\n  <div class='e5-title'>e5core-ui-work-item {{workItem.workId}}</div>\n  <div class='e5-content'>\n    <e5core-ui-work-menu [workItem$]=\"workItem$\"></e5core-ui-work-menu>\n    <e5core-ui-work-tab-set [workItem$]=\"workItem$\"></e5core-ui-work-tab-set>\n    <e5core-ui-work-history></e5core-ui-work-history>\n    <e5core-ui-work-attachments></e5core-ui-work-attachments>\n    <e5core-ui-work-casenotes></e5core-ui-work-casenotes>\n  </div>\n</div>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5CoreUiWorkItemBoxComponent.ctorParameters = () => [];
E5CoreUiWorkItemBoxComponent.propDecorators = {
    workItem$: [{ type: Input }],
    workItem: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5CoreUiWorkItemBootstrapComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5CoreUiWorkItemBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-item-bootstrap',
                template: "<div class=\"card\" *ngIf=\"workItem$\">\n  <div class=\"card-body\">\n    <h5 class=\"card-title\">{{(workItem$ | async).workId}}</h5>\n    <!-- <h6 class=\"card-subtitle mb-2 text-muted\">Card subtitle</h6> -->\n    <p class=\"card-text\">\n      <e5core-ui-work-menu [workItem$]=\"workItem$\"></e5core-ui-work-menu>\n      <e5core-ui-work-tab-set [workItem$]=\"workItem$\"></e5core-ui-work-tab-set>\n      <e5core-ui-work-history></e5core-ui-work-history>\n      <e5core-ui-work-attachments></e5core-ui-work-attachments>\n      <e5core-ui-work-casenotes></e5core-ui-work-casenotes>\n    </p>\n    <a href=\"#\" class=\"card-link\">Save</a>\n    <a href=\"#\" class=\"card-link\">Cancel</a>\n  </div>\n</div>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5CoreUiWorkItemBootstrapComponent.ctorParameters = () => [];
E5CoreUiWorkItemBootstrapComponent.propDecorators = {
    workItem$: [{ type: Input }],
    workItem: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileUploadModel {
    constructor() {
        this.workId = Guid.EMPTY;
        this.name = null;
    }
}
/**
 * @return {?}
 */
function CreateBlankFileUpload() {
    return new FileUploadModel();
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ViewerModel {
    constructor() {
        this.workId = Guid.EMPTY;
        this.name = null;
        this.id = "";
        this.fullUrl = null;
        this.features = null;
    }
}
/**
 * @return {?}
 */
function CreateBlankViewer() {
    return new ViewerModel();
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const ViewerBehaviourType = {
    Popup: 0,
    Inline: 1,
};
ViewerBehaviourType[ViewerBehaviourType.Popup] = 'Popup';
ViewerBehaviourType[ViewerBehaviourType.Inline] = 'Inline';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiAttachmentViewerBaseComponent {
    /**
     * @param {?} e5ConfigurationService
     * @param {?} changeDetectorRef
     */
    constructor(e5ConfigurationService, changeDetectorRef) {
        this.e5ConfigurationService = e5ConfigurationService;
        this.changeDetectorRef = changeDetectorRef;
        this.viewerDisplayedEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    showInlineViewer(viewerModel) {
        this.constructViewerUrl(viewerModel, null);
        this.raiseEvent(viewerModel);
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    showPopViewer(viewerModel) {
        this.constructViewerUrl(viewerModel, (vm, url) => this.performWindowPopup(vm, url));
    }
    /**
     * @param {?} viewerModel
     * @param {?} attachmentUrl
     * @return {?}
     */
    performWindowPopup(viewerModel, attachmentUrl) {
        window.open(attachmentUrl, "E5AttachmentViewer", this.popupWindowFeatures);
        this.raiseEvent(viewerModel);
    }
    /**
     * @param {?} viewerModel
     * @param {?} nextFunction
     * @return {?}
     */
    constructViewerUrl(viewerModel, nextFunction) {
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    raiseEvent(viewerModel) {
    }
}
E5coreUiAttachmentViewerBaseComponent.propDecorators = {
    behaviourType: [{ type: Input }],
    popupWindowFeatures: [{ type: Input }],
    readonly: [{ type: Input }],
    viewerDisplayedEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkAttachmentViewerComponent {
    constructor() {
        this.behaviourType = 0;
        this.popupWindowFeatures = "top=0,left=0,width=500,height=700,directories=no,location=no,menubar=no,status=no,resizable=yes,titlebar=yes,toolbar=no";
        this.readonly = true;
        this.viewerDisplayedEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    showViewer(viewerModel) {
        if (this.attachmentViewerComponents == undefined)
            return;
        switch (+this.behaviourType) {
            case ViewerBehaviourType.Inline:
                this.attachmentViewerComponents.forEach(element => {
                    element.showInlineViewer(viewerModel);
                });
                break;
            case ViewerBehaviourType.Popup:
                this.attachmentViewerComponents.forEach(element => {
                    element.showPopViewer(viewerModel);
                });
                break;
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onViewerDisplayed(event) {
        this.viewerDisplayedEvent.emit(event);
    }
}
E5coreUiWorkAttachmentViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-attachment-viewer',
                template: `
    <span [ngSwitch]="viewerType">
    <e5core-ui-e5-attachment-viewer *ngSwitchCase='0' [behaviourType]="behaviourType" [popupWindowFeatures]="popupWindowFeatures" [readonly]="readonly" (viewerDisplayedEvent)="onViewerDisplayed($event)"></e5core-ui-e5-attachment-viewer>
    <e5core-ui-weburi-attachment-viewer *ngSwitchCase='1' [behaviourType]="behaviourType" [popupWindowFeatures]="popupWindowFeatures" [readonly]="readonly" (viewerDisplayedEvent)="onViewerDisplayed($event)"></e5core-ui-weburi-attachment-viewer>
    <e5core-ui-webdav-weburi-attachment-viewer *ngSwitchCase='2' [behaviourType]="behaviourType" [popupWindowFeatures]="popupWindowFeatures" [readonly]="readonly" (viewerDisplayedEvent)="onViewerDisplayed($event)"></e5core-ui-webdav-weburi-attachment-viewer>
    </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkAttachmentViewerComponent.ctorParameters = () => [];
E5coreUiWorkAttachmentViewerComponent.propDecorators = {
    viewerType: [{ type: Input }],
    behaviourType: [{ type: Input }],
    popupWindowFeatures: [{ type: Input }],
    readonly: [{ type: Input }],
    viewerDisplayedEvent: [{ type: Output }],
    attachmentViewerComponents: [{ type: ViewChildren, args: [E5coreUiAttachmentViewerBaseComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiEmailConversationViewerComponent {
    /**
     * @param {?} e5ConfigurationService
     * @param {?} configurationScopeService
     */
    constructor(e5ConfigurationService, configurationScopeService) {
        this.e5ConfigurationService = e5ConfigurationService;
        this.configurationScopeService = configurationScopeService;
        this.viewerDisplayedEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    showInlineViewer(viewerModel) {
        this.constructViewerUrl(viewerModel, null);
        this.raiseEvent(viewerModel);
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    showPopViewer(viewerModel) {
        this.constructViewerUrl(viewerModel, this.performWindowPopup);
    }
    /**
     * @private
     * @param {?} viewerModel
     * @return {?}
     */
    performWindowPopup(viewerModel) {
        window.open(viewerModel.fullUrl, 'E5ConversationViewer', viewerModel.features);
        this.raiseEvent(viewerModel);
    }
    /**
     * @param {?} viewerModel
     * @param {?} nextFunction
     * @return {?}
     */
    constructViewerUrl(viewerModel, nextFunction) {
        // format URL e.g.
        // http://hcfv3dev:84/Web/app/conversation/conversation.view.standalone.html?
        //  workid=c398be5d-e2ea-11e8-9681-005056ba65e4&source=GetNext&
        //  instance=8a97a0dc-ecf9-497f-95cb-42837ea6e4f2&department=66b8d445-b186-41e2-8c0e-661ccfc93ffc
        // format URL e.g.
        // http://hcfv3dev:84/Web/app/conversation/conversation.view.standalone.html?
        //  workid=c398be5d-e2ea-11e8-9681-005056ba65e4&source=GetNext&
        //  instance=8a97a0dc-ecf9-497f-95cb-42837ea6e4f2&department=66b8d445-b186-41e2-8c0e-661ccfc93ffc
        /** @type {?} */
        const documentStoreBaseUrl = this.e5ConfigurationService.settings.apiServer.baseUrl;
        viewerModel.features = this.popupWindowFeatures;
        this.configurationScopeService.get(this.e5ConfigurationService.settings.apiServer.scope).subscribe(s => {
            /** @type {?} */
            const departmentId = s.siteId;
            /** @type {?} */
            const instanceId = s.instanceId;
            /** @type {?} */
            const url = documentStoreBaseUrl + // e.g http://hcfv3dev:84
                '/Web/app/conversation/conversation.view.standalone.html' +
                '?workid=' + viewerModel.workId +
                '&source=GetNext' +
                '&instance=' + instanceId +
                '&department=' + departmentId;
            viewerModel.fullUrl = url;
            if (nextFunction) {
                nextFunction(viewerModel);
            }
        }, error => {
            console.error(error);
        });
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    raiseEvent(viewerModel) {
        this.viewerDisplayedEvent.emit({
            workId: viewerModel.workId,
            type: 'EmailConversation',
            attachmentId: null,
            fullUrl: null,
            name: null
        });
    }
}
E5coreUiEmailConversationViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-email-conversation-viewer',
                template: `
    <span *ngIf="1==+behaviourType">
    <iframe *ngIf="!(conversationViewerUrl == '')" [src]="conversationViewerUrl | safe"></iframe>
    </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiEmailConversationViewerComponent.ctorParameters = () => [
    { type: E5ConfigurationService },
    { type: ConfigurationScopeService }
];
E5coreUiEmailConversationViewerComponent.propDecorators = {
    behaviourType: [{ type: Input }],
    popupWindowFeatures: [{ type: Input }],
    readonly: [{ type: Input }],
    viewerDisplayedEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiConversationViewerComponent {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        this.style = style$$1;
        this.popupWindowFeatures = "top=0,left=0,width=500,height=700,directories=no,location=no,menubar=no,status=no,resizable=yes,titlebar=yes,toolbar=no";
        this.readonly = false;
        this.viewerDisplayedEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    showViewer(viewerModel) {
        if (this.emailConversationViewerComponent == undefined)
            return;
        switch (+this.behaviourType) {
            case ViewerBehaviourType.Inline:
                this.emailConversationViewerComponent.showInlineViewer(viewerModel);
                break;
            case ViewerBehaviourType.Popup:
                this.emailConversationViewerComponent.showPopViewer(viewerModel);
                break;
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onViewerDisplayed(event) {
        this.viewerDisplayedEvent.emit(event);
    }
}
E5coreUiConversationViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-conversation-viewer',
                template: `
    <span>
    <e5core-ui-email-conversation-viewer [behaviourType]="behaviourType" [popupWindowFeatures]="popupWindowFeatures" [readonly]="readonly" (viewerDisplayedEvent)="onViewerDisplayed($event)"></e5core-ui-email-conversation-viewer>
    </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiConversationViewerComponent.ctorParameters = () => [
    { type: UiStyleService }
];
E5coreUiConversationViewerComponent.propDecorators = {
    behaviourType: [{ type: Input }],
    popupWindowFeatures: [{ type: Input }],
    readonly: [{ type: Input }],
    viewerDisplayedEvent: [{ type: Output }],
    emailConversationViewerComponent: [{ type: ViewChild, args: [E5coreUiEmailConversationViewerComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5CoreUiWorkItemMaterialComponent {
    constructor() {
        this.workRelatedItemFields = [
            { key: "Category1Name", value: "Product" },
            { key: "Category2Name", value: "Business Unit" },
            { key: "Category3Name", value: "Category" },
            { key: "StatusName", value: "Status" },
            { key: "Reference", value: "" },
            { key: "AssignedUser", value: "" }
        ];
        this.selectFromListFields = [
            { fieldId: "FullUrl", fieldCode: "fullUrl", name: "Full Url", display: false },
            { fieldId: "FileLeafRef", fieldCode: "fileLeafRef", name: "Document Name", display: true },
            { fieldId: "_dlc_DocId", fieldCode: "_dlc_DocId", name: "Policy No", display: true },
            { fieldId: "_UIVersionString", fieldCode: "_UIVersionString", name: "Version No", display: true },
            { fieldId: "Synonym", fieldCode: "synonym", name: "Synonyms", display: true }
        ];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const blankFileUpload = CreateBlankFileUpload();
        this.fileUpload$ = new BehaviorSubject(blankFileUpload);
        this.fileUpload$.subscribe(m => { }, error => {
            console.error(error);
        });
        if (typeof this.workItem$ == 'undefined') {
            console.error('e5core-ui-work-related-items [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (typeof this.workItem$ != 'undefined') {
            this.workItem$.subscribe(wim => {
                if (wim.workId != null && wim.workId != Guid.EMPTY) {
                    this.workId = wim.workId;
                }
            });
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onConversationView(event) {
        /** @type {?} */
        const viewerModel = CreateBlankViewer();
        viewerModel.workId = this.workId;
        this.conversationViewerComponent.forEach(element => {
            element.showViewer(viewerModel);
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onAttachmentSelect(event) {
        /** @type {?} */
        const viewerModel = CreateBlankViewer();
        viewerModel.id = event.attachmentId;
        viewerModel.workId = event.workId;
        this.attachmentViewerComponents.forEach(element => {
            if (element.viewerType == "0")
                element.showViewer(viewerModel);
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onGenerateDocument(event) {
        /** @type {?} */
        const viewerModel = CreateBlankViewer();
        viewerModel.fullUrl = event.fullUrl;
        viewerModel.workId = event.workId;
        this.attachmentViewerComponents.forEach(element => {
            if (element.viewerType == "2")
                element.showViewer(viewerModel);
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onListItemViewEvent(event) {
        debugger;
        /** @type {?} */
        const viewerModel = CreateBlankViewer();
        viewerModel.name = event.name;
        viewerModel.fullUrl = event.fullUrl;
        this.attachmentViewerComponents.forEach(element => {
            if (element.viewerType == "1")
                element.showViewer(viewerModel);
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onListItemSelectEvent(event) {
        alert("You have selected: " + event.element.fileLeafRef);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onWorkItemSelect(event) {
        alert("You are opening : " + event.workId);
    }
    //Diarise
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiarisePeriodOptionClick($event) {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseButtonClick($event) {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDateChange($event) {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseReasonTextChange($event) {
    }
}
E5CoreUiWorkItemMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-item-material',
                template: "<mat-card class=\"example-card\">\n  <mat-card-header>\n    <div mat-card-avatar><e5core-ui-work-menu [workItem$]=\"workItem$\"></e5core-ui-work-menu> </div>\n    <mat-card-title>e5 Work Item</mat-card-title>\n    <mat-card-subtitle>{{workItem.workId}}</mat-card-subtitle>\n  </mat-card-header>\n  <mat-card-content>\n    <e5core-ui-work-attachment-viewer behaviourType=\"0\" viewerType=\"0\" ></e5core-ui-work-attachment-viewer>\n\n    <e5core-ui-work-tab-set [workItem$]=\"workItem$\"></e5core-ui-work-tab-set>\n    <!-- <e5core-ui-work-history></e5core-ui-work-history>\n    <e5core-ui-work-attachments></e5core-ui-work-attachments>\n    <e5core-ui-work-casenotes></e5core-ui-work-casenotes> -->\n\n    <mat-tab-group>\n      <mat-tab label=\"History\" >\n        <e5core-ui-work-history [workItem$]=\"workItem$\"></e5core-ui-work-history>\n      </mat-tab>\n      <mat-tab label=\"Attachments\">\n          <e5core-ui-file-upload [workItem$]=\"workItem$\"\n                                 [fileUpload$]=\"fileUpload$\">\n          </e5core-ui-file-upload>\n          <e5core-ui-work-attachments [workItem$]=\"workItem$\" (attachmentSelectEvent)=\"onAttachmentSelect($event)\"></e5core-ui-work-attachments>\n      </mat-tab>\n      <mat-tab label=\"Case Notes\">\n        <e5core-ui-work-casenotes [workItem$]=\"workItem$\"></e5core-ui-work-casenotes>\n      </mat-tab>\n      <mat-tab label=\"Documents\">\n        <e5core-ui-work-attachment-viewer behaviourType=\"0\" viewerType=\"1\"></e5core-ui-work-attachment-viewer>\n        <e5core-ui-select-from-list [workItem$]='workItem$' [libraryId]=\"5\" [fieldsToShow]=\"selectFromListFields\" (listItemViewEvent)=\"onListItemViewEvent($event)\" (listItemSelectEvent)=\"onListItemSelectEvent($event)\"></e5core-ui-select-from-list>\n      </mat-tab>\n      <mat-tab label=\"Related\">\n        <e5core-ui-work-related-items [workItem$]='workItem$' [createButtonText]=\"'Refer'\" [showDefinedChildrenOnly]=\"false\" [findId]=\"1\" [fieldsToShow]=\"workRelatedItemFields\" (workItemSelectEvent)=\"onWorkItemSelect($event)\" (attachmentSelectEvent)=\"onAttachmentSelect($event)\" ></e5core-ui-work-related-items>\n      </mat-tab>\n      <mat-tab label=\"Diarise\">\n        <e5core-ui-work-diarise\u00A0\n        [workItem$]=\"workItem$\"\n        [periodOptions]='[\n        { label:\"Tomorrow\", diariseUnit:\"Days\", value:\"1\" },\n        { label:\"2 Days\", diariseUnit:\"Days\", value:\"2\" },\n        { label:\"Next Week\", diariseUnit:\"Weeks\", value:\"1\" }]'\u00A0\n        [displayedDate]\u00A0='displayedDate'\u00A0\n        [displayedTime]\u00A0=\u00A0'displayedTime'\u00A0\n        [diariseReasonPropertyId]\u00A0='\"AssessmentExplanationcode\"'\u00A0\n        [diariseReasonPlaceHolder]\u00A0='\"Enter the diarise reason here\"'\u00A0\n        [diariseReasonTextValue]='diariseReasonTextValue'\u00A0\n        [showDiariseButton]=true\u00A0\n        [showDiariseTime]=true\u00A0\n        [showDiariseReasonDropdown]\u00A0=\u00A0false\n        (periodChange)='onDiarisePeriodOptionClick($event)'\u00A0\n        (diariseClick)='onDiariseButtonClick($event)'\u00A0\n        (dateChange)='onDateChange($event)'\u00A0\n        (reasonTextChange)='onDiariseReasonTextChange($event)'></e5core-ui-work-diarise> \n      </mat-tab>\n      <mat-tab label=\"Others\">\n          <p>\n              <button mat-raised-button (click)=\"onConversationView($event)\">Conversation Viewer</button>\n          </p>\n          <e5core-ui-conversation-viewer behaviourType=\"0\" ></e5core-ui-conversation-viewer>\n          <e5core-ui-work-attachment-viewer behaviourType=\"0\" viewerType=\"2\"></e5core-ui-work-attachment-viewer>\n          <e5core-ui-generate-document [workItem$]='workItem$' [fileUpload$]=\"fileUpload$\" [showGenerateButton]=\"true\" (generateDocumentEvent)=\"onGenerateDocument($event)\"></e5core-ui-generate-document>\n      </mat-tab>\n    </mat-tab-group>\n\n  </mat-card-content>\n</mat-card>",
                styles: [".example-header-image{background-image:url(https://material.angular.io/assets/img/examples/shiba1.jpg);background-size:cover}"]
            }] }
];
/** @nocollapse */
E5CoreUiWorkItemMaterialComponent.ctorParameters = () => [];
E5CoreUiWorkItemMaterialComponent.propDecorators = {
    workItem$: [{ type: Input }],
    workItem: [{ type: Input }],
    attachmentViewerComponents: [{ type: ViewChildren, args: [E5coreUiWorkAttachmentViewerComponent,] }],
    conversationViewerComponent: [{ type: ViewChildren, args: [E5coreUiConversationViewerComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabSetMaterialComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkTabSetMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-tab-set-material',
                template: "<mat-tab-group *ngIf='workItem$'>\n  <div *ngIf='tabs && tabs.length > 0'>\n    <div *ngFor='let tab of tabs'>\n      <!-- <e5core-ui-work-tab [workItem$]='workItem$' [tabId]='tab.tabId'></e5core-ui-work-tab> -->\n      <mat-tab label=\"{{tab.name}}\">\n        <ng-template mat-tab-label>\n          <!-- <span *ngIf='tab.errorCount > 0' matBadge=\"{{tab.errorCount}}\" matBadgeOverlap=\"false\" matBadgeColor=\"warn\">{{tab.name}}</span> -->\n          <span>{{tab.name}}</span>\n        </ng-template>\n        <e5core-ui-work-tab [workItem$]='workItem$' [tabId]='tab.tabId'></e5core-ui-work-tab>\n      </mat-tab>\n    </div>\n  </div>\n</mat-tab-group>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkTabSetMaterialComponent.ctorParameters = () => [];
E5coreUiWorkTabSetMaterialComponent.propDecorators = {
    workItem$: [{ type: Input }],
    tabs: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabSetBoxComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkTabSetBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-tab-set-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <div class='e5-title'>e5core-ui-work-tab-set {{(workItem$ | async).workId}}</div>\n  <div class='e5-content'>\n\n    <div *ngIf='tabs && tabs.length > 0'>\n      <div *ngFor='let tab of tabs'>\n          <e5core-ui-work-tab [workItem$]='workItem$' [tabId]='tab.tabId'></e5core-ui-work-tab>\n        </div>\n      </div>\n  </div>\n</div>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkTabSetBoxComponent.ctorParameters = () => [];
E5coreUiWorkTabSetBoxComponent.propDecorators = {
    workItem$: [{ type: Input }],
    tabs: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabSetBootstrapComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkTabSetBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-tab-set-bootstrap',
                template: "<div class='e5-component' *ngIf='workItem$'>\n\n  <ul class=\"nav nav-tabs\">\n    <li *ngFor='let tab of tabs'><a href=\"#\">{{tab.name}}</a></li>\n  </ul>\n\n  <div *ngIf='tabs && tabs.length > 0' >\n    <e5core-ui-work-tab *ngFor='let tab of tabs' [workItem$]='workItem$' [tabId]='tab.tabId'></e5core-ui-work-tab>\n  </div>\n\n</div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkTabSetBootstrapComponent.ctorParameters = () => [];
E5coreUiWorkTabSetBootstrapComponent.propDecorators = {
    workItem$: [{ type: Input }],
    tabs: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabBaseComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkTabBaseComponent.propDecorators = {
    workItem$: [{ type: Input }],
    tab: [{ type: Input }],
    fieldSetIds: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabBootstrapComponent extends E5coreUiWorkTabBaseComponent {
}
E5coreUiWorkTabBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-tab-bootstrap',
                template: "<div class='panel panel-default e5-component' *ngIf='workItem$'>\n  <div class='panel-body' *ngIf='fieldSetIds && fieldSetIds.length > 0'>\n    <e5core-ui-work-field-set *ngFor='let fieldSetId of fieldSetIds' [workItem$]='workItem$' [fieldSetId]='fieldSetId'></e5core-ui-work-field-set>\n  </div>\n</div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabBoxComponent extends E5coreUiWorkTabBaseComponent {
}
E5coreUiWorkTabBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-tab-box',
                template: "<div class='e5-component'>\n  <div class='e5-title'>e5core-ui-work-tab {{(workItem$ | async).workId}} / {{tab.tabId}}</div>\n  <div class='e5-content'>\n    <code>{{tab | json}}</code>\n    <!-- <e5core-ui-work-field-set></e5core-ui-work-field-set> -->\n    <div *ngIf='fieldSetIds && fieldSetIds.length > 0'>\n      <div *ngFor='let fieldSetId of fieldSetIds'>\n          <e5core-ui-work-field-set [workItem$]='workItem$' [fieldSetId]='fieldSetId'></e5core-ui-work-field-set>\n      </div>\n    </div>\n  </div>\n</div>",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkTabMaterialComponent extends E5coreUiWorkTabBaseComponent {
}
E5coreUiWorkTabMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-tab-material',
                template: "<mat-card class='e5-work-tab' *ngIf='fieldSetIds && fieldSetIds.length > 0'>\n  <div *ngFor='let fieldSetId of fieldSetIds'>\n    <e5core-ui-work-field-set [workItem$]='workItem$' [fieldSetId]='fieldSetId'></e5core-ui-work-field-set>\n  </div>\n</mat-card>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldSetBoxComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkFieldSetBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-set-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <div class='e5-title'>e5core-ui-work-field-set {{(workItem$ | async).workId}} / {{fieldSet.fieldSetId}}</div>\n  <div class='e5-content'>\n    {{fields | json}}\n    <div *ngIf='fields && fields.length > 0'>\n      <div *ngFor='let field of fields'>\n        <e5core-ui-work-field [workItem$]='workItem$' [fieldSetId]='fieldSet.fieldSetId' [propertyId]='field.propertyId' [readonly]='readonly'></e5core-ui-work-field>\n      </div>\n    </div>\n\n  </div>\n</div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldSetBoxComponent.ctorParameters = () => [];
E5coreUiWorkFieldSetBoxComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fieldSet: [{ type: Input }],
    fields: [{ type: Input }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldSetMaterialComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkFieldSetMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-set-material',
                template: "<mat-card class='e5-work-field-set' *ngIf='workItem$'>\n  <mat-card-content>\n    <div *ngFor='let field of fields'>\n        <e5core-ui-work-field [workItem$]='workItem$' [fieldSetId]='fieldSet.fieldSetId' [propertyId]='field.propertyId' [readonly]='readonly'></e5core-ui-work-field>\n    </div>\n    <small class='e5core-work-field-set-id' *ngIf=\"fieldSet\">{{fieldSet.fieldSetId}}</small>\n  </mat-card-content>\n</mat-card>\n",
                styles: [".e5-work-field-set{margin-bottom:10pt}.e5core-work-field-set-id{display:none}"]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldSetMaterialComponent.ctorParameters = () => [];
E5coreUiWorkFieldSetMaterialComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fieldSet: [{ type: Input }],
    fields: [{ type: Input }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldSetBootstrapComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkFieldSetBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-set-bootstrap',
                template: "<div class='e5-component'>\n    <div class='e5-title'>e5core-ui-work-field-set</div>\n    <div class=\"e5-content\">\n\n      <div *ngIf='fields && fields.length > 0'>\n        <div *ngFor='let field of fields'>\n          <e5core-ui-work-field [workItem$]='workItem$' [fieldSetId]='fieldSet.fieldSetId' [propertyId]='field.propertyId' [readonly]='readonly'></e5core-ui-work-field>\n        </div>\n      </div>\n\n    </div>\n  </div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldSetBootstrapComponent.ctorParameters = () => [];
E5coreUiWorkFieldSetBootstrapComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fieldSet: [{ type: Input }],
    fields: [{ type: Input }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldBootstrapComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkFieldBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-bootstrap',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <div class='e5-title'>e5core-ui-work-field {{(workItem$ | async).workId}}/{{field.propertyId}}</div>\n  <div class='e5-content'>\n    <code>field = {{field | json}}</code>\n    <code>property = {{property | json}}</code>\n\n    <e5core-ui-work-field-switch [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-switch>\n\n  </div>\n</div>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldBootstrapComponent.ctorParameters = () => [];
E5coreUiWorkFieldBootstrapComponent.propDecorators = {
    workItem$: [{ type: Input }],
    field: [{ type: Input, args: ['field',] }],
    property: [{ type: Input, args: ['property',] }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldMaterialComponent {
    /**
     * @param {?} cd
     */
    constructor(cd) {
        this.cd = cd;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$) {
            this.workItem$.subscribe();
        }
    }
}
E5coreUiWorkFieldMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-material',
                template: "<e5core-ui-work-field-switch [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-switch>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldMaterialComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
E5coreUiWorkFieldMaterialComponent.propDecorators = {
    workItem$: [{ type: Input }],
    field: [{ type: Input, args: ['field',] }],
    property: [{ type: Input, args: ['property',] }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldBoxComponent {
    /**
     * @param {?} cd
     */
    constructor(cd) {
        this.cd = cd;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$) {
            this.workItem$.subscribe(wi => this.cd.markForCheck());
        }
    }
}
E5coreUiWorkFieldBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field {{(workItem$ | async).workId}}/{{field.propertyId}}</div>\n    <div class='e5-content'>\n      <div><code>field={{field | json}} property={{property | json}}</code></div>\n\n      <!-- This code MUST be identical in all components -->\n      <e5core-ui-work-field-switch [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-switch>\n\n    </div>\n  </div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldBoxComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
E5coreUiWorkFieldBoxComponent.propDecorators = {
    workItem$: [{ type: Input }],
    field: [{ type: Input }],
    property: [{ type: Input }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeComponentBase {
    /**
     * @return {?}
     */
    get propertyId() {
        return (this.property) ? this.property.propertyId : '';
    }
    /**
     * @return {?}
     */
    get label() {
        if (this.property) {
            return this.property.label || this.property.placeholder || this.property.propertyId;
        }
        return ('');
    }
    /**
     * @return {?}
     */
    get description() {
        /** @type {?} */
        let text = '';
        if (this.field) {
            text = this.field.description;
        }
        return (text || '');
    }
    /**
     * @return {?}
     */
    get placeholder() {
        /** @type {?} */
        let text = '';
        if (this.property && !text) {
            text = this.property.placeholder;
        }
        return (text || '');
    }
    // You can override the readonly flag on all fields
    /**
     * @return {?}
     */
    get isReadOnly() {
        return (this.readonly || (this.field && this.field.isReadOnly));
    }
    /**
     * @param {?} formControl
     * @return {?}
     */
    updatePropertyValueOnChange(formControl) {
        this.workItem$.subscribe(wi => {
            /** @type {?} */
            let newProp = wi.properties.find(p => p.propertyId == this.propertyId);
            if (newProp && (newProp.resolvedValue !== formControl.value)) {
                formControl.setValue(newProp.resolvedValue);
            }
        });
    }
}
E5coreUiWorkFieldTypeComponentBase.propDecorators = {
    workItem$: [{ type: Input }],
    field: [{ type: Input, args: ['field',] }],
    property: [{ type: Input, args: ['property',] }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeInputBaseComponent extends E5coreUiWorkFieldTypeComponentBase {
    constructor() {
        super(...arguments);
        // Regex
        this.valueChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const validators = [];
        if (this.field && this.field.isRequired) {
            validators.push(Validators.required);
        }
        this.formControl = new FormControl(this.property.value, validators);
        this.formControl.markAsTouched();
        /** @type {?} */
        const error = this.getError();
        this.updatePropertyValueOnChange(this.formControl);
    }
    /**
     * @protected
     * @return {?}
     */
    getError() {
        /** @type {?} */
        let error = '';
        if (this.formControl.hasError('required')) {
            error = 'required';
        }
        return (error);
    }
    /**
     * @return {?}
     */
    get resolvedPattern() {
        return (this.pattern || this.property.pattern);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeValue($event) {
        this.valueChange.emit({ $event: $event, value: $event, error: this.getError() });
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    blur($event) {
        this.changeValue(this.formControl.value);
    }
}
E5coreUiWorkFieldTypeInputBaseComponent.propDecorators = {
    pattern: [{ type: Input }],
    valueChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeInputBoxComponent extends E5coreUiWorkFieldTypeInputBaseComponent {
}
E5coreUiWorkFieldTypeInputBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-input-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n    <div class='e5-content'>\n      <input type='input'\n        [(ngModel)]='property.value'\n        (change)='changeValue($event)'\n        [readonly]='isReadOnly'\n        class=\"form-control\"\n        id=\"{{propertyId}}\"\n        placeholder=\"{{placeholder}}\"\n        name=\"{{propertyId}}\"/>\n    </div>\n  </div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeInputMaterialComponent extends E5coreUiWorkFieldTypeInputBaseComponent {
}
E5coreUiWorkFieldTypeInputMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-input-material',
                template: "<mat-form-field class='e5-work-field-type-input'>\n  <input\n    (blur)=\"blur($event)\"\n    [readonly]='isReadOnly'\n    matInput\n    placeholder=\"{{label || placeholder}}\"\n    name=\"{{propertyId}}\"\n    type=\"text\"\n    pattern=\"{{resolvedPattern}}\"\n    [formControl]=\"formControl\"\n  />\n  <!--\n    [required]=\"field.isRequired\"\n\n  <mat-error *ngIf=\"formControl.hasError('required')\">\n      Please enter a value for {{placeholder}}.\n  </mat-error>\n  -->\n</mat-form-field>\n",
                styles: [".e5-work-field-type-input{width:100%}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeInputBootstrapComponent extends E5coreUiWorkFieldTypeInputBaseComponent {
}
E5coreUiWorkFieldTypeInputBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-input-bootstrap',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n    <div class='e5-content'>\n\n      <div class='form-group'>\n        <label for='exampleInputEmail1'>{{label}}</label>\n        <input type='input'\n          [(ngModel)]='property.value'\n          (change)='changeValue($event)'\n          [readonly]='isReadOnly'\n          class=\"form-control\"\n          id=\"{{propertyId}}\"\n          placeholder=\"{{placeholder}}\"\n          name=\"{{propertyId}}\"/>\n        <small class=\"form-text text-muted\">{{field.description}}</small>\n      </div>\n\n    </div>\n  </div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeIntegerBaseComponent extends E5coreUiWorkFieldTypeComponentBase {
    constructor() {
        super(...arguments);
        this.valueChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const validators = [];
        if (this.field && this.field.isRequired) {
            validators.push(Validators.required);
        }
        this.formControl = new FormControl(this.property.value, validators);
        this.formControl.markAsTouched();
        /** @type {?} */
        const error = this.getError();
        this.updatePropertyValueOnChange(this.formControl);
        // this.workItem$.subscribe(
        //   wi => {
        //     let newProp = wi.properties.find(p => p.propertyId == this.propertyId) ;
        //     if(newProp && (newProp.value !== this.formControl.value) && (newProp.value != undefined))  {
        //       this.formControl.setValue(newProp.value) ;
        //     }
        //   }
        // )
    }
    /**
     * @protected
     * @return {?}
     */
    getError() {
        /** @type {?} */
        let error = '';
        if (this.formControl.hasError('required')) {
            error = 'required';
        }
        return (error);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeValue($event) {
        /** @type {?} */
        let error = '';
        if (this.formControl.hasError('required')) {
            error = 'required';
        }
        this.valueChange.emit({ $event: $event, value: $event, error: error });
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    blur($event) {
        this.changeValue(this.formControl.value);
    }
}
E5coreUiWorkFieldTypeIntegerBaseComponent.propDecorators = {
    valueChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeIntegerBootstrapComponent extends E5coreUiWorkFieldTypeIntegerBaseComponent {
}
E5coreUiWorkFieldTypeIntegerBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-integer-bootstrap',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n    <div class='e5-content'>\n\n      <div class='form-group'>\n        <label for='exampleInputEmail1'>{{label}}</label>\n        <input type='number'\n          [(ngModel)]='property.value'\n          (change)='changeValue($event)'\n          [readonly]='isReadOnly'\n          class=\"form-control\"\n          id=\"{{propertyId}}\"\n          placeholder=\"{{placeholder}}\"\n          name=\"{{propertyId}}\"/>\n        <small class=\"form-text text-muted\">{{description}}</small>\n      </div>\n\n    </div>\n  </div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeIntegerMaterialComponent extends E5coreUiWorkFieldTypeIntegerBaseComponent {
}
E5coreUiWorkFieldTypeIntegerMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-integer-material',
                template: "<mat-form-field class='e5-work-field-type-input'>\n    <input\n        (blur)=\"blur($event)\"\n        [readonly]='isReadOnly'\n        matInput\n        placeholder=\"{{label || placeholder}}\"\n        name=\"{{propertyId}}\"\n        type=\"number\"\n        [required]=\"field.isRequired\"\n        [formControl]=\"formControl\"/>\n</mat-form-field>",
                styles: [".e5-work-field-type-input-integer{width:100%}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeIntegerBoxComponent extends E5coreUiWorkFieldTypeIntegerBaseComponent {
}
E5coreUiWorkFieldTypeIntegerBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-integer-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n  <div class='e5-content'>\n    <input type='number'\n      [(ngModel)]='property.value'\n      (change)='changeValue($event)'\n      [readonly]='isReadOnly'\n      class=\"form-control\"\n      id=\"{{propertyId}}\"\n      placeholder=\"{{placeholder}}\"\n      name=\"{{propertyId}}\"/>\n  </div>\n</div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeDateComponent extends E5coreUiWorkFieldTypeBase {
    /**
     * @param {?} style
     * @param {?} cd
     */
    constructor(style$$1, cd) {
        super();
        this.style = style$$1;
        this.cd = cd;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        this.workItem$.subscribe(wim => {
            if (this.property && this.property.value) {
                this.date = new Date(this.property.value);
                if (!(this.date instanceof Date)) {
                    this.date = undefined;
                }
            }
            else {
                this.date = undefined;
            }
            this.cd.markForCheck();
        });
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    valueChange($event) {
        this.dispatchPropertyChange(this.property.propertyId, $event.value.toJSON(), $event.error);
    }
}
E5coreUiWorkFieldTypeDateComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-date',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-work-field-type-date-box *ngSwitchCase='0' [workItem$]='workItem$' [date]='date' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-date-box>
    <e5core-ui-work-field-type-date-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [date]='date' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-date-bootstrap>
    <e5core-ui-work-field-type-date-material *ngSwitchCase='2' [workItem$]='workItem$' [date]='date' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-date-material>
  </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeDateComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: ChangeDetectorRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeDateBaseComponent extends E5coreUiWorkFieldTypeComponentBase {
    constructor() {
        super(...arguments);
        this.valueChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeValue($event) {
        this.valueChange.emit({ $event: $event, value: $event });
    }
}
E5coreUiWorkFieldTypeDateBaseComponent.propDecorators = {
    date: [{ type: Input }],
    valueChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeDateBoxComponent extends E5coreUiWorkFieldTypeDateBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkFieldTypeDateBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-date-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field-date-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n    <div class='e5-content'>\n      <input type='date'\n        [(ngModel)]='property.value'\n        (change)='changeValue($event)'\n        [readonly]='isReadOnly'\n        class=\"form-control\"\n        id=\"{{propertyId}}\"\n        placeholder=\"{{placeholder}}\"\n        name=\"{{propertyId}}\"/>\n    </div>\n  </div>",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeDateMaterialComponent extends E5coreUiWorkFieldTypeDateBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onMatChange($event) {
        this.valueChange.emit({ $event: $event, value: $event.value });
    }
}
E5coreUiWorkFieldTypeDateMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-date-material',
                template: "<!-- <div *ngIf=\"!field.inFindMode\"> -->\n  <mat-form-field>\n    <input\n      matInput\n      [(ngModel)]='date'\n      (dateInput)=\"onMatChange($event)\"\n      (dateChange)=\"onMatChange($event)\"\n      [readonly]='isReadOnly'\n      [disabled]='isReadOnly'\n      [matDatepicker]=\"picker1\"\n      placeholder=\"{{label || placeholder}}\"\n      name=\"{{propertyId}}\"\n      >\n    <mat-datepicker-toggle matSuffix [for]=\"picker1\"></mat-datepicker-toggle>\n    <mat-datepicker #picker1></mat-datepicker>\n  </mat-form-field>  \n<!-- </div> -->\n\n<!-- <div *ngIf=\"field.inFindMode\">\n  <mat-form-field>\n    <input\n      matInput\n      [(ngModel)]='date'\n      (dateInput)=\"onMatChange($event)\"\n      (dateChange)=\"onMatChange($event)\"\n      [readonly]='isReadOnly'\n      [disabled]='isReadOnly'\n      [matDatepicker]=\"picker2\"\n      placeholder=\"From {{label || placeholder}}\"\n      name=\"{{propertyId}}\"\n      >\n    <mat-datepicker-toggle matSuffix [for]=\"picker2\"></mat-datepicker-toggle>\n    <mat-datepicker #picker2></mat-datepicker>\n  </mat-form-field>  \n  &nbsp;\n  <mat-form-field>\n    <input\n      matInput\n      [(ngModel)]='date_2'\n      (dateInput)=\"onMatChange($event)\"\n      (dateChange)=\"onMatChange($event)\"\n      [readonly]='isReadOnly'\n      [disabled]='isReadOnly'\n      [matDatepicker]=\"picker3\"\n      placeholder=\"To {{label || placeholder}}\"\n      name=\"{{propertyId}}_2\"\n      >\n    <mat-datepicker-toggle matSuffix [for]=\"picker3\"></mat-datepicker-toggle>\n    <mat-datepicker #picker3></mat-datepicker>\n  </mat-form-field> \n</div> -->\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeDateBootstrapComponent extends E5coreUiWorkFieldTypeDateBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkFieldTypeDateBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-date-bootstrap',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <input type='date'\n    [(ngModel)]='property.value'\n    (change)='changeValue($event)'\n    [readonly]='isReadOnly'\n    class=\"form-control\"\n    id=\"{{propertyId}}\"\n    placeholder=\"{{placeholder}}\"\n    name=\"{{propertyId}}\"/>\n</div>",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeTextComponent extends E5coreUiWorkFieldTypeBase {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        super();
        this.style = style$$1;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    valueChange($event) {
        this.dispatchPropertyChange(this.property.propertyId, $event.value, $event.error);
    }
}
E5coreUiWorkFieldTypeTextComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-text',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-work-field-type-text-box *ngSwitchCase='0' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-text-box>
    <e5core-ui-work-field-type-text-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-text-bootstrap>
    <e5core-ui-work-field-type-text-material *ngSwitchCase='2' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-text-material>
  </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeTextComponent.ctorParameters = () => [
    { type: UiStyleService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeTextBaseComponent extends E5coreUiWorkFieldTypeComponentBase {
    constructor() {
        super(...arguments);
        this.valueChange = new EventEmitter();
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeValue($event) {
        this.valueChange.emit({ $event: $event, value: $event });
    }
}
E5coreUiWorkFieldTypeTextBaseComponent.propDecorators = {
    valueChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeTextBoxComponent extends E5coreUiWorkFieldTypeTextBaseComponent {
}
E5coreUiWorkFieldTypeTextBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-text-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n    <div class='e5-content'>\n      <textarea type='input'\n        [(ngModel)]='property.value'\n        (change)='changeValue($event)'\n        [readonly]='isReadOnly'\n        class=\"form-control\"\n        id=\"{{propertyId}}\"\n        placeholder=\"{{placeholder}}\"\n        name=\"{{propertyId}}\" >\n      </textarea>\n    </div>\n  </div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeTextMaterialComponent extends E5coreUiWorkFieldTypeTextBaseComponent {
}
E5coreUiWorkFieldTypeTextMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-text-material',
                template: "<mat-form-field class='e5-work-field-type-test'>\n  <textarea\n    (blur)=\"changeValue($event)\"\n    [ngModel]=\"property.value\"\n    [readonly]='isReadOnly'\n    matInput\n    placeholder=\"{{label || placeholder}}\"\n    name=\"{{propertyId}}\">\n  </textarea>\n</mat-form-field>\n",
                styles: [".e5-work-field-type-test{width:100%}.e5-work-field-type-test textarea{width:100%;height:60pt}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeTextBootstrapComponent extends E5coreUiWorkFieldTypeTextBaseComponent {
}
E5coreUiWorkFieldTypeTextBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-text-bootstrap',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n    <div class='e5-content'>\n\n      <div class='form-group'>\n        <label for='{{propertyId}}'>{{label}}</label>\n        <textarea type='input'\n          [(ngModel)]='property.value'\n          (change)='changeValue($event)'\n          [readonly]='isReadOnly'\n          class=\"form-control\"\n          id=\"{{propertyId}}\"\n          placeholder=\"{{placeholder}}\"\n          name=\"{{propertyId}}\" >\n        </textarea>\n        <small id=\"{{propertyId}}\" class=\"form-text text-muted\">{{description}}</small>\n      </div>\n\n    </div>\n  </div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeUserComponent extends E5coreUiWorkFieldTypeBase {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        super();
        this.style = style$$1;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    valueChange($event) {
        this.dispatchPropertyChange(this.property.propertyId, $event.value, $event.error);
    }
}
E5coreUiWorkFieldTypeUserComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-user',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-work-field-type-user-box *ngSwitchCase='0' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' ></e5core-ui-work-field-type-user-box>
    <e5core-ui-work-field-type-user-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' ></e5core-ui-work-field-type-user-bootstrap>
    <e5core-ui-work-field-type-user-material *ngSwitchCase='2' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' ></e5core-ui-work-field-type-user-material>
  </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeUserComponent.ctorParameters = () => [
    { type: UiStyleService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeUserBoxComponent extends E5coreUiWorkFieldTypeTextBaseComponent {
}
E5coreUiWorkFieldTypeUserBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-user-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field-type-user {{(workItem$ | async).workId}}/{{propertyId}}</div>\n    <div class='e5-content'>\n\n        <select placeholder=\"Not Implemented\">\n            <option [value]=\"1\">one</option>\n            <option [value]=\"2\">two</option>\n            <option [value]=\"3\">three</option>\n            <option [value]=\"4\">four</option>\n            <option [value]=\"5\">five</option>\n        </select>\n\n    </div>\n  </div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeUserMaterialComponent extends E5coreUiWorkFieldTypeTextBaseComponent {
}
E5coreUiWorkFieldTypeUserMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-user-material',
                template: "<mat-form-field>\n  <mat-select placeholder=\"{{label || placeholder}}\">\n    <mat-option [value]=\"1\">one</mat-option>\n    <mat-option [value]=\"2\">two</mat-option>\n    <mat-option [value]=\"3\">three</mat-option>\n    <mat-option [value]=\"4\">four</mat-option>\n    <mat-option [value]=\"5\">five</mat-option>\n  </mat-select>\n</mat-form-field>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeUserBootstrapComponent extends E5coreUiWorkFieldTypeTextBaseComponent {
}
E5coreUiWorkFieldTypeUserBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-user-bootstrap',
                template: "<select placeholder=\"Not Implemented\">\n    <option [value]=\"1\">one</option>\n    <option [value]=\"2\">two</option>\n    <option [value]=\"3\">three</option>\n    <option [value]=\"4\">four</option>\n    <option [value]=\"5\">five</option>\n</select>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldSwitchComponent {
    constructor() {
        this.RegexGuid = '^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-5][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$';
        this.RegexCurrency = '^\\$?([0-9]{1,3},([0-9]{3},)*[0-9]{3}|[0-9]+)(.[0-9][0-9])?$';
        this.RegexDecimal = '^\\d*\\.?\\d*$';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkFieldSwitchComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-switch',
                template: "<div *ngIf='workItem$' [ngSwitch]='property.fieldDataType'>\n  <e5core-ui-work-field-type-input *ngSwitchCase='1' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-input>\n  <e5core-ui-work-field-type-date *ngSwitchCase='2' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-date>\n  <e5core-ui-work-field-type-text *ngSwitchCase='3' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-text>\n  <e5core-ui-work-field-type-list *ngSwitchCase='4' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-list>\n  <e5core-ui-work-field-type-input *ngSwitchCase='5' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='RegexGuid' [readonly]='readonly'></e5core-ui-work-field-type-input> <!-- GUID -->\n  <e5core-ui-work-field-type-text *ngSwitchCase='6' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-text> <!-- CaseNote -->\n  <e5core-ui-work-field-type-list *ngSwitchCase='7' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-list>\n  <!-- <e5core-ui-work-field-type-lookup *ngSwitchCase='8' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-lookup> Lookup -->\n  <e5core-ui-work-field-type-integer *ngSwitchCase='9' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-integer>\n  <e5core-ui-work-field-type-currency *ngSwitchCase='10' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='RegexCurrency' [readonly]='readonly'></e5core-ui-work-field-type-currency> <!-- Currency -->\n  <e5core-ui-work-field-type-date *ngSwitchCase='11' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-date>\n  <e5core-ui-work-field-type-integer *ngSwitchCase='12' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-integer> <!-- reference -->\n  <!-- <e5core-ui-work-field-type-sitegroup *ngSwitchCase='13' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-sitegroup> -->\n  <e5core-ui-work-field-type-checkbox *ngSwitchCase='14' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-checkbox>\n  <!-- <e5core-ui-work-field-type-form *ngSwitchCase='15' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-form> : NOT SUPPORTED -->\n  <!-- <e5core-ui-work-field-type-link *ngSwitchCase='16' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-link> -->\n  <!-- <e5core-ui-work-field-type-grid *ngSwitchCase='17' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-grid> -->\n  <e5core-ui-work-field-type-input *ngSwitchCase='18' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='RegexDecimal' [readonly]='readonly'></e5core-ui-work-field-type-input>\n  <!-- <e5core-ui-work-field-type-multivaluelist *ngSwitchCase='19' [workItem$]='workItem$' [field]='field' [property]='property' [readonly]='readonly'></e5core-ui-work-field-type-multivaluelist> -->\n</div>\n\n<!--\n  Input = 1,\n  Date = 2,\n  Text = 3,\n  User = 4,\n  GUID = 5,\n  CaseNote = 6,\n  List = 7,\n  Lookup = 8,\n  Integer = 9,\n  Currency = 10,\n  DateTime = 11,\n  Reference = 12,\n  SiteGroup = 13,\n  Checkbox = 14,\n  Form = 15, // N/A\n  Link = 16,\n  Grid = 17,\n  Decimal = 18,\n  MultiValueList = 19\n-->"
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldSwitchComponent.ctorParameters = () => [];
E5coreUiWorkFieldSwitchComponent.propDecorators = {
    workItem$: [{ type: Input }],
    field: [{ type: Input }],
    property: [{ type: Input }],
    readonly: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCheckboxComponent extends E5coreUiWorkFieldTypeBase {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        super();
        this.style = style$$1;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    valueChange($event) {
        if (typeof ($event.value) === 'undefined') {
            return;
        } // prevents and odd <input> problem when event arrives twice
        this.dispatchPropertyChange(this.property.propertyId, $event.value ? 'True' : 'False', $event.error);
    }
}
E5coreUiWorkFieldTypeCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-checkbox',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-work-field-type-checkbox-box *ngSwitchCase='0' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-checkbox-box>
    <e5core-ui-work-field-type-checkbox-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-checkbox-bootstrap>
    <e5core-ui-work-field-type-checkbox-material *ngSwitchCase='2' [workItem$]='workItem$' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-checkbox-material>
  </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeCheckboxComponent.ctorParameters = () => [
    { type: UiStyleService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCheckboxBaseComponent extends E5coreUiWorkFieldTypeComponentBase {
    constructor() {
        super(...arguments);
        this.valueChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const validators = [];
        if (this.field && this.field.isRequired) {
            validators.push(Validators.required);
        }
        // Convert e5 "", "True" and "False" to angular numeric.
        /** @type {?} */
        const state$$1 = (this.property && this.property.value && this.property.value.toLowerCase() === 'true');
        this.formControl = new FormControl({
            value: state$$1,
            disabled: this.field.isReadOnly
        }, validators);
        this.formControl.markAsTouched();
        /** @type {?} */
        const error = this.getError();
        this.workItem$.subscribe(wi => {
            if (this.property) {
                /** @type {?} */
                let checked = this.property.value && this.property.value.toLowerCase() == "true";
                if (this.formControl.value != checked)
                    this.formControl.setValue(checked);
            }
        });
    }
    /**
     * @protected
     * @return {?}
     */
    getError() {
        /** @type {?} */
        let error = '';
        if (this.formControl.hasError('required')) {
            error = 'required';
        }
        return (error);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeValue($event) {
        this.valueChange.emit({ $event: $event, value: this.formControl.value, error: this.getError() });
    }
}
E5coreUiWorkFieldTypeCheckboxBaseComponent.propDecorators = {
    valueChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCheckboxBoxComponent extends E5coreUiWorkFieldTypeCheckboxBaseComponent {
}
E5coreUiWorkFieldTypeCheckboxBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-checkbox-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n  <div class='e5-content'>\n    <input type='checkbox'\n      (ngModelChange)='changeValue($event)'\n      class=\"form-control\"\n      [formControl]=\"formControl\"\n      id=\"{{propertyId}}\"\n      name=\"{{propertyId}}\"/>{{placeholder}}\n  </div>\n</div>",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCheckboxBootstrapComponent extends E5coreUiWorkFieldTypeCheckboxBaseComponent {
}
E5coreUiWorkFieldTypeCheckboxBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-checkbox-bootstrap',
                template: "<div class='e5-component' *ngIf='workItem$'>\n    <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n    <div class='e5-content'>\n      <input type='checkbox'\n        (ngModelChange)='changeValue($event)'\n        class='form-check-input'\n        [formControl]=\"formControl\"\n        class=\"form-control\"\n        id=\"{{propertyId}}\"\n        name=\"{{propertyId}}\"/>{{placeholder}}\n    </div>\n  </div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCheckboxMaterialComponent extends E5coreUiWorkFieldTypeCheckboxBaseComponent {
}
E5coreUiWorkFieldTypeCheckboxMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-checkbox-material',
                template: "<mat-checkbox\n  (ngModelChange)=\"changeValue($event)\"\n  name=\"{{propertyId}}\"\n  [disabled]='isReadOnly'\n  [formControl]=\"formControl\">{{label || placeholder}}</mat-checkbox>\n<!--\n  [required]=\"field.isRequired\"\n\n<mat-error *ngIf=\"formControl.hasError('required')\">\n    Please enter a value for {{placeholder}}.\n</mat-error>\n-->\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CachedListSearchService {
    /**
     * @param {?} listService
     */
    constructor(listService) {
        this.listService = listService;
        this.cache = [];
    }
    /**
     * @param {?} listId
     * @param {?} options
     * @return {?}
     */
    search(listId, options) {
        /** @type {?} */
        let subject$ = new BehaviorSubject([]);
        /** @type {?} */
        var cacheKey = listId;
        if (options !== undefined)
            cacheKey = cacheKey + options.parentListItemId;
        /** @type {?} */
        var cachedItem = this.cache.filter(f => f.key == cacheKey);
        if (cachedItem.length > 0) {
            subject$.next(cachedItem[0].value);
            return (subject$);
        }
        this.listService.search(listId, options).subscribe(list => {
            // TODO : Add "field.isSystemProperty"
            if (listId != "Category1_Id" && listId != "Category2_Id" && listId != "Category3_Id" && listId != "Status_Id") {
                list.unshift((/** @type {?} */ ({ id: "-2", code: "", label: "(no value)" })));
                list.unshift((/** @type {?} */ ({ id: "-1", code: "", label: "(any value)" })));
            }
            list.unshift((/** @type {?} */ ({ id: "0", code: "", label: "" })));
            this.cache.push({ key: cacheKey, value: list });
            subject$.next(list);
        }, error => {
            console.error(error);
            subject$.error(error);
        });
        return (subject$);
    }
}
CachedListSearchService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
CachedListSearchService.ctorParameters = () => [
    { type: ListSearchService }
];
/** @nocollapse */ CachedListSearchService.ngInjectableDef = defineInjectable({ factory: function CachedListSearchService_Factory() { return new CachedListSearchService(inject(ListSearchService)); }, token: CachedListSearchService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/*
 *
 *	When a list is in "Find" view, it can have the following values.
 *	"" - [0]
 *	"(any value)" - [-1]
 *	"(no value)" - [-2]
 *	"VALUE" - [>0]
 */
class E5coreUiWorkFieldTypeListComponent extends E5coreUiWorkFieldTypeBase {
    /**
     * @param {?} style
     * @param {?} listService
     */
    constructor(style$$1, listService) {
        super();
        this.style = style$$1;
        this.listService = listService;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    valueChange($event) {
        this.dispatchPropertyChange(this.property.propertyId, $event.id.toString(), $event.error);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        this.workItem$.subscribe(wim => {
            if (this.property && (this.property.listId || this.property.propertyId)) {
                // If the listId is 0 then we can quiry the list using the propertyId. This is to
                // handle the situation for System Lists list Status_Id, Category1_Id, etc that
                // do not have a coresponding ListId.
                /** @type {?} */
                let listId = this.property.listId || this.property.propertyId;
                // If the list has a parentListId or a parentPropertyId then we need to find the
                // selected value of that property, so that we know how to filter this property.
                /** @type {?} */
                let parentProperty;
                if (this.property.parentListId) {
                    parentProperty = wim.properties.find(p => p.listId == this.property.parentListId);
                }
                if (!parentProperty && this.property.parentPropertyId) {
                    parentProperty = wim.properties.find(p => p.propertyId == this.property.parentPropertyId);
                }
                /** @type {?} */
                let property = wim.properties.find(p => p.propertyId == this.property.propertyId);
                this.loadList(listId, parentProperty, property);
            }
        });
    }
    /**
     * @private
     * @param {?} listId
     * @param {?} parent
     * @param {?} property
     * @return {?}
     */
    loadList(listId, parent, property) {
        /** @type {?} */
        let options;
        if (parent) {
            // The parent property is on the page, however, if it's empty then this list should also be empty
            if (!parent.value || parent.value == "0") {
                this.clearList();
                return;
            }
            options = { parentListItemId: parent.value };
        }
        this.listService.search(listId, options).subscribe(list => {
            this.list = list || [];
            if (list.length > 0 && this.field.inFindMode) {
                /** @type {?} */
                let currentSelected = property.value;
                /** @type {?} */
                let inList = this.list.find(i => i.id == currentSelected) != undefined;
                this.selected = (currentSelected == "0" || !inList) ? undefined : currentSelected;
            }
            else {
                this.clearList();
            }
        }, error => this.clearList());
    }
    /**
     * @private
     * @return {?}
     */
    clearList() {
        this.list = [];
        this.selected = undefined;
    }
}
E5coreUiWorkFieldTypeListComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-list',
                template: `
	<span [ngSwitch]="style.current()">
		<e5core-ui-work-field-type-list-box *ngSwitchCase='0' [workItem$]='workItem$' [list]='list' [selected]='selected' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-list-box>
		<e5core-ui-work-field-type-list-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [list]='list' [selected]='selected' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-list-bootstrap>
		<e5core-ui-work-field-type-list-material *ngSwitchCase='2' [workItem$]='workItem$' [list]='list' [selected]='selected' [field]='field' [property]='property' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-list-material>
	</span>`
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeListComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: CachedListSearchService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeListBaseComponent extends E5coreUiWorkFieldTypeComponentBase {
    constructor() {
        super(...arguments);
        this.valueChange = new EventEmitter();
    }
    //formControl: FormControl ;
    // selected : any ;
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @protected
     * @return {?}
     */
    getError() {
        /** @type {?} */
        let error = '';
        // if (this.formControl.hasError('required')) {
        // 	error = 'required' ;
        // }
        return (error);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeValue($event) {
        /** @type {?} */
        let error = '';
        // if (this.formControl.hasError('required')) {
        // 	error = 'required' ;
        // }
        /** @type {?} */
        let event = (/** @type {?} */ ({
            id: $event.value,
            error: error
        }));
        this.valueChange.emit(event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    blur($event) {
        //this.changeValue(this.formControl.value) ;
    }
}
E5coreUiWorkFieldTypeListBaseComponent.propDecorators = {
    valueChange: [{ type: Output }],
    list: [{ type: Input }],
    selected: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeListMaterialComponent extends E5coreUiWorkFieldTypeListBaseComponent {
}
E5coreUiWorkFieldTypeListMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-list-material',
                template: "<mat-form-field class='e5-work-field-type-list' *ngIf=\"isReadOnly\">\n  <input\n    [readonly]='true'\n    matInput\n    placeholder=\"{{label || placeholder}}\"\n    name=\"{{propertyId}}\"\n    type=\"text\"\n    [(ngModel)]=\"property.resolvedValue\"\n  />\n</mat-form-field>\n<mat-form-field class='e5-work-field-type-list' *ngIf=\"!isReadOnly\">\n  <mat-select [(ngModel)]=\"selected\" placeholder=\"{{label || placeholder}}\" (selectionChange)=\"changeValue($event)\">    \n    <!-- <mat-option *ngIf=\"!list || list.length == 0\" [value]=\"0\">Empty</mat-option> -->\n    <mat-option *ngFor=\"let item of list\" [value]=\"item.id\">{{item.label}}</mat-option>\n  </mat-select>\n</mat-form-field>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeListBoxComponent extends E5coreUiWorkFieldTypeListBaseComponent {
}
E5coreUiWorkFieldTypeListBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-list-box',
                template: "<p>\n  e5core-ui-work-field-type-list-box works!\n</p>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeListBootstrapComponent extends E5coreUiWorkFieldTypeListBaseComponent {
}
E5coreUiWorkFieldTypeListBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-list-bootstrap',
                template: "<p>\n  e5core-ui-work-field-type-list-bootstrap works!\n</p>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCurrencyComponent extends E5coreUiWorkFieldTypeBase {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        super();
        this.style = style$$1;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    valueChange($event) {
        this.dispatchPropertyChange(this.property.propertyId, ($event.value || "").toString(), $event.error);
        return;
    }
}
E5coreUiWorkFieldTypeCurrencyComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-currency',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-work-field-type-currency-box *ngSwitchCase='0' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='pattern' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-currency-box>
    <e5core-ui-work-field-type-currency-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='pattern' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-currency-bootstrap>
    <e5core-ui-work-field-type-currency-material *ngSwitchCase='2' [workItem$]='workItem$' [field]='field' [property]='property' [pattern]='pattern' (valueChange)='valueChange($event)' [readonly]='readonly'></e5core-ui-work-field-type-currency-material>
  </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeCurrencyComponent.ctorParameters = () => [
    { type: UiStyleService }
];
E5coreUiWorkFieldTypeCurrencyComponent.propDecorators = {
    pattern: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCurrencyBaseComponent extends E5coreUiWorkFieldTypeComponentBase {
    /**
     * @param {?} cp
     */
    constructor(cp) {
        super();
        this.cp = cp;
        // Regex
        this.valueChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const validators = [];
        if (this.field && this.field.isRequired) {
            validators.push(Validators.required);
        }
        /** @type {?} */
        var formatted = this.cp.transform(this.property.value, "USD", "", "1.2-2");
        this.formControl = new FormControl(formatted, validators);
        this.formControl.markAsTouched();
        /** @type {?} */
        const error = this.getError();
        this.updatePropertyValueOnChange(this.formControl);
    }
    /**
     * @protected
     * @return {?}
     */
    getError() {
        /** @type {?} */
        let error = '';
        if (this.formControl.hasError('required')) {
            error = 'required';
        }
        return (error);
    }
    /**
     * @return {?}
     */
    get resolvedPattern() {
        return (this.pattern || this.property.pattern);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeValue($event) {
        this.valueChange.emit({ $event: $event, value: $event, error: this.getError() });
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    blur($event) {
        this.changeValue(this.formControl.value);
    }
    /**
     * @private
     * @return {?}
     */
    formatToCurrency() {
        return "";
    }
}
E5coreUiWorkFieldTypeCurrencyBaseComponent.propDecorators = {
    pattern: [{ type: Input }],
    valueChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCurrencyBootstrapComponent extends E5coreUiWorkFieldTypeCurrencyBaseComponent {
    /**
     * @param {?} cp
     */
    constructor(cp) {
        super(cp);
    }
}
E5coreUiWorkFieldTypeCurrencyBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-currency-bootstrap',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n  <div class='e5-content'>\n\n    <div class='form-group'>\n      <label for='exampleInputEmail1'>{{label}}</label>\n      <input type='number'\n        [(ngModel)]='property.value'\n        (change)='changeValue($event)'\n        [readonly]='isReadOnly'\n        class=\"form-control\"\n        id=\"{{propertyId}}\"\n        placeholder=\"{{placeholder}}\"\n        name=\"{{propertyId}}\"/>\n      <small class=\"form-text text-muted\">{{description}}</small>\n    </div>\n\n  </div>\n</div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeCurrencyBootstrapComponent.ctorParameters = () => [
    { type: CurrencyPipe }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCurrencyBoxComponent extends E5coreUiWorkFieldTypeCurrencyBaseComponent {
    /**
     * @param {?} cp
     */
    constructor(cp) {
        super(cp);
    }
}
E5coreUiWorkFieldTypeCurrencyBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-currency-box',
                template: "<div class='e5-component' *ngIf='workItem$'>\n  <div class='e5-title'>e5core-ui-work-field-type-input {{(workItem$ | async).workId}}/{{propertyId}}</div>\n  <div class='e5-content'>\n    <input type='number'\n      [(ngModel)]='property.value'\n      (change)='changeValue($event)'\n      [readonly]='isReadOnly'\n      class=\"form-control\"\n      id=\"{{propertyId}}\"\n      placeholder=\"{{placeholder}}\"\n      name=\"{{propertyId}}\"/>\n  </div>\n</div>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeCurrencyBoxComponent.ctorParameters = () => [
    { type: CurrencyPipe }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkFieldTypeCurrencyMaterialComponent extends E5coreUiWorkFieldTypeCurrencyBaseComponent {
    /**
     * @param {?} cp
     */
    constructor(cp) {
        super(cp);
    }
}
E5coreUiWorkFieldTypeCurrencyMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-field-type-currency-material',
                template: "<mat-form-field class='e5-work-field-type-input'>\n  <input\n    (ngModelChange)=\"changeValue($event)\"\n    (blur)=\"blur($event)\"\n    [readonly]='isReadOnly'\n    matInput\n    placeholder=\"{{label || placeholder}}\"\n    name=\"{{propertyId}}\"\n    type=\"string\"\n    [required]=\"field.isRequired\"\n    [formControl]=\"formControl\"/>\n  <span matPrefix>$&nbsp;</span>\n</mat-form-field>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiWorkFieldTypeCurrencyMaterialComponent.ctorParameters = () => [
    { type: CurrencyPipe }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkHistoryComponent {
    /**
     * @param {?} style
     * @param {?} configuration
     */
    constructor(style$$1, configuration) {
        this.style = style$$1;
        this.configuration = configuration;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-history [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        this.workItem$.subscribe(w => {
            if (this.workId != w.workId) {
                this.updateData();
            }
        });
    }
    /**
     * @private
     * @return {?}
     */
    updateData() {
    }
}
E5coreUiWorkHistoryComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-history',
                template: `
  <span *ngIf="workItem$" [ngSwitch]="style.current()">
    <e5core-ui-work-history-box *ngSwitchCase='0' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes'></e5core-ui-work-history-box>
    <e5core-ui-work-history-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes'></e5core-ui-work-history-bootstrap>
    <e5core-ui-work-history-material *ngSwitchCase='2' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes'></e5core-ui-work-history-material>
  </span>
  <div *ngIf="!(workItem$)" class="e5core-component-error">&lt;e5core-ui-work-history&gt; [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkHistoryComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: E5ConfigurationService }
];
E5coreUiWorkHistoryComponent.propDecorators = {
    workItem$: [{ type: Input }],
    readonly: [{ type: Input }],
    pagesizes: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkHistoryBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkHistoryBaseComponent.propDecorators = {
    workItem$: [{ type: Input }],
    readonly: [{ type: Input }],
    pagesizes: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkHistoryFrameModel {
}
class WorkHistoryDtoModel {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HistoryOdataService {
    /**
     * @param {?} http
     * @param {?} config
     */
    constructor(http, config) {
        this.http = http;
        this.config = config;
    }
    // apiServer: {
    //   baseUrl: 'http://vlane5dev2016:84',
    //   scope: 'test'
    // }
    // e.g. http://localhost:12661/site/odata/Ui/History/8b50f520-cac0-11e8-a32f-00155d2a720c?$count=true&$top=2&$skip=2
    //
    //   {
    //     "WorkId": "8b50f520-cac0-11e8-a32f-00155d2a720c",
    //     "Id": 618315,
    //     "EventDate": "2018-10-08T17:09:00.157+11:00",
    //     "EventId": 100,
    //     "EventName": "Changed Work Status",
    //     "EventUser": "LOCALDEV\\pfinch",
    //     "StatusId": 1,
    //     "StatusName": "Active",
    //     "Detail": "Launched",
    //     "Allocation": "1|1|1|0"
    //  },
    /**
     * @param {?} workId
     * @param {?} page
     * @param {?} pagesize
     * @param {?=} options
     * @return {?}
     */
    getHistory(workId, page, pagesize, options) {
        /** @type {?} */
        let subject$ = new BehaviorSubject(new WorkHistoryFrameModel());
        /** @type {?} */
        let baseUrl = this.config.settings.apiServer.baseUrl;
        /** @type {?} */
        let scope = this.config.settings.apiServer.scope;
        /** @type {?} */
        let offset = page * pagesize;
        /** @type {?} */
        let url = `${baseUrl}/${scope}/odata/Ui/History/${workId.toString()}?$count=true&$top=${pagesize || 10}&$skip=${offset || 0}`;
        // Append orderby
        if (options && options.orderby && options.orderby !== "")
            url += `&$orderby=${encodeURIComponent(options.orderby)}`;
        this.http.get(url).subscribe(result => {
            /** @type {?} */
            let whf = new WorkHistoryFrameModel();
            whf.count = result["@odata.count"];
            whf.page = page;
            whf.pagesize = pagesize;
            whf.data = result.value;
            subject$.next(whf);
        }, error => {
            console.error(error);
            subject$.error(error);
        });
        return (subject$);
    }
}
HistoryOdataService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
HistoryOdataService.ctorParameters = () => [
    { type: HttpClient },
    { type: E5ConfigurationService }
];
/** @nocollapse */ HistoryOdataService.ngInjectableDef = defineInjectable({ factory: function HistoryOdataService_Factory() { return new HistoryOdataService(inject(HttpClient), inject(E5ConfigurationService)); }, token: HistoryOdataService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OdataMatTableDataSource$1 extends DataSource {
    /**
     * @param {?} workId
     * @param {?} historyService
     */
    constructor(workId, historyService) {
        super();
        this.workId = workId;
        this.historyService = historyService;
        this.subject$ = new BehaviorSubject([]);
        this.orderby = { active: "EventDate", direction: "desc" };
        this.loading$ = new BehaviorSubject(false);
    }
    /**
     * @param {?} paginator
     * @return {?}
     */
    set paginator(paginator) {
        this._paginator = paginator;
        this._paginator.page.subscribe(x => {
            // {"previousPageIndex":0,"pageIndex":1,"pageSize":10,"length":100}
            this.update();
        });
    }
    /**
     * @param {?} sort
     * @return {?}
     */
    set sort(sort) {
        this._sort = sort;
        this._sort.sortChange.subscribe(ob => {
            // {active: "detail", direction: ""}
            this.orderby = ob;
            this.update();
        });
    }
    /**
     * @param {?} id
     * @return {?}
     */
    setWorkId(id) {
        // if(id !== this.workId) {
        this.workId = id;
        this.update();
        // }
    }
    /**
     * @return {?}
     */
    get loadingEvents() {
        return this.loading$;
    }
    /**
     * @return {?}
     */
    update() {
        if (!this.workId || !Guid.isGuid(this.workId) || this.workId.toString() === Guid.EMPTY) {
            this.subject$.next([]);
            return;
        }
        /** @type {?} */
        let page = (this._paginator) ? this._paginator.pageIndex : 0;
        /** @type {?} */
        let pagesize = (this._paginator) ? this._paginator.pageSize : 10;
        /** @type {?} */
        let options = {};
        // Setup orderby option if it's available
        /** @type {?} */
        let orderby = this.orderby;
        if (orderby && orderby.direction && orderby.active) {
            options.orderby = `${orderby.active} ${orderby.direction}`;
        }
        // Go get the data
        this.loading$.next(true);
        this.historyService.getHistory(this.workId, page || 0, pagesize || 10, options).subscribe(frame => {
            this._paginator.length = frame.count;
            this.subject$.next(frame.data);
            this.loading$.next(false);
        }, error => {
            console.error(error);
            this.loading$.next(false);
        });
    }
    /**
     * @return {?}
     */
    connect() {
        this.update();
        return (this.subject$);
    }
    /**
     * @return {?}
     */
    disconnect() { }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkHistoryMaterialComponent extends E5coreUiWorkHistoryBaseComponent {
    /**
     * @param {?} history
     */
    constructor(history) {
        super();
        this.history = history;
        this.displayedColumns = ['EventDate', 'EventUser', 'EventName', 'StatusName', 'Detail'];
        this.isLoading = true;
        this.length = 0;
        this.pageSize = 10;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.pageSizeOptions = (this.pagesizes && this.pagesizes.length > 0) ? this.pagesizes : [5, 10, 25, 50];
        this.dataSource = new OdataMatTableDataSource$1(Guid.EMPTY, this.history); // this.history.getHistory(id, 0, 10) ;
        this.dataSource.sort = this.sort;
        this.dataSource.paginator = this.paginator;
        this.dataSource.loadingEvents.subscribe(isLoading => {
            this.isLoading = isLoading;
        });
        this.workItem$.subscribe(wim => {
            this.dataSource.setWorkId(wim.workId);
        });
    }
    /**
     * @param {?} setPageSizeOptionsInput
     * @return {?}
     */
    setPageSizeOptions(setPageSizeOptionsInput) {
        this.pageSizeOptions = setPageSizeOptionsInput.split(',').map(str => +str);
    }
}
E5coreUiWorkHistoryMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-history-material',
                template: "<div class=\"e5core-ui-work-history\">\n\n    <div *ngIf=\"isLoading\" class=\"mat-spinner-holder\" align=\"center\">\n        <mat-spinner></mat-spinner>\n    </div>\n\n    <table mat-table [dataSource]=\"dataSource\" matSort class=\"e5core-ui-work-history\">\n\n      <!-- Date Date -->\n      <ng-container matColumnDef=\"EventDate\">\n        <th mat-header-cell *matHeaderCellDef mat-sort-header> Date </th>\n        <td mat-cell *matCellDef=\"let element\"> {{element.EventDate | date : 'd LLL yyyy h:mm aa' }} </td> <!-- https://angular.io/api/common/DatePipe -->\n      </ng-container>\n\n      <!-- Name User -->\n      <ng-container matColumnDef=\"EventUser\">\n        <th mat-header-cell *matHeaderCellDef mat-sort-header> User </th>\n        <td mat-cell *matCellDef=\"let element\"> {{element.EventUser}} </td>\n      </ng-container>\n\n      <!-- Weight Event -->\n      <ng-container matColumnDef=\"EventName\">\n        <th mat-header-cell *matHeaderCellDef mat-sort-header> Event </th>\n        <td mat-cell *matCellDef=\"let element\"> {{element.EventName}} </td>\n      </ng-container>\n\n      <!-- Symbol Status -->\n      <ng-container matColumnDef=\"StatusName\">\n        <th mat-header-cell *matHeaderCellDef mat-sort-header> Status </th>\n        <td mat-cell *matCellDef=\"let element\"> {{element.StatusName}} </td>\n      </ng-container>\n\n      <!-- Symbol Details -->\n      <ng-container matColumnDef=\"Detail\">\n          <th mat-header-cell *matHeaderCellDef mat-sort-header> Detail </th>\n          <td mat-cell *matCellDef=\"let element\"> {{element.Detail}} </td>\n        </ng-container>\n\n      <tr mat-header-row *matHeaderRowDef=\"displayedColumns\"></tr>\n      <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\n    </table>\n\n    <mat-paginator [length]=\"length\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"pageSizeOptions\" (page)=\"pageEvent = $event\" showFirstLastButtons></mat-paginator>\n</div>\n",
                styles: ["table.e5core-ui-work-history{width:100%}table.e5core-ui-work-history tr th:nth-child(1){width:150pt}table.e5core-ui-work-history tr th:nth-child(2),table.e5core-ui-work-history tr th:nth-child(3){width:120pt}table.e5core-ui-work-history tr th:nth-child(4){width:80pt}.e5core-ui-work-history .mat-spinner-holder{width:100%;padding:20pt;position:relative;top:30px;height:1px}.e5core-ui-work-history .mat-paginator{margin-top:0;background:0 0}"]
            }] }
];
/** @nocollapse */
E5coreUiWorkHistoryMaterialComponent.ctorParameters = () => [
    { type: HistoryOdataService }
];
E5coreUiWorkHistoryMaterialComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    paginator: [{ type: ViewChild, args: [MatPaginator,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkHistoryBoxComponent extends E5coreUiWorkHistoryBaseComponent {
}
E5coreUiWorkHistoryBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-history-box',
                template: "<p>\n  e5core-ui-work-history-box not implement!\n</p>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkHistoryBootstrapComponent extends E5coreUiWorkHistoryBaseComponent {
}
E5coreUiWorkHistoryBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-history-bootstrap',
                template: "<p>\n  e5core-ui-work-history-bootstrap not implemented!\n</p>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkCasenotesComponent {
    /**
     * @param {?} style
     * @param {?} configuration
     */
    constructor(style$$1, configuration) {
        this.style = style$$1;
        this.configuration = configuration;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-work-casenotes [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        this.workItem$.subscribe(w => {
            if (this.workId != w.workId) {
                this.updateData();
            }
        });
    }
    /**
     * @private
     * @return {?}
     */
    updateData() {
    }
}
E5coreUiWorkCasenotesComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-casenotes',
                template: `
  <span *ngIf="workItem$" [ngSwitch]="style.current()">
    <e5core-ui-work-casenotes-box *ngSwitchCase='0' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes'></e5core-ui-work-casenotes-box>
    <e5core-ui-work-casenotes-bootstrap *ngSwitchCase='1' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes'></e5core-ui-work-casenotes-bootstrap>
    <e5core-ui-work-casenotes-material *ngSwitchCase='2' [workItem$]='workItem$' [readonly]='readonly' [pagesizes]='pagesizes'></e5core-ui-work-casenotes-material>
  </span>
  <div *ngIf="!(workItem$)" class="e5core-component-error">&lt;e5core-ui-work-casenotes&gt; [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkCasenotesComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: E5ConfigurationService }
];
E5coreUiWorkCasenotesComponent.propDecorators = {
    workItem$: [{ type: Input }],
    readonly: [{ type: Input }],
    pagesizes: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkCasenotesBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiWorkCasenotesBaseComponent.propDecorators = {
    workItem$: [{ type: Input }],
    readonly: [{ type: Input }],
    pagesizes: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkCasenotesBootstrapComponent extends E5coreUiWorkCasenotesBaseComponent {
}
E5coreUiWorkCasenotesBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-casenotes-bootstrap',
                template: "<p>\n  e5core-ui-work-casenotes-bootstrap not implemented!\n</p>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkCasenotesFrameModel {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CasenotesOdataService {
    /**
     * @param {?} http
     * @param {?} config
     */
    constructor(http, config) {
        this.http = http;
        this.config = config;
    }
    // apiServer: {
    //   baseUrl: 'http://vlane5dev2016:84',
    //   scope: 'test'
    // }
    // e.g. http://localhost:12661/site/odata/Ui/Casenotes/8b50f520-cac0-11e8-a32f-00155d2a720c?$count=true&$top=2&$skip=2
    //
    //   {
    //     "WorkId": "8b50f520-cac0-11e8-a32f-00155d2a720c",
    //     "Id": 618315,
    //     "EventDate": "2018-10-08T17:09:00.157+11:00",
    //     "EventId": 100,
    //     "EventName": "Changed Work Status",
    //     "EventUser": "LOCALDEV\\pfinch",
    //     "StatusId": 1,
    //     "StatusName": "Active",
    //     "Detail": "Launched",
    //     "Allocation": "1|1|1|0"
    //  },
    /**
     * @param {?} workId
     * @param {?} page
     * @param {?} pagesize
     * @param {?=} options
     * @return {?}
     */
    getCasenotes(workId, page, pagesize, options) {
        /** @type {?} */
        let subject$ = new BehaviorSubject(new WorkCasenotesFrameModel());
        /** @type {?} */
        let baseUrl = this.config.settings.apiServer.baseUrl;
        /** @type {?} */
        let scope = this.config.settings.apiServer.scope;
        /** @type {?} */
        let offset = page * pagesize;
        /** @type {?} */
        let url = `${baseUrl}/${scope}/odata/Ui/Casenotes/${workId.toString()}?$count=true&$top=${pagesize || 10}&$skip=${offset || 0}`;
        // Append orderby
        if (options && options.orderby && options.orderby !== "")
            url += `&$orderby=${encodeURIComponent(options.orderby)}`;
        this.http.get(url).subscribe(result => {
            /** @type {?} */
            let whf = new WorkCasenotesFrameModel();
            whf.count = result["@odata.count"];
            whf.page = page;
            whf.pagesize = pagesize;
            whf.data = result.value;
            subject$.next(whf);
        }, error => {
            console.error(error);
            subject$.error(error);
        });
        return (subject$);
    }
}
CasenotesOdataService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
CasenotesOdataService.ctorParameters = () => [
    { type: HttpClient },
    { type: E5ConfigurationService }
];
/** @nocollapse */ CasenotesOdataService.ngInjectableDef = defineInjectable({ factory: function CasenotesOdataService_Factory() { return new CasenotesOdataService(inject(HttpClient), inject(E5ConfigurationService)); }, token: CasenotesOdataService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OdataMatTableDataSource$2 extends DataSource {
    /**
     * @param {?} workId
     * @param {?} casenotesService
     */
    constructor(workId, casenotesService) {
        super();
        this.workId = workId;
        this.casenotesService = casenotesService;
        this.subject$ = new BehaviorSubject([]);
        this.orderby = { active: "CasenoteDate", direction: "desc" };
        this.loading$ = new BehaviorSubject(false);
    }
    /**
     * @param {?} paginator
     * @return {?}
     */
    set paginator(paginator) {
        this._paginator = paginator;
        this._paginator.page.subscribe(x => {
            // {"previousPageIndex":0,"pageIndex":1,"pageSize":10,"length":100}
            this.update();
        });
    }
    /**
     * @param {?} sort
     * @return {?}
     */
    set sort(sort) {
        this._sort = sort;
        this._sort.sortChange.subscribe(ob => {
            // {active: "detail", direction: ""}
            this.orderby = ob;
            this.update();
        });
    }
    /**
     * @param {?} id
     * @return {?}
     */
    setWorkId(id) {
        // if(id !== this.workId) {
        this.workId = id;
        this.update();
        // }
    }
    /**
     * @return {?}
     */
    get loadingEvents() {
        return this.loading$;
    }
    /**
     * @return {?}
     */
    update() {
        if (!this.workId || !Guid.isGuid(this.workId) || this.workId.toString() === Guid.EMPTY) {
            this.subject$.next([]);
            return;
        }
        /** @type {?} */
        let page = (this._paginator) ? this._paginator.pageIndex : 0;
        /** @type {?} */
        let pagesize = (this._paginator) ? this._paginator.pageSize : 10;
        /** @type {?} */
        let options = {};
        // Setup orderby option if it's available
        /** @type {?} */
        let orderby = this.orderby;
        if (orderby && orderby.direction && orderby.active) {
            options.orderby = `${orderby.active} ${orderby.direction}`;
        }
        // Go get the data
        this.loading$.next(true);
        this.casenotesService.getCasenotes(this.workId, page, pagesize, options).subscribe(frame => {
            this._paginator.length = frame.count;
            this.subject$.next(frame.data);
            this.loading$.next(false);
        }, error => {
            console.error(error);
            this.loading$.next(false);
        });
    }
    /**
     * @return {?}
     */
    connect() {
        this.update();
        return (this.subject$);
    }
    /**
     * @return {?}
     */
    disconnect() { }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkCasenotesMaterialComponent extends E5coreUiWorkCasenotesBaseComponent {
    /**
     * @param {?} casenotes
     */
    constructor(casenotes) {
        super();
        this.casenotes = casenotes;
        this.displayedColumns = ['CasenoteDate', 'User', 'CasenoteType', 'Detail'];
        this.isLoading = true;
        this.length = 0;
        this.pageSize = 10;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.pageSizeOptions = (this.pagesizes && this.pagesizes.length > 0) ? this.pagesizes : [5, 10, 25, 50];
        this.dataSource = new OdataMatTableDataSource$2(Guid.EMPTY, this.casenotes); // this.history.getHistory(id, 0, 10) ;
        this.dataSource.sort = this.sort;
        this.dataSource.paginator = this.paginator;
        this.dataSource.loadingEvents.subscribe(isLoading => {
            this.isLoading = isLoading;
        });
        this.workItem$.subscribe(wim => {
            this.dataSource.setWorkId(wim.workId);
        });
    }
    /**
     * @param {?} setPageSizeOptionsInput
     * @return {?}
     */
    setPageSizeOptions(setPageSizeOptionsInput) {
        this.pageSizeOptions = setPageSizeOptionsInput.split(',').map(str => +str);
    }
}
E5coreUiWorkCasenotesMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-casenotes-material',
                template: "<div class=\"e5core-ui-work-casenotes\">\n\n  <div *ngIf=\"isLoading\" class=\"mat-spinner-holder\" align=\"center\">\n      <mat-spinner></mat-spinner>\n  </div>\n\n  <table mat-table [dataSource]=\"dataSource\" matSort class=\"e5core-ui-work-casenotes\">\n\n    <!-- Date Date -->\n    <ng-container matColumnDef=\"CasenoteDate\">\n      <th mat-header-cell *matHeaderCellDef mat-sort-header> Date </th>\n      <td mat-cell *matCellDef=\"let element\"> {{element.CasenoteDate | date : 'd LLL yyyy h:mm aa' }} </td> <!-- https://angular.io/api/common/DatePipe -->\n    </ng-container>\n\n    <!-- Name User -->\n    <ng-container matColumnDef=\"User\">\n      <th mat-header-cell *matHeaderCellDef mat-sort-header> User </th>\n      <td mat-cell *matCellDef=\"let element\"> {{element.User}} </td>\n    </ng-container>\n\n    <!-- Weight Event -->\n    <ng-container matColumnDef=\"CasenoteType\">\n      <th mat-header-cell *matHeaderCellDef mat-sort-header> Type </th>\n      <td mat-cell *matCellDef=\"let element\"> {{element.CasenoteType}} </td>\n    </ng-container>\n\n    <!-- Symbol Status -->\n    <ng-container matColumnDef=\"Detail\">\n      <th mat-header-cell *matHeaderCellDef mat-sort-header> Detail </th>\n      <td mat-cell *matCellDef=\"let element\"> {{element.Detail}} </td>\n    </ng-container>\n\n    <tr mat-header-row *matHeaderRowDef=\"displayedColumns\"></tr>\n    <tr mat-row *matRowDef=\"let row; columns: displayedColumns;\"></tr>\n  </table>\n\n  <mat-paginator [length]=\"length\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"pageSizeOptions\" (page)=\"pageEvent = $event\" showFirstLastButtons></mat-paginator>\n</div>",
                styles: ["table.e5core-ui-work-casenotes{width:100%}table.e5core-ui-work-casenotes tr th:nth-child(1){width:150pt}table.e5core-ui-work-casenotes tr th:nth-child(2),table.e5core-ui-work-casenotes tr th:nth-child(3){width:120pt}.e5core-ui-work-casenotes .mat-spinner-holder{width:100%;padding:20pt;position:relative;top:30px;height:1px}.e5core-ui-work-casenotes .mat-paginator{margin-top:0;background:0 0}"]
            }] }
];
/** @nocollapse */
E5coreUiWorkCasenotesMaterialComponent.ctorParameters = () => [
    { type: CasenotesOdataService }
];
E5coreUiWorkCasenotesMaterialComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    paginator: [{ type: ViewChild, args: [MatPaginator,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkCasenotesBoxComponent extends E5coreUiWorkCasenotesBaseComponent {
}
E5coreUiWorkCasenotesBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-casenotes-box',
                template: "<p>\n  e5core-ui-work-casenotes-box not implemented!\n</p>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const FieldDataType = {
    Input: 1,
    Date: 2,
    Text: 3,
    User: 4,
    GUID: 5,
    CaseNote: 6,
    List: 7,
    Lookup: 8,
    Integer: 9,
    Currency: 10,
    DateTime: 11,
    Reference: 12,
    SiteGroup: 13,
    Checkbox: 14,
    Form: 15,
    Link: 16,
    Grid: 17,
    Decimal: 18,
    MultiValueList: 19,
};
FieldDataType[FieldDataType.Input] = 'Input';
FieldDataType[FieldDataType.Date] = 'Date';
FieldDataType[FieldDataType.Text] = 'Text';
FieldDataType[FieldDataType.User] = 'User';
FieldDataType[FieldDataType.GUID] = 'GUID';
FieldDataType[FieldDataType.CaseNote] = 'CaseNote';
FieldDataType[FieldDataType.List] = 'List';
FieldDataType[FieldDataType.Lookup] = 'Lookup';
FieldDataType[FieldDataType.Integer] = 'Integer';
FieldDataType[FieldDataType.Currency] = 'Currency';
FieldDataType[FieldDataType.DateTime] = 'DateTime';
FieldDataType[FieldDataType.Reference] = 'Reference';
FieldDataType[FieldDataType.SiteGroup] = 'SiteGroup';
FieldDataType[FieldDataType.Checkbox] = 'Checkbox';
FieldDataType[FieldDataType.Form] = 'Form';
FieldDataType[FieldDataType.Link] = 'Link';
FieldDataType[FieldDataType.Grid] = 'Grid';
FieldDataType[FieldDataType.Decimal] = 'Decimal';
FieldDataType[FieldDataType.MultiValueList] = 'MultiValueList';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// import { UiSearchDefinitionService, FoundationWorkFindWorkItemResultModel, FoundationWorkFindWorkItemColumnDefModel, UIPropertyModel } from "e5core-angular-services";
// import { Injectable } from "@angular/core";
// import { BehaviorSubject, Subject, Observable } from "rxjs";
// import { WorkSearchFoundationService } from "e5core-angular-services";
// import { SearchFormModel } from "../models/search-form.model";
// import { SearchResultsModel, CreateBlankSearchResult } from "../models/search-results.model";
// import { SearchFilter, SearchFilterExpression } from "../models/search-filter.model";
// export class PerformSearchOptions {
//   attachmentTypeFilter?: any;
//   includeArchives?: boolean;
//   includeSla?: boolean;
//   includeAttachmentCount?: boolean;
//   includeNextDueTask?: boolean;
//   customProcedure?: string;
//   select?: string;
//   orderBy?: string;
//   siteGroupsFilter?: string;
//   page?: number;
//   pageSize?: number
// }
/**
 * This service is used to provide work into the work item Subject/
 */
class SearchDeliveryService {
    /**
     * @param {?} uiSearchDefinitionService
     * @param {?} workSearchService
     */
    constructor(uiSearchDefinitionService, workSearchService) {
        this.uiSearchDefinitionService = uiSearchDefinitionService;
        this.workSearchService = workSearchService;
    }
    /**
     * Get the search defintion, inclusing the fields to be shown by default, the search fields
     * and the default search information.
     * @param {?} searchForm$ publish the new search definition to this observable.
     * @param {?} searchDefinitionId
     * @return {?}
     */
    getSearchDefinition(searchForm$, searchDefinitionId) {
        /** @type {?} */
        const subject$ = new Subject();
        this.uiSearchDefinitionService.get(searchDefinitionId).subscribe(searchDefiniton => {
            /** @type {?} */
            let current = searchForm$.getValue();
            /** @type {?} */
            let updated = Object.assign({}, current, searchDefiniton);
            searchForm$.next(updated);
            subject$.next(updated);
        }, error => subject$.error(error), () => subject$.complete());
        return (subject$);
    }
}
SearchDeliveryService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
SearchDeliveryService.ctorParameters = () => [
    { type: UiSearchDefinitionService },
    { type: WorkSearchFoundationService }
];
/** @nocollapse */ SearchDeliveryService.ngInjectableDef = defineInjectable({ factory: function SearchDeliveryService_Factory() { return new SearchDeliveryService(inject(UiSearchDefinitionService), inject(WorkSearchFoundationService)); }, token: SearchDeliveryService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchFormComponent {
    /**
     * @param {?} style
     * @param {?} searchDeliveryService
     * @param {?} search
     * @param {?} cd
     */
    constructor(style$$1, searchDeliveryService, search, cd) {
        this.style = style$$1;
        this.searchDeliveryService = searchDeliveryService;
        this.search = search;
        this.cd = cd;
        this.queryChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.searchForm$ == null) {
            console.error('e5core-ui-search-form [searchForm$] must have a BehaviorSubject<SearchFormModel>');
            return;
        }
        if (this.searchDefinitionId) {
            this.searchDeliveryService.getSearchDefinition(this.searchForm$, this.searchDefinitionId).subscribe(s => {
                this.applyDefaultValues(this.defaultValues);
            }, error => {
                this.errorMessage = error.message || "Unable to get data from server.";
                console.error(error);
                this.cd.markForCheck();
            });
        }
        else {
            console.warn("e5core-ui-search-form searchId is missing. Expecting one later...");
        }
        this.searchForm$.subscribe(searchModel => {
            this.errorMessage = "";
            this.zones = (searchModel) ? searchModel.zones : undefined;
            this.zoneTemplateId = (searchModel && searchModel.zoneTemplateId) ? searchModel.zoneTemplateId.toUpperCase() : "";
            this.cd.markForCheck();
            this.queryChange.emit(this.createDataSourceQuery(searchModel));
        });
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    createDataSourceQuery(model) {
        /** @type {?} */
        let query = null;
        if (model && model.properties && model.properties.length > 0) {
            query = {
                Expressions: model.properties
                    .filter(p => p.value)
                    .map(p => (/** @type {?} */ ({
                    Field: p.propertyId,
                    Value: p.value
                })))
            };
        }
        return (query);
    }
    /**
     * If there are any default values on the form, then set them.
     * @private
     * @param {?} values the default values to use on the form
     * @param {?=} reset
     * @return {?}
     */
    applyDefaultValues(values, reset) {
        /** @type {?} */
        let searchForm = (/** @type {?} */ (Object.assign({}, this.searchForm$.getValue())));
        /** @type {?} */
        let updated = false;
        if (reset) {
            searchForm.properties.forEach(p => {
                p.value = undefined;
                p.resolvedValue = undefined;
            });
            updated = true;
        }
        if (values) {
            if (searchForm.properties) {
                Object.keys(values).forEach(key => {
                    /** @type {?} */
                    let property = searchForm.properties.find(p => p.propertyId == key);
                    if (property) {
                        updated = true;
                        /** @type {?} */
                        let value = values[key];
                        property.value = value; // will be set to undefined if not specified
                        if (property.fieldDataType != FieldDataType.List && property.fieldDataType != FieldDataType.Lookup) // if it's not a list or lookup
                            property.resolvedValue = value;
                    }
                });
            }
        }
        if (updated)
            this.searchForm$.next(searchForm);
    }
    /**
     * Reset the serch form to the original default values, or clear it.
     * @return {?}
     */
    reset() {
        this.applyDefaultValues(this.defaultValues, true /* reset */);
        this.cd.markForCheck();
    }
}
E5coreUiSearchFormComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-form',
                template: `
  <span *ngIf="searchForm$" [ngSwitch]="style.current()">
    <e5core-ui-search-form-box *ngSwitchCase='0' [searchForm$]='searchForm$' [zones]='zones' [zoneTemplateId]='zoneTemplateId'></e5core-ui-search-form-box>
    <e5core-ui-search-form-bootstrap *ngSwitchCase='1' [searchForm$]='searchForm$' [zones]='zones' [zoneTemplateId]='zoneTemplateId'></e5core-ui-search-form-bootstrap>
    <e5core-ui-search-form-material *ngSwitchCase='2' [searchForm$]='searchForm$' [zones]='zones' [zoneTemplateId]='zoneTemplateId'></e5core-ui-search-form-material>
  </span>
  <div *ngIf="!searchForm$" class="e5core-component-error">&lt;e5core-ui-search-form&gt; [searchForm$] must have a BehaviorSubject&lt;SearchModel&gt;</div>
  <div *ngIf="errorMessage" class="e5core-component-error">&lt;e5core-ui-search-form&gt; error : {{errorMessage}}</div>`,
                styles: [".e5core-component-error{border-left:5px solid red;background-color:#ffbaba;color:#d8000c;padding:12px;box-sizing:content-box;border-radius:4pt;display:inline-block;font-family:Arial,Helvetica,sans-serif;margin:5pt 0}.e5-component{margin:5pt;border:solid #00f;box-sizing:content-box;padding:5pt}.e5-component .e5-title{color:#00f;font-weight:700}"]
            }] }
];
/** @nocollapse */
E5coreUiSearchFormComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: SearchDeliveryService },
    { type: UiSearchDefinitionService },
    { type: ChangeDetectorRef }
];
E5coreUiSearchFormComponent.propDecorators = {
    searchForm$: [{ type: Input }],
    searchDefinitionId: [{ type: Input }],
    defaultValues: [{ type: Input }],
    queryChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchFormBaseComponent {
    constructor() {
        this.zoneId = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchFormBaseComponent.propDecorators = {
    searchForm$: [{ type: Input }],
    zones: [{ type: Input }],
    zoneTemplateId: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchFormBootstrapComponent extends E5coreUiSearchFormBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchFormBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-form-bootstrap',
                template: "<p>\n  e5core-ui-search-form-bootstrap not implemented!\n</p>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchFormMaterialComponent extends E5coreUiSearchFormBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchFormMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-form-material',
                template: "<div class='e5core-search-form' *ngIf='zones && zones.length > 0'>\n\n  <div *ngIf=\"!zoneTemplateId\">\n    <div *ngFor='let zone of zones'>\n      <e5core-ui-work-field-set [workItem$]='searchForm$' [fieldSetId]='zone.contentTypeId'></e5core-ui-work-field-set>\n    </div>\n  </div>\n\n  <!-- Zone tempalte AF1051FC-B2B1-4A74-9AA7-2D868CA2EBBC - Two by One -->\n  <table class='e5core-search-form-template' *ngIf=\"zoneTemplateId == 'AF1051FC-B2B1-4A74-9AA7-2D868CA2EBBC' \">\n    <tr>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[0]' [workItem$]='searchForm$' [fieldSetId]='zones[0].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[1]' [workItem$]='searchForm$' [fieldSetId]='zones[1].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n    </tr>\n    <tr>\n      <td colspan=\"2\" valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[2]' [workItem$]='searchForm$' [fieldSetId]='zones[2].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n    </tr>\n  </table>\n\n  <!-- Zone template AF1051FC-B2B2-4A74-9AA7-2D868CA2EBBC - Two by Two -->\n  <table class='e5core-search-form-template' *ngIf=\"zoneTemplateId == 'AF1051FC-B2B2-4A74-9AA7-2D868CA2EBBC' \">\n    <tr>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[0]' [workItem$]='searchForm$' [fieldSetId]='zones[0].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[1]' [workItem$]='searchForm$' [fieldSetId]='zones[1].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n    </tr>\n    <tr>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[2]' [workItem$]='searchForm$' [fieldSetId]='zones[2].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[3]' [workItem$]='searchForm$' [fieldSetId]='zones[3].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n    </tr>\n  </table>\n\n  <!-- Zone template AF1051FC-C3B1-4539-B8DC-498DE8374550 - Three by One -->\n  <table class='e5core-search-form-template' *ngIf=\"zoneTemplateId == 'AF1051FC-C3B1-4539-B8DC-498DE8374550'  \">\n    <tr>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[0]' [workItem$]='searchForm$' [fieldSetId]='zones[0].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[1]' [workItem$]='searchForm$' [fieldSetId]='zones[1].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[2]'  [workItem$]='searchForm$' [fieldSetId]='zones[2].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n    </tr>\n    <tr>\n      <td colspan=\"3\" valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[3]' [workItem$]='searchForm$' [fieldSetId]='zones[3].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n    </tr>\n  </table>\n\n  <!-- Zone template AF1051FC-C3B3-4539-B8DC-498DE8374550 - Three by Three -->\n  <table class='e5core-search-form-template' *ngIf=\"zoneTemplateId == 'AF1051FC-C3B3-4539-B8DC-498DE8374550'  \">\n    <tr>\n        <td valign=\"top\">\n          <e5core-ui-work-field-set *ngIf='zones[0]'  [workItem$]='searchForm$' [fieldSetId]='zones[0].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n        <td valign=\"top\">\n          <e5core-ui-work-field-set *ngIf='zones[1]' [workItem$]='searchForm$' [fieldSetId]='zones[1].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n        <td valign=\"top\">\n          <e5core-ui-work-field-set *ngIf='zones[2]' [workItem$]='searchForm$' [fieldSetId]='zones[2].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n      </tr>\n      <tr>\n        <td valign=\"top\">\n          <e5core-ui-work-field-set *ngIf='zones[3]' [workItem$]='searchForm$' [fieldSetId]='zones[3].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n        <td valign=\"top\">\n          <e5core-ui-work-field-set *ngIf='zones[4]' [workItem$]='searchForm$' [fieldSetId]='zones[4].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n        <td valign=\"top\">\n          <e5core-ui-work-field-set *ngIf='zones[5]' [workItem$]='searchForm$' [fieldSetId]='zones[5].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n      </tr>\n      <tr>\n        <td valign=\"top\">\n            <e5core-ui-work-field-set *ngIf='zones[6]' [workItem$]='searchForm$' [fieldSetId]='zones[6].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n        <td valign=\"top\">\n            <e5core-ui-work-field-set *ngIf='zones[7]' [workItem$]='searchForm$' [fieldSetId]='zones[7].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n        <td valign=\"top\">\n            <e5core-ui-work-field-set *ngIf='zones[8]' [workItem$]='searchForm$' [fieldSetId]='zones[8].contentTypeId'></e5core-ui-work-field-set>\n        </td>\n      </tr>\n  </table>\n\n  <!-- Zone template AF1051FC-A1B1-4C33-B1A3-C2F1F24CB958 - One by One -->\n  <table class='e5core-search-form-template' *ngIf=\"zoneTemplateId == 'AF1051FC-A1B1-4C33-B1A3-C2F1F24CB958'  \">\n    <tr>\n      <td valign=\"top\">\n        <e5core-ui-work-field-set *ngIf='zones[0]' [workItem$]='searchForm$' [fieldSetId]='zones[0].contentTypeId'></e5core-ui-work-field-set>\n      </td>\n    </tr>\n  </table>\n\n</div>\n\n\n",
                styles: [".e5core-search-form-template{width:100%}.e5core-search-form-template td{padding:10pt}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchFormBoxComponent extends E5coreUiSearchFormBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchFormBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-form-box',
                template: "<div class=\"e5-component\">\n  <div class=\"e5-title\">e5core-ui-search-form</div>\n  <div class=\"e5-content\">\n      {{ zones | json }}\n      <div *ngFor='let zone of zones'>\n        {{ zone.contentTypeId }}\n        <e5core-ui-work-field-set [workItem$]='searchForm$' [fieldSetId]='zone.contentTypeId'></e5core-ui-work-field-set>\n      </div>\n\n  </div>\n</div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const DataSourceColumnStatus = {
    Hidden: 0,
    Available: 1,
    Selected: 2,
};
DataSourceColumnStatus[DataSourceColumnStatus.Hidden] = 'Hidden';
DataSourceColumnStatus[DataSourceColumnStatus.Available] = 'Available';
DataSourceColumnStatus[DataSourceColumnStatus.Selected] = 'Selected';
class DataSourceColumn {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchDataSourceService {
    /**
     * @param {?} searchDefinitionService
     * @param {?} searchService
     */
    constructor(searchDefinitionService, searchService) {
        this.searchDefinitionService = searchDefinitionService;
        this.searchService = searchService;
        this.SlaExpiryColumnCode = '_SLAExpiryStatus';
        this.NextTaskColumnCode = '_NextDueTask';
        this.searchDefinitionId = 0;
        this.searchOptions = {};
    }
    /**
     * @return {?}
     */
    defaultOptions() {
        return (this.searchOptions);
    }
    /**
     * @param {?} options
     * @return {?}
     */
    setDefaultOptions(options) {
        this.searchOptions = Object.assign({}, options); // clone
    }
    /**
     * @param {?} id
     * @return {?}
     */
    setSearchDefinitionId(id) {
        this.searchDefinitionId = id;
        return (this);
    }
    /**
     * @return {?}
     */
    columns() {
        return this.searchDefinitionService.get(this.searchDefinitionId).pipe(map(r => {
            /** @type {?} */
            const columns = r.searchFields.map(sf => (/** @type {?} */ ({
                code: sf.fieldDefinitionId,
                label: sf.fieldLabel,
                type: sf.fieldDataType,
                status: sf.fieldStatus
            })));
            return this.addOptionalColumns(columns);
        }));
    }
    /**
     * @private
     * @param {?} columns
     * @return {?}
     */
    addOptionalColumns(columns) {
        if (this.searchOptions) {
            if (this.searchOptions.includeSla) {
                // Add to start
                columns.unshift((/** @type {?} */ ({
                    label: 'SLA',
                    code: this.SlaExpiryColumnCode,
                    type: 'SLA',
                    status: DataSourceColumnStatus.Selected
                })));
            }
            if (this.searchOptions.includeNextDueTask) {
                // Add to end
                columns.push((/** @type {?} */ ({
                    code: this.NextTaskColumnCode,
                    label: 'Next Due Task',
                    type: 'Input',
                    status: DataSourceColumnStatus.Selected
                })));
            }
        }
        return (columns);
    }
    /**
     * @param {?} page
     * @param {?} pageSize
     * @param {?} optionsIn
     * @return {?}
     */
    read(page, pageSize, optionsIn) {
        /** @type {?} */
        const options = Object.assign({}, this.searchOptions, optionsIn, { page: page, pageSize: pageSize });
        /** @type {?} */
        const filterBy = this.mapQueryToFilterBy(options.query);
        return this.searchService.getFindWorkItem(this.searchDefinitionId, filterBy, options)
            .pipe(map(results => {
            return {
                total: results.total,
                data: this.mapResults(results)
            };
        }));
    }
    /**
     * The data that comes back from the API is a columns defintion and an array
     * of array of data. We need to map this into an array of objects with the column property
     * id as the object key so that it's easier to handle by the table.
     * @private
     * @param {?} model
     * @return {?}
     */
    mapResults(model) {
        /** @type {?} */
        const data = model.results;
        /** @type {?} */
        let results;
        if (model && model.total > 0 && model.results && model.columns) {
            /** @type {?} */
            const colDefs = model.columns;
            results = model.results.map(r => {
                /** @type {?} */
                const dataRow = r;
                /** @type {?} */
                const objectRow = {};
                for (let c = 0; c < colDefs.length; c++) {
                    /** @type {?} */
                    const columnDef = colDefs[c];
                    objectRow[columnDef.code] = dataRow[c];
                }
                return (objectRow);
            });
        }
        return results;
    }
    //  In order to use the foundation service we need to map the DataSourceQuery into 
    //  the underlying foundation query
    // 	{
    // 		'filters': [
    // 	  		{
    // 				'field': 'string',
    // 				'operator': 'string',
    // 				'value': 'string'
    // 	  		}
    // 		],
    // 		'logic': 'string'
    // 	}
    /**
     * @private
     * @param {?} query
     * @return {?}
     */
    mapQueryToFilterBy(query) {
        /** @type {?} */
        let filterBy = {};
        if (query && query.Expressions && query.Expressions.length > 0) {
            /** @type {?} */
            const filters = query.Expressions
                .filter(e => e.Value)
                .map(e => {
                return {
                    field: e.Field,
                    value: e.Value
                };
            });
            filterBy = {
                filters: filters
            };
        }
        return (filterBy);
    }
}
SearchDataSourceService.decorators = [
    { type: Injectable, args: [{
                providedIn: null // 'root'
            },] }
];
/** @nocollapse */
SearchDataSourceService.ctorParameters = () => [
    { type: UiSearchDefinitionService },
    { type: WorkSearchFoundationService }
];
/** @nocollapse */ SearchDataSourceService.ngInjectableDef = defineInjectable({ factory: function SearchDataSourceService_Factory() { return new SearchDataSourceService(inject(UiSearchDefinitionService), inject(WorkSearchFoundationService)); }, token: SearchDataSourceService, providedIn: null });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const QueryOperation = {
    Equal: "eq",
    NotEqual: "ne",
    LessThan: "lt",
    LessThanOrEqual: "lte",
    GreaterThan: "gt",
    GreaterThanOrEqual: "gte",
    Contains: "contains",
};
/** @enum {string} */
const QueryBooleanOperation = {
    And: "and",
    Or: "or",
    Not: "not",
};
class QueryExpression {
}
class DataSourceQuery {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchResultsComponent {
    /**
     * @param {?} style
     * @param {?} datasource
     */
    constructor(style$$1, datasource) {
        this.style = style$$1;
        this.datasource = datasource;
        this.open = new EventEmitter();
        this.link = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.searchDefinitionId == null) {
            this.error = 'e5core-ui-search-results [searchDefinitionId] must be specified';
            console.error(this.error);
            return;
        }
        this.datasource.setSearchDefinitionId(this.searchDefinitionId);
        /** @type {?} */
        let options = this.datasource.defaultOptions();
        options.includeSla = this.includeSla;
        options.includeNextDueTask = this.includeNextDueTask;
        this.datasource.setDefaultOptions(options);
    }
    /**
     *  Pass the open work item event on to any listener.
     * @param {?} data the row of data, including the "Id" from the table.
     * @return {?}
     */
    onOpen(data) {
        this.open.emit(data);
    }
    /**
     *  Pass the open link on to any listener.
     * @param {?} url
     * @return {?}
     */
    onLink(url) {
        this.open.emit(url);
    }
    /**
     * Execute a search with the required search expression values.
     * @param {?} query
     * @return {?}
     */
    search(query) {
        this.resultChildren.forEach(c => c.search(query));
    }
    /**
     * Clear the search results.
     * @return {?}
     */
    reset() {
        this.resultChildren.forEach(c => c.reset());
    }
    /**
     * Refresh the search results at the current page.
     * @return {?}
     */
    refresh() {
        this.resultChildren.forEach(c => c.refresh());
    }
}
E5coreUiSearchResultsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-results',
                // (open)='onOpen' (link)='onLink'
                // We don't need a switch as the e5core-ui-datagrid handles the different implementations
                template: `
  <span *ngIf="!error">
    <e5core-ui-datagrid #SearchResults
      [datasource]='datasource'  [query]='query' [autoSearch]='autoSearch'
      (open)='onOpen($event)' (link)='onLink($event)'>
    </e5core-ui-datagrid>
  </span>
  <div *ngIf="error" class="e5core-component-error">{{error}}</div>`,
                //changeDetection: ChangeDetectionStrategy.OnPush
                providers: [
                    SearchDataSourceService
                ],
                styles: [".e5core-component-error{border-left:5px solid red;background-color:#ffbaba;color:#d8000c;padding:12px;box-sizing:content-box;border-radius:4pt;display:inline-block;font-family:Arial,Helvetica,sans-serif;margin:5pt 0}.e5-component{margin:5pt;border:solid #00f;box-sizing:content-box;padding:5pt}.e5-component .e5-title{color:#00f;font-weight:700}"]
            }] }
];
/** @nocollapse */
E5coreUiSearchResultsComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: SearchDataSourceService }
];
E5coreUiSearchResultsComponent.propDecorators = {
    searchDefinitionId: [{ type: Input }],
    query: [{ type: Input }],
    includeSla: [{ type: Input }],
    includeNextDueTask: [{ type: Input }],
    autoSearch: [{ type: Input }],
    open: [{ type: Output }],
    link: [{ type: Output }],
    resultChildren: [{ type: ViewChildren, args: ["SearchResults",] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchResultsBaseComponent {
    constructor() {
        this.open = new EventEmitter();
        this.link = new EventEmitter();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set query(value) {
        this.search(value);
    }
    ;
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     *  Pass the open work item event on to any listener.
     * @param {?} data the row of data, including the "Id" from the table.
     * @return {?}
     */
    onOpen(data) {
        this.open.emit(data);
    }
    /**
     *  Pass the open link on to any listener.
     * @param {?} link
     * @return {?}
     */
    onLink(link) {
        this.link.emit(link);
    }
    /**
     * Execute a search with the required search expression values.
     * @param {?} expression the fields and values required to perform the search.
     * @return {?}
     */
    search(expression) {
    }
    /**
     * Clear the search results.
     * @return {?}
     */
    reset() {
    }
    /**
     * Refresh the search results at the current page.
     * @return {?}
     */
    refresh() {
    }
}
E5coreUiSearchResultsBaseComponent.propDecorators = {
    datasource: [{ type: Input }],
    query: [{ type: Input }],
    autoSearch: [{ type: Input }],
    pagesizes: [{ type: Input }],
    open: [{ type: Output }],
    link: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchResultsBootstrapComponent extends E5coreUiSearchResultsBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchResultsBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-results-bootstrap',
                template: "<p>\n  e5core-ui-search-results-bootstrap not implemented!\n</p>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchMatTableDataSource extends DataSource {
    /**
     * @param {?} datasource
     */
    constructor(datasource) {
        super();
        this.datasource = datasource;
        this.subject$ = new BehaviorSubject([]);
        this.loading$ = new BehaviorSubject(false);
        //this.refresh() ;
    }
    /**
     * @param {?} paginator
     * @return {?}
     */
    set paginator(paginator) {
        this._paginator = paginator;
        this._paginator.page.subscribe(x => {
            // {"previousPageIndex":0,"pageIndex":1,"pageSize":10,"length":100}
            this.update(this.lastQuery);
        });
    }
    /**
     * @param {?} sort
     * @return {?}
     */
    set sort(sort) {
        this._sort = sort;
        this._sort.sortChange.subscribe(ob => {
            // {active: "detail", direction: ""}
            this.orderby = ob;
            this.update(this.lastQuery);
        });
    }
    /**
     * @protected
     * @param {?} query
     * @return {?}
     */
    update(query) {
        /** @type {?} */
        let page = (this._paginator) ? this._paginator.pageIndex : 0;
        /** @type {?} */
        let pageSize = (this._paginator) ? this._paginator.pageSize : 10;
        /** @type {?} */
        let options = this.datasource.defaultOptions();
        // Setup orderby option if it's available
        /** @type {?} */
        let orderby = this.orderby;
        if (orderby && orderby.direction && orderby.active) {
            if (orderby.direction.toLowerCase() == "desc")
                options.orderBy = `-${orderby.active}`;
            else
                options.orderBy = `+${orderby.active}`;
        }
        options.query = query;
        this.loading$.next(true);
        this.datasource.read(page, pageSize, options).subscribe(results => {
            this._paginator.length = results.total;
            this.subject$.next(results.data);
        }, error => { this.loading$.next(false); }, () => { this.loading$.next(false); });
        this.lastQuery = query;
    }
    /**
     * Subscribe to this observable if you want to be informed when the datasource is loading.
     * @return {?}
     */
    get loadingEvents() {
        return (this.loading$);
    }
    /**
     * @param {?} query
     * @return {?}
     */
    search(query) {
        this._paginator.pageIndex = 0;
        this.update(query);
    }
    /**
     * @return {?}
     */
    refresh() {
        this.update(this.lastQuery);
    }
    /**
     * @return {?}
     */
    reset() {
        this.clear();
    }
    /**
     * @return {?}
     */
    clear() {
        this._paginator.pageIndex = 0;
        this._paginator.length = 0;
        this.subject$.next([]);
    }
    /**
     * @return {?}
     */
    connect() {
        return (this.subject$);
    }
    /**
     * @return {?}
     */
    disconnect() { }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// https://stackblitz.com/edit/dynamic-columns-mat-table?file=app%2Ftable-pagination-example.html
// https://github.com/angular/material2/issues/5927
class E5coreUiSearchResultsMaterialComponent extends E5coreUiSearchResultsBaseComponent {
    /**
     * @param {?} searchService
     */
    constructor(searchService) {
        super();
        this.searchService = searchService;
        this.isEmpty = false;
        this.length = 0;
        this.pageSize = 10;
        this.loading = true;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.pageSizeOptions = (this.pagesizes && this.pagesizes.length > 0) ? this.pagesizes : [5, 10, 25, 50];
        // this.tableDataSource = new SearchMatTableDataSource(this.datasource); // this.history.getHistory(id, 0, 10) ;
        this.tableDataSource = new SearchMatTableDataSource(this.datasource); // this.history.getHistory(id, 0, 10) ;
        this.tableDataSource.sort = this.sort;
        this.tableDataSource.paginator = this.paginator;
        this.tableDataSource.loadingEvents.subscribe(loading => {
            this.loading = loading;
        });
        // Load the columns
        this.loading = true;
        this.datasource.columns().subscribe(dsColumns => {
            this.headings = dsColumns;
            this.loading = false;
            if (this.delayedQuery || this.autoSearch) {
                this.search(this.delayedQuery);
            }
        }, error => { }, () => {
            this.loading = false;
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        // if (this.tableDataSource)
        // 	this.tableDataSource.loadingEvents.unsubscribe();
    }
    /**
     * @param {?} setPageSizeOptionsInput
     * @return {?}
     */
    setPageSizeOptions(setPageSizeOptionsInput) {
        this.pageSizeOptions = setPageSizeOptionsInput.split(',').map(str => +str);
    }
    /**
     * Return the list of columns available in the table.
     * @return {?}
     */
    columns() {
        if (this.headings) {
            /** @type {?} */
            let cols = (this.headings
                .filter(f => f.code !== 'Id') // Id is added at the beginning
                .map(f => (/** @type {?} */ ({
                label: f.label,
                name: f.code,
                type: f.type,
                status: f.status
            }))));
            return (cols);
        }
        return [];
    }
    /**
     * Return the list of column names that will be displayed in the table.
     * @return {?}
     */
    displayedColumns() {
        /** @type {?} */
        var cols = this.columns()
            .filter(f => f.status > 1) // Selected only
            .map(c => c.name);
        cols.unshift("Id");
        return (cols);
    }
    /**
     * @param {?} query
     * @return {?}
     */
    search(query) {
        if (this.tableDataSource)
            this.tableDataSource.search(query);
        else
            this.delayedQuery = query;
    }
    /**
     * @return {?}
     */
    reset() {
        this.tableDataSource.reset();
    }
    /**
     * @return {?}
     */
    refresh() {
        this.tableDataSource.refresh();
    }
}
E5coreUiSearchResultsMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-results-material',
                template: "<mat-card class='e5core-ui-search-results' [ngClass]=\"{'loading': loading}\">\n\t<div class=\"e5core-content\"  [ngClass]=\"{'loading': loading}\">\n\n\t\t<div *ngIf=\"loading\" class=\"e5core-loader\">\n\t\t\t<mat-spinner></mat-spinner>\n\t\t</div>\n\n\t\t<table mat-table [dataSource]=\"tableDataSource\" matSort class=\"e5core-ui-search-results-sort\">\n\n\t\t\t<!-- <ng-container matColumnDef=\"CasenoteDate\">\n            <th mat-header-cell *matHeaderCellDef mat-sort-header> Date </th>\n            <td mat-cell *matCellDef=\"let element\"> {{element.CasenoteDate | date : 'd LLL yyyy h:mm aa' }} </td>\n          </ng-container> -->\n\n\t\t\t<ng-container matColumnDef=\"Id\">\n\t\t\t\t<th mat-header-cell *matHeaderCellDef class='e5core-ui-search-results-column-workid'>Work</th>\n\t\t\t\t<td mat-cell *matCellDef=\"let element\" class='e5core-ui-search-results-column-workid'>\n\t\t\t\t\t<button mat-icon-button (click)='onOpen(element)'>\n\t\t\t\t\t\t<mat-icon aria-label=\"Open work item\">folder</mat-icon>\n\t\t\t\t\t</button>\n\t\t\t\t</td>\n\t\t\t</ng-container>\n\n\t\t\t<ng-container *ngFor=\"let column of columns()\" matColumnDef=\"{{column.name}}\">\n\t\t\t\t<th mat-header-cell *matHeaderCellDef mat-sort-header>{{column.label}} </th>\n\t\t\t\t<td mat-cell *matCellDef=\"let element\">\n\t\t\t\t\t<!-- {{ formatCell(element, column) }}  {{column.type}} -->\n\t\t\t\t\t<span [ngSwitch]=\"column.type\">\n\t\t\t\t\t\t<span *ngSwitchCase=\"'DateTime'\">{{ element[column.name] | date : 'd LLL yyyy h:mm aa' }}</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'Date'\">{{ element[column.name] | date : 'd LLL yyyy' }}</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'Currency'\">{{element[column.name] | currency}}</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'Checkbox'\">\n\t\t\t\t\t\t\t<mat-checkbox [(ngModel)]='element[column.name]' [disabled]=\"1\"></mat-checkbox>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'Link'\">\n\t\t\t\t\t\t\t<button mat-icon-button (click)='onLink(element[column.name])'>\n\t\t\t\t\t\t\t\t<mat-icon aria-label=\"Open work item\">public</mat-icon>\n\t\t\t\t\t\t\t</button>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'SLA'\">\n\t\t\t\t\t\t\t<mat-icon *ngIf=\"element[column.name] == 'expired'\" aria-label=\"Breached SLA\" color=\"warn\">report_problem</mat-icon>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t\t<span *ngSwitchDefault>{{element[column.name]}}</span>\n\t\t\t\t\t</span>\n\t\t\t\t</td>\n\t\t\t</ng-container>\n\n\t\t\t<tr mat-header-row *matHeaderRowDef=\"displayedColumns()\"></tr>\n\t\t\t<tr mat-row *matRowDef=\"let row; columns: displayedColumns();\"></tr>\n\t\t</table>\n\n\t\t<div *ngIf=\"paginator.length == 0\" class=\"empty\">\n\t\t\tNo Results\n\t\t</div>\n\n\t\t<mat-paginator [length]=\"length\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"pageSizeOptions\" (page)=\"pageEvent = $event\"\n\t\t showFirstLastButtons></mat-paginator>\n\n\t</div>\n\n\t<!-- <div><code>headings = {{ headings | json }}</code></div>\n  <div><code>properties = {{ properties | json }}</code></div> -->\n\n</mat-card>",
                styles: ["table{width:100%}.mat-paginator{margin-top:0;background:0 0}.e5core-ui-search-results{margin:10pt}.empty{width:100%;text-align:center;padding:15pt}.e5core-ui-search-results-column-workid{width:50px}.e5core-content.loading{background-color:rgba(.1,.1,.1,.1)}.e5core-content.loading table{background-color:transparent}.e5core-content .e5core-loader{position:absolute;margin-left:50%;margin-right:50%}.e5core-content .e5core-loader mat-spinner{top:20pt;left:-55pt}"]
            }] }
];
/** @nocollapse */
E5coreUiSearchResultsMaterialComponent.ctorParameters = () => [
    { type: SearchDataSourceService }
];
E5coreUiSearchResultsMaterialComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    paginator: [{ type: ViewChild, args: [MatPaginator,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchResultsBoxComponent extends E5coreUiSearchResultsBaseComponent {
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchResultsBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-results-box',
                template: "<div class=\"e5-component\">\n    <div class=\"e5-title\">e5core-ui-search-results</div>\n    <div class=\"e5-content\">\n\n    </div>\n  </div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchMenuComponent {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        this.style = style$$1;
        this.search = new EventEmitter();
        this.reset = new EventEmitter();
        this.refresh = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    onSearch() {
        this.search.emit();
    }
    /**
     * @return {?}
     */
    onReset() {
        this.reset.emit();
    }
    /**
     * @return {?}
     */
    onRefresh() {
        this.refresh.emit();
    }
}
E5coreUiSearchMenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-menu',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-search-menu-box *ngSwitchCase='0' (search)="onSearch()" (reset)="onReset()" (refresh)="onRefresh()"></e5core-ui-search-menu-box>
    <e5core-ui-search-menu-bootstrap *ngSwitchCase='1' (search)="onSearch()" (reset)="onReset()" (refresh)="onRefresh()"></e5core-ui-search-menu-bootstrap>
    <e5core-ui-search-menu-material *ngSwitchCase='2' (search)="onSearch()" (reset)="onReset()" (refresh)="onRefresh()"></e5core-ui-search-menu-material>
  </span>`,
                styles: [".e5core-component-error{border-left:5px solid red;background-color:#ffbaba;color:#d8000c;padding:12px;box-sizing:content-box;border-radius:4pt;display:inline-block;font-family:Arial,Helvetica,sans-serif;margin:5pt 0}.e5-component{margin:5pt;border:solid #00f;box-sizing:content-box;padding:5pt}.e5-component .e5-title{color:#00f;font-weight:700}"]
            }] }
];
/** @nocollapse */
E5coreUiSearchMenuComponent.ctorParameters = () => [
    { type: UiStyleService }
];
E5coreUiSearchMenuComponent.propDecorators = {
    search: [{ type: Output }],
    reset: [{ type: Output }],
    refresh: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchMenuBase {
    constructor() {
        this.search = new EventEmitter();
        this.reset = new EventEmitter();
        this.refresh = new EventEmitter();
    }
    /**
     * @return {?}
     */
    onSearch() {
        this.search.emit();
    }
    /**
     * @return {?}
     */
    onReset() {
        this.reset.emit();
    }
    /**
     * @return {?}
     */
    onRefresh() {
        this.refresh.emit();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchMenuBase.propDecorators = {
    search: [{ type: Output }],
    reset: [{ type: Output }],
    refresh: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchMenuBootstrapComponent extends E5coreUiSearchMenuBase {
    constructor() {
        super();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchMenuBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-menu-bootstrap',
                template: "<p>\n  e5core-ui-search-form-menu-bootstrap works!\n</p>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiSearchMenuBootstrapComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchMenuBoxComponent extends E5coreUiSearchMenuBase {
    constructor() {
        super();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchMenuBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-menu-box',
                template: "<p>\n  e5core-ui-search-form-menu-box works!\n</p>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiSearchMenuBoxComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSearchMenuMaterialComponent extends E5coreUiSearchMenuBase {
    constructor() {
        super();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSearchMenuMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-search-menu-material',
                template: "<div class='e5core-ui-search-menu'>\n    <button mat-raised-button (click)=\"onSearch()\">Search</button>\n    <button mat-raised-button (click)=\"onReset()\">Reset</button>\n    <button mat-raised-button (click)=\"onRefresh()\">Refresh</button>\n</div>\n",
                styles: [".e5core-ui-search-menu a,.e5core-ui-search-menu button{margin-right:8px}"]
            }] }
];
/** @nocollapse */
E5coreUiSearchMenuMaterialComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiFileUploadComponent {
    /**
     * @param {?} style
     * @param {?} config
     */
    constructor(style$$1, config) {
        this.style = style$$1;
        this.config = config;
        this.uploadToUrl = "";
        this.acceptedFileExtensions = ".pdf,.doc,.docx,.text,.txt,.jpg,.jpeg,.tif,.tiff,.png,.gif,.xls,.xslx,.ppt,.pptx,.vsd,.vsdx";
        this.maxFileSize = "20971520";
        this.uploadEvent = new EventEmitter();
        this.isInitialised = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null && this.uploadToUrl == "") {
            console.error('e5core-ui-file-upload either uploadToUrl needs to be specified or [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        this.DetermineUploadUrl();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onUploadEvent(event) {
        /** @type {?} */
        var wid = this.workItem$.getValue().workId;
        this.uploadEvent.emit({ workId: wid, id: null, name: null, fullUrl: null });
    }
    /**
     * @private
     * @return {?}
     */
    DetermineUploadUrl() {
        /** @type {?} */
        var baseUrl = this.config.settings.apiServer.baseUrl;
        /** @type {?} */
        var scope = this.config.settings.apiServer.scope;
        this.actualUploadToUrl = this.uploadToUrl;
        if (typeof this.workItem$ != 'undefined') {
            if (this.uploadToUrl == "") {
                this.workItem$.subscribe(w => {
                    this.actualUploadToUrl = `${baseUrl}/${scope}/api/Attachment/Add/${w.workId}`;
                    if (typeof this.workItem$ != 'undefined' && this.workItem$.getValue().workId && this.workItem$.getValue().workId != Guid.EMPTY) {
                        this.isInitialised = true;
                    }
                });
            }
        }
    }
}
E5coreUiFileUploadComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-file-upload',
                template: "<e5core-ui-file-upload-prime \r\n    [workItem$]=\"workItem$\" \r\n    [fileUpload$]=\"fileUpload$\" \r\n    [uploadToUrl]=actualUploadToUrl\r\n    [acceptedFileExtensions]=acceptedFileExtensions\r\n    [maxFileSize]=maxFileSize \r\n    [readOnly]=\"!isInitialised\"\r\n    (uploadEvent)='onUploadEvent($event)'\r\n    >\r\n</e5core-ui-file-upload-prime>",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiFileUploadComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: E5ConfigurationService }
];
E5coreUiFileUploadComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fileUpload$: [{ type: Input }],
    uploadToUrl: [{ type: Input }],
    acceptedFileExtensions: [{ type: Input }],
    maxFileSize: [{ type: Input }],
    uploadEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiFileUploadPrimeComponent {
    constructor() {
        this.uploadEvent = new EventEmitter();
        this.uploadedFiles = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onBeforeUpload(event) {
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onUploadSuccess(event) {
        this.uploadEvent.emit(event);
        this.workItem$.next(this.workItem$.getValue());
        this.fileUpload$.next(this.fileUpload$.getValue());
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onUploadError(event) {
        this.uploadEvent.emit(event);
    }
}
E5coreUiFileUploadPrimeComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-file-upload-prime',
                template: "<p-fileUpload #fubauto \r\n    class=\"ui-fileupload\" \r\n    mode=\"basic\" \r\n    name=\"filesToUpload[]\" \r\n    url=\"{{uploadToUrl}}\" \r\n    accept=\"{{acceptedFileExtensions}}\" \r\n    maxFileSize=\"{{maxFileSize}}\" \r\n    [disabled]=\"readOnly\"\r\n    (onBeforeUpload)=\"onBeforeUpload($event)\" \r\n    (onUpload)=\"onUploadSuccess($event)\" \r\n    (onError)=\"onUploadError($event)\" \r\n    auto=\"true\" \r\n    chooseLabel=\"Add\" \r\n    withCredentials=\"true\"></p-fileUpload>\r\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiFileUploadPrimeComponent.ctorParameters = () => [];
E5coreUiFileUploadPrimeComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fileUpload$: [{ type: Input }],
    uploadToUrl: [{ type: Input }],
    acceptedFileExtensions: [{ type: Input }],
    maxFileSize: [{ type: Input }],
    readOnly: [{ type: Input }],
    uploadEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiGenerateDocumentBaseComponent {
    constructor() {
        this.selectDocumentTemplateEvent = new EventEmitter();
        this.selectAttachmentTypeEvent = new EventEmitter();
        this.generateDocumentEvent = new EventEmitter();
        this.hasAttachments = false;
    }
    /**
     * @param {?} attachmentTypes
     * @return {?}
     */
    set attachmentTypes(attachmentTypes) {
        this._attachmentTypes = attachmentTypes;
        this.hasAttachments = attachmentTypes.length > 0;
    }
    /**
     * @return {?}
     */
    get attachmentTypes() { return this._attachmentTypes; }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    onGenerateDocument() {
        this.generateDocumentEvent.emit(null);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSelectDocumentTemplate(event) {
        this.selectDocumentTemplateEvent.emit(event);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSelectAttachmentType(event) {
        this.selectAttachmentTypeEvent.emit(event);
    }
    /**
     * @return {?}
     */
    get isReadOnly() {
        return (this.readonly);
    }
}
E5coreUiGenerateDocumentBaseComponent.propDecorators = {
    attachmentTypes: [{ type: Input }],
    documentTemplates: [{ type: Input }],
    showGenerateButton: [{ type: Input }],
    readonly: [{ type: Input }],
    selectDocumentTemplateEvent: [{ type: Output }],
    selectAttachmentTypeEvent: [{ type: Output }],
    generateDocumentEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiGenerateDocumentComponent {
    /**
     * @param {?} style
     * @param {?} workAttachmentTypeFoundationService
     * @param {?} workDocumentFoundationService
     */
    constructor(style$$1, workAttachmentTypeFoundationService, workDocumentFoundationService) {
        this.style = style$$1;
        this.workAttachmentTypeFoundationService = workAttachmentTypeFoundationService;
        this.workDocumentFoundationService = workDocumentFoundationService;
        this.showGenerateButton = true;
        this.readonly = false;
        this.generateDocumentEvent = new EventEmitter();
        this.selectedDocumentTemplateId = 0;
        this.selectedAttachmentTypeId = 0;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.workItem$ == null) {
            console.error('e5core-ui-generate-document [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (typeof this.workItem$ != 'undefined') {
            this.workItem$.subscribe(wim => {
                if (wim.workId != null && wim.workId != Guid.EMPTY) {
                    this.populateDocumentTemplates(wim.workId);
                    this.populateAttachmentTypes(wim.workId);
                }
            });
        }
    }
    /**
     * @param {?} wid
     * @return {?}
     */
    populateAttachmentTypes(wid) {
        this.workAttachmentTypeFoundationService.get(wid).subscribe(s => {
            this.generateDocumentComponents.forEach(element => {
                element.attachmentTypes = s;
            });
        }, error => {
            console.error(error);
        });
    }
    /**
     * @param {?} wid
     * @return {?}
     */
    populateDocumentTemplates(wid) {
        this.workDocumentFoundationService.getDocumentTemplates(wid, null).subscribe(s => {
            this.generateDocumentComponents.forEach(element => {
                element.documentTemplates = s;
            });
        }, error => {
            console.error(error);
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onGenerateDocument(event) {
        this.generateDocument();
    }
    /**
     * @return {?}
     */
    generateDocument() {
        if (this.selectedDocumentTemplateId != 0) {
            /** @type {?} */
            var wid = this.workItem$.getValue().workId;
            this.workDocumentFoundationService.create(wid, this.selectedDocumentTemplateId, this.selectedAttachmentTypeId).subscribe(s => {
                if (typeof this.workItem$ != "undefined") {
                    this.workItem$.next(this.workItem$.getValue());
                }
                if (typeof this.fileUpload$ != "undefined") {
                    this.fileUpload$.next(this.fileUpload$.getValue());
                }
                this.generateDocumentEvent.emit({ workId: wid, id: null, name: s.name, fullUrl: s.documentUrl });
            }, error => {
                console.error(error);
                throw error;
            });
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSelectDocumentTemplate(event) {
        this.selectedDocumentTemplateId = event.value.id;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSelectAttachmentType(event) {
        this.selectedAttachmentTypeId = event.value.id;
    }
}
E5coreUiGenerateDocumentComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-generate-document',
                template: `
  <span *ngIf="workItem$" [ngSwitch]="style.current()">
  <e5core-ui-generate-document-box *ngSwitchCase='0' [showGenerateButton]='showGenerateButton' [readonly]='readonly' (selectDocumentTemplateEvent)='onSelectDocumentTemplate($event)' (selectAttachmentTypeEvent)='onSelectAttachmentType($event)' (generateDocumentEvent)='onGenerateDocument($event)'></e5core-ui-generate-document-box>
  <e5core-ui-generate-document-bootstrap *ngSwitchCase='1' [showGenerateButton]='showGenerateButton' [readonly]='readonly' (selectDocumentTemplateEvent)='onSelectDocumentTemplate($event)' (selectAttachmentTypeEvent)='onSelectAttachmentType($event)' (generateDocumentEvent)='onGenerateDocument($event)'></e5core-ui-generate-document-bootstrap>
  <e5core-ui-generate-document-material *ngSwitchCase='2' [showGenerateButton]='showGenerateButton' [readonly]='readonly' (selectDocumentTemplateEvent)='onSelectDocumentTemplate($event)' (selectAttachmentTypeEvent)='onSelectAttachmentType($event)' (generateDocumentEvent)='onGenerateDocument($event)'></e5core-ui-generate-document-material>
  </span>
  <div *ngIf="!(workItem$)" class="e5core-component-error">&lt;e5core-ui-generate-document&gt; [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiGenerateDocumentComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: WorkAttachmentTypeFoundationService },
    { type: WorkDocumentFoundationService }
];
E5coreUiGenerateDocumentComponent.propDecorators = {
    workItem$: [{ type: Input }],
    fileUpload$: [{ type: Input }],
    showGenerateButton: [{ type: Input }],
    readonly: [{ type: Input }],
    generateDocumentEvent: [{ type: Output }],
    generateDocumentComponents: [{ type: ViewChildren, args: [E5coreUiGenerateDocumentBaseComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiGenerateDocumentMaterialComponent extends E5coreUiGenerateDocumentBaseComponent {
}
E5coreUiGenerateDocumentMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-generate-document-material',
                template: "<div class=\"e5core-ui-generate-document\">\n\n  <div>\n    <mat-form-field class='e5-work-field-type-input' *ngIf=\"isReadOnly\">\n      <input\n        [readonly]='true'\n        matInput\n        placeholder=\"Template to Use\"\n        name=\"template\"\n        type=\"text\"\n      />\n    </mat-form-field>\n    <mat-form-field class='e5-work-field-type-list' *ngIf=\"!isReadOnly\">\n      <mat-select placeholder=\"Template to Use\" (selectionChange)=\"onSelectDocumentTemplate($event)\">\n        <mat-option *ngFor=\"let documentTemplate of documentTemplates\" [value]=documentTemplate>{{documentTemplate.name}}</mat-option>\n      </mat-select>\n    </mat-form-field>\n  </div>\n  <div>\n    <mat-form-field class='e5-work-field-type-input' *ngIf=\"isReadOnly\">\n      <input\n        [readonly]='true'\n        matInput\n        placeholder=\"Attachment Type\"\n        name=\"attachmentType\"\n        type=\"text\"\n      />\n    </mat-form-field>\n    <mat-form-field class='e5-work-field-type-list' *ngIf=\"!isReadOnly && hasAttachments\">\n      <mat-select placeholder=\"Attachment Type\" (selectionChange)=\"onSelectAttachmentType($event)\">\n        <mat-option *ngFor=\"let attachmentType of attachmentTypes\" [value]=attachmentType>{{attachmentType.name}}</mat-option>\n      </mat-select>\n    </mat-form-field>\n  </div> \n  <button *ngIf=\"showGenerateButton\" mat-raised-button (click)=\"onGenerateDocument()\">Generate</button>\n</div>\n",
                providers: [{ provide: E5coreUiGenerateDocumentBaseComponent, useExisting: E5coreUiGenerateDocumentMaterialComponent }],
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSafePipe {
    /**
     * @param {?} sanitizer
     */
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    /**
     * @param {?} url
     * @return {?}
     */
    transform(url) {
        return this.sanitizer.bypassSecurityTrustResourceUrl(url);
    }
}
E5coreUiSafePipe.decorators = [
    { type: Pipe, args: [{ name: 'safe' },] }
];
/** @nocollapse */
E5coreUiSafePipe.ctorParameters = () => [
    { type: DomSanitizer }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiCategorizationComponent {
    /**
     * @param {?} style
     * @param {?} listService
     * @param {?} fieldDefinitonServices
     */
    constructor(style$$1, listService, fieldDefinitonServices) {
        this.style = style$$1;
        this.listService = listService;
        this.fieldDefinitonServices = fieldDefinitonServices;
        this.CATEGORY1_ID = 'Category1_Id';
        this.CATEGORY2_ID = 'Category2_Id';
        this.CATEGORY3_ID = 'Category3_Id';
        this.categorizationChange = new EventEmitter();
        this.defaultComplete = new EventEmitter();
        // Child inputs
        this.cat1List = [];
        this.cat2List = [];
        this.cat3List = [];
        this.cat123 = [0, 0, 0];
        this.catLabels = ['Business Area.', 'Product.', 'Category.'];
        // Locals
        this.lastCat123 = [0, 0, 0];
    }
    /**
     * @param {?} cat123
     * @return {?}
     */
    set categorization(cat123) {
        this.loadCategorization1(cat123);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.listService.search(this.CATEGORY1_ID).subscribe(list => {
            this.cat1List = list;
        });
        this.applyLabels();
    }
    /**
     * @return {?}
     */
    applyLabels() {
        if (this.labels && this.labels[0]) {
            this.catLabels[0] = this.labels[0];
        }
        else {
            this.fieldDefinitonServices.get('Category1_Id').subscribe(fd => this.catLabels[0] = fd.label);
        }
        if (this.labels && this.labels[1]) {
            this.catLabels[1] = this.labels[1];
        }
        else {
            this.fieldDefinitonServices.get('Category2_Id').subscribe(fd => this.catLabels[1] = fd.label);
        }
        if (this.labels && this.labels[2]) {
            this.catLabels[2] = this.labels[2];
        }
        else {
            this.fieldDefinitonServices.get('Category3_Id').subscribe(fd => this.catLabels[2] = fd.label);
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onCategoryChange($event) {
        if (this.cat123[0] !== this.lastCat123[0]) {
            // Load new Cat 2, reset cat 3
            this.listService.search(this.CATEGORY2_ID, { parentListItemId: this.cat123[0] }).subscribe(cat2List => {
                this.cat2List = cat2List;
            });
            this.lastCat123 = [this.cat123[0], undefined, undefined];
            this.cat123[1] = this.cat123[2] = undefined;
            this.cat2List = this.cat3List = [];
            $event.category2Id = $event.category3Id = 0;
        }
        if (this.cat123[1] !== this.lastCat123[1]) {
            // Load new Cat 3
            this.listService.search(this.CATEGORY3_ID, { parentListItemId: this.cat123[1] }).subscribe(cat3List => {
                this.cat3List = cat3List;
            });
            this.lastCat123 = [this.cat123[0], this.cat123[1], undefined];
            this.cat123[2] = undefined;
            this.cat3List = [];
            $event.category3Id = 0;
        }
        this.categorizationChange.emit($event);
    }
    /**
     * @private
     * @param {?} cat123
     * @return {?}
     */
    loadCategorization1(cat123) {
        this.lastCat123 = [...cat123];
        if (cat123 && cat123.length >= 1 && +(cat123[0]) !== 0) {
            // Load the Category 1 and select it
            this.listService.search(this.CATEGORY1_ID, {}).subscribe(catList => {
                /** @type {?} */
                const cat = catList.find(c => +c.id === cat123[0]);
                if (cat) {
                    this.cat1List = catList;
                    this.cat123 = [cat123[0], 0, 0];
                    this.loadCategorization2(cat123, cat123[0]);
                }
                else {
                    this.cat1List = this.cat2List = this.cat3List = [];
                    this.cat123 = [0, 0, 0];
                }
            });
        }
    }
    /**
     * @private
     * @param {?} cat123
     * @param {?} parentId
     * @return {?}
     */
    loadCategorization2(cat123, parentId) {
        if (cat123 && cat123.length >= 2 && +(cat123[1]) !== 0) {
            // Load the Category 2 and select it
            this.listService.search(this.CATEGORY2_ID, { parentListItemId: parentId }).subscribe(catList => {
                /** @type {?} */
                const cat = catList.find(c => +c.id === cat123[1]);
                this.cat2List = catList;
                if (cat) {
                    this.cat123 = [cat123[0], cat123[1], 0];
                    this.loadCategorization3(cat123, cat123[1]);
                }
                else {
                    this.cat3List = [];
                    this.cat123 = [cat123[0], 0, 0];
                }
            });
        }
    }
    /**
     * @private
     * @param {?} cat123
     * @param {?} parentId
     * @return {?}
     */
    loadCategorization3(cat123, parentId) {
        if (cat123 && cat123.length >= 3 && +(cat123[2]) !== 0) {
            // Load the Category 3 and select it
            this.listService.search(this.CATEGORY3_ID, { parentListItemId: parentId }).subscribe(catList => {
                /** @type {?} */
                const cat = catList.find(c => +c.id === cat123[2]);
                this.cat3List = catList;
                if (cat) {
                    this.cat123 = [cat123[0], cat123[1], cat123[2]];
                }
                else {
                    this.cat123 = [cat123[0], cat123[1], 0];
                }
            });
        }
    }
}
E5coreUiCategorizationComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-categorization',
                template: `
  <span [ngSwitch]="style.current()">
    <e5core-ui-categorization-box *ngSwitchCase='0' ></e5core-ui-categorization-box>
    <e5core-ui-categorization-bootstrap *ngSwitchCase='1' ></e5core-ui-categorization-bootstrap>
	<e5core-ui-categorization-material *ngSwitchCase='2'
		[hideToLevel]='hideToLevel'
		[categorization]='cat123'
		[labels]='catLabels'
		[readonly]='readonly'
		[cat1List]='cat1List' [cat2List]='cat2List' [cat3List]='cat3List'
		(catChange)='onCategoryChange($event)'></e5core-ui-categorization-material>
  </span>`
            }] }
];
/** @nocollapse */
E5coreUiCategorizationComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: ListSearchService },
    { type: TaxonomyFieldDefinitionService }
];
E5coreUiCategorizationComponent.propDecorators = {
    hideToLevel: [{ type: Input }],
    categorization: [{ type: Input }],
    labels: [{ type: Input }],
    readonly: [{ type: Input }],
    categorizationChange: [{ type: Output }],
    defaultComplete: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiCategorizationBootstrapComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiCategorizationBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-categorization-bootstrap',
                template: "<p>\n  e5core-ui-categorization-bootstrap works!\n</p>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiCategorizationBootstrapComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiCategorizationBoxComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiCategorizationBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-categorization-box',
                template: "<p>\n  e5core-ui-categorization-box works!\n</p>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiCategorizationBoxComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiCategorizationBase {
    constructor() {
        this.catChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    onChange() {
        this.catChange.emit((/** @type {?} */ ({
            category1Id: this.categorization[0] | 0,
            category2Id: this.categorization[1] | 0,
            category3Id: this.categorization[2] | 0
        })));
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        /** @type {?} */
        let cat = (this.cat1List) ? (this.cat1List.find(i => i.id == this.categorization[0])) : null;
        this.cat1Value = cat ? cat.label : undefined;
        cat = (this.cat2List) ? (this.cat2List.find(i => i.id == this.categorization[1])) : null;
        this.cat2Value = cat ? cat.label : undefined;
        cat = (this.cat3List) ? (this.cat3List.find(i => i.id == this.categorization[2])) : null;
        this.cat3Value = cat ? cat.label : undefined;
    }
}
E5coreUiCategorizationBase.propDecorators = {
    categorization: [{ type: Input }],
    labels: [{ type: Input }],
    readonly: [{ type: Input }],
    cat1List: [{ type: Input }],
    cat2List: [{ type: Input }],
    cat3List: [{ type: Input }],
    hideToLevel: [{ type: Input }],
    catChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiCategorizationMaterialComponent extends E5coreUiCategorizationBase {
    constructor() {
        super();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.cat1List.find(i => i.id === this.categorization[0]);
    }
}
E5coreUiCategorizationMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-categorization-material',
                template: "<div *ngIf=\"!readonly\">\n  <mat-form-field class='e5core-ui-categorization-cat1' *ngIf='(+hideToLevel || 0) < 1'>\n    <mat-select [(ngModel)]=\"categorization[0]\" placeholder=\"{{ labels[0] || 'Business Area' }}\" (selectionChange)=\"onChange()\"> \n      <mat-option *ngIf=\"cat1List.length == 0\" [value]=\"\">(Empty)</mat-option>\n      <mat-option *ngFor=\"let item of cat1List\" [value]=\"+item.id\">{{item.label}}</mat-option>\n    </mat-select>\n  </mat-form-field>\n\n  <mat-form-field class='e5core-ui-categorization-cat2' *ngIf='(+hideToLevel || 0) < 2'>\n    <mat-select [(ngModel)]=\"categorization[1]\" placeholder=\"{{ labels[1] || 'Product' }}\" (selectionChange)=\"onChange()\">    \n      <mat-option *ngIf=\"cat2List.length == 0\" [value]=\"\">(Empty)</mat-option>\n      <mat-option *ngFor=\"let item of cat2List\" [value]=\"+item.id\">{{item.label}}</mat-option>\n    </mat-select>\n  </mat-form-field>\n\n  <mat-form-field class='e5core-ui-categorization-cat3' *ngIf='(+hideToLevel || 0) < 3'>\n    <mat-select [(ngModel)]=\"categorization[2]\" placeholder=\"{{ labels[2] || 'Category' }}\" (selectionChange)=\"onChange()\">    \n      <mat-option *ngIf=\"cat3List.length == 0\" [value]=\"\">(Empty)</mat-option>\n      <mat-option *ngFor=\"let item of cat3List\" [value]=\"+item.id\">{{item.label}}</mat-option>\n    </mat-select>\n  </mat-form-field>\n</div>\n<div *ngIf=\"readonly\">\n  <mat-form-field class='e5core-ui-categorization-cat1' *ngIf='(+hideToLevel || 0) < 1'>\n    <input matInput [readonly]='true' placeholder=\"{{ labels[0] || 'Business Area' }}\" [(ngModel)]=\"cat1Value\" />\n  </mat-form-field>\n  <mat-form-field class='e5core-ui-categorization-cat2' *ngIf='(+hideToLevel || 0) < 2'>\n    <input matInput [readonly]='true' placeholder=\"{{ labels[1] || 'Product' }}\" [(ngModel)]=\"cat2Value\" />\n  </mat-form-field>\n  <mat-form-field class='e5core-ui-categorization-cat3'  *ngIf='(+hideToLevel || 0) < 3'>\n    <input matInput [readonly]='true' placeholder=\"{{ labels[2] || 'Category' }}\" [(ngModel)]=\"cat3Value\" />\n  </mat-form-field>\n</div>\n\n ",
                styles: ["mat-form-field{margin-right:20pt;display:block}"]
            }] }
];
/** @nocollapse */
E5coreUiCategorizationMaterialComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiGenerateDocumentBoxComponent extends E5coreUiGenerateDocumentBaseComponent {
}
E5coreUiGenerateDocumentBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-generate-document-box',
                template: "<div class='e5-component'>\n  <div class='e5-title'>e5core-ui-generate-document</div>\n  <div class='e5-content'>    \n    <div>\n      Template to Use\n      <input *ngIf=\"isReadOnly\"\n        [readonly]='true'\n        name=\"template\"\n        type=\"text\"\n      />\n      <select *ngIf=\"!isReadOnly\" (onchange)=\"onSelectDocumentTemplate($event)\">\n        <option *ngFor=\"let documentTemplate of documentTemplates\" [value]=documentTemplate>{{documentTemplate.name}}</option>\n      </select>\n    </div>\n    <div>\n      Attachment Type\n      <input  *ngIf=\"isReadOnly\"\n        [readonly]='true'\n        name=\"attachmentType\"\n        type=\"text\"\n      />\n      <select *ngIf=\"!isReadOnly && hasAttachments\" (onchange)=\"onSelectAttachmentType($event)\">\n        <option *ngFor=\"let attachmentType of attachmentTypes\" [value]=attachmentType>{{attachmentType.name}}</option>\n      </select>\n    </div> \n    <button *ngIf=\"showGenerateButton\" mat-raised-button (click)=\"onGenerateDocument()\">Generate</button>\n  </div>\n</div>",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiGenerateDocumentBootstrapComponent extends E5coreUiGenerateDocumentBaseComponent {
}
E5coreUiGenerateDocumentBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-generate-document-bootstrap',
                template: "<div class='e5-component'>\n  <div class='e5-content'>\n\n    <div class='form-group'>\n      <label for='documentTemplate'>Template to Use</label>\n      <input\n        *ngIf=\"isReadOnly\"\n        [readonly]='true'\n        name=\"documentTemplate\"\n        type=\"text\"/>\n\n      <select name=\"documentTemplate\" *ngIf=\"!isReadOnly\" (onchange)=\"onSelectDocumentTemplate($event)\">\n        <option *ngFor=\"let documentTemplate of documentTemplates\" [value]=documentTemplate>{{documentTemplate.name}}</option>\n      </select>\n    </div>\n\n    <div class='form-group'>\n      <label for='attachmentType'>Attachment Type</label>\n      <input\n        *ngIf=\"isReadOnly\"\n        [readonly]='true'\n        name=\"attachmentType\"\n        type=\"text\"/>\n\n        <select name=\"attachmentType\" *ngIf=\"!isReadOnly && hasAttachments\" (onchange)=\"onSelectAttachmentType($event)\">\n          <option *ngFor=\"let attachmentType of attachmentTypes\" [value]=attachmentType>{{attachmentType.name}}</option>\n        </select>\n    </div>\n    <button *ngIf=\"showGenerateButton\" (click)=\"onGenerateDocument()\">Generate</button>\n  </div>\n</div>\n",
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWebdavWeburiAttachmentViewerComponent extends E5coreUiAttachmentViewerBaseComponent {
    /**
     * @param {?} e5ConfigurationService
     * @param {?} changeDetectorRef
     */
    constructor(e5ConfigurationService, changeDetectorRef) {
        super(e5ConfigurationService, changeDetectorRef);
        this.e5ConfigurationService = e5ConfigurationService;
        this.changeDetectorRef = changeDetectorRef;
        this.forceInline = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    showPopViewer(viewerModel) {
        this.forceInline = false;
        /** @type {?} */
        var fileName = (viewerModel.name != null) ? viewerModel.name.toLowerCase().trim() : viewerModel.fullUrl.toLowerCase().trim();
        if (fileName.endsWith(".doc") || fileName.endsWith(".docx") ||
            fileName.endsWith(".xls") || fileName.endsWith(".xlsx") ||
            fileName.endsWith(".ppt") || fileName.endsWith(".pptx")) {
            /** @type {?} */
            var filePrefix = "";
            if (fileName.endsWith(".doc") || fileName.endsWith(".docx")) {
                filePrefix = "ms-word:ofe|u|";
            }
            if (fileName.endsWith(".xls") || fileName.endsWith(".xlsx")) {
                filePrefix = "ms-excel:ofe|u|";
            }
            if (fileName.endsWith(".ppt") || fileName.endsWith(".pptx")) {
                filePrefix = "ms-powerpoint:ofe|u|";
            }
            viewerModel.fullUrl = filePrefix + viewerModel.fullUrl;
            this.forceInline = true;
            this.showInlineViewer(viewerModel);
            return;
        }
        this.constructViewerUrl(viewerModel, (vm, url) => this.performWindowPopup(vm, url));
    }
    /**
     * @param {?} viewerModel
     * @param {?} nextFunction
     * @return {?}
     */
    constructViewerUrl(viewerModel, nextFunction) {
        this.attachmentUrl = viewerModel.fullUrl;
        this.changeDetectorRef.detectChanges();
        setTimeout(() => {
            this.attachmentUrl = "";
            this.changeDetectorRef.detectChanges();
        }, 200);
        if (nextFunction)
            nextFunction(viewerModel, this.attachmentUrl);
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    raiseEvent(viewerModel) {
        this.viewerDisplayedEvent.emit({ workId: viewerModel.workId, type: "WebDavWebUrl", attachmentId: null, fullUrl: viewerModel.fullUrl, name: null });
    }
}
E5coreUiWebdavWeburiAttachmentViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-webdav-weburi-attachment-viewer',
                template: `

    <span *ngIf="1==+behaviourType || forceInline">
        <iframe *ngIf="!(attachmentUrl == '')" [src]="attachmentUrl | safe" style="width:0;height:0;border:0; border:none; position: absolute;"></iframe>
    </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: E5coreUiAttachmentViewerBaseComponent, useExisting: E5coreUiWebdavWeburiAttachmentViewerComponent }]
            }] }
];
/** @nocollapse */
E5coreUiWebdavWeburiAttachmentViewerComponent.ctorParameters = () => [
    { type: E5ConfigurationService },
    { type: ChangeDetectorRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiE5AttachmentViewerComponent extends E5coreUiAttachmentViewerBaseComponent {
    /**
     * @param {?} e5ConfigurationService
     * @param {?} configurationScopeService
     * @param {?} changeDetectorRef
     */
    constructor(e5ConfigurationService, configurationScopeService, changeDetectorRef) {
        super(e5ConfigurationService, changeDetectorRef);
        this.e5ConfigurationService = e5ConfigurationService;
        this.configurationScopeService = configurationScopeService;
        this.changeDetectorRef = changeDetectorRef;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @param {?} viewerModel
     * @param {?} nextFunction
     * @return {?}
     */
    constructViewerUrl(viewerModel, nextFunction) {
        //  "DocAttachmentId":"36",
        //  "DocName":"Sleepy.jpg",
        //  "DocUrl":"http://vlane5dev2016:81/sites/e5dev/e5%20Attachments/2/Sleepy.jpg",
        //  "WorkItemId":"7657fec3-1e74-11e7-a2c4-00155d2aaa1d",
        //  "Extension":"jpg",
        //  "DocTypeId":2,
        //  "DocId":2005,
        //  "DocTypeName":"Public Images"
        // format URL e.g.
        // "/sites/travel/_layouts/e5/WorkAttachmentViewer.aspx?id=6da5fd96-5462-11e6-815d-90e2ba57fbe1&source=FindWork&auto=false&attachments=6da5fd96-5462-11e6-815d-90e2ba57fbe1;23319|"
        // WorkAttachmentViewer.aspx?id=13a11814-1efb-11e7-8144-000d3aa0265d&source=FindWork&auto=false&attachments=13a11814-1efb-11e7-8144-000d3aa0265d;17627|
        this.configurationScopeService.get(this.e5ConfigurationService.settings.apiServer.scope).subscribe(s => {
            /** @type {?} */
            var documentStoreBaseUrl = s.siteUrl;
            /** @type {?} */
            var attachmentIdUrlSegment = "";
            if (viewerModel.id != null)
                attachmentIdUrlSegment = viewerModel.workId + ";" + viewerModel.id + "|";
            this.attachmentUrl = documentStoreBaseUrl + // e.g http://vlane5dev2016:81/sites/e5dev/
                "/_layouts/15/e5/WorkAttachmentViewer.aspx" +
                "?id=" + viewerModel.workId +
                "&source=FindWork&auto=false" +
                "&attachments=" + attachmentIdUrlSegment;
            if (nextFunction)
                nextFunction(viewerModel, this.attachmentUrl);
        }, error => {
            console.error(error);
        });
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    raiseEvent(viewerModel) {
        this.viewerDisplayedEvent.emit({ workId: viewerModel.workId, type: "E5SharepointAttachment", attachmentId: viewerModel.id, fullUrl: viewerModel.fullUrl, name: null });
    }
}
E5coreUiE5AttachmentViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-e5-attachment-viewer',
                template: `
    <span *ngIf="1==+behaviourType">
    <iframe *ngIf="!(attachmentUrl == '')" [src]="attachmentUrl | safe"></iframe>
    </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: E5coreUiAttachmentViewerBaseComponent, useExisting: E5coreUiE5AttachmentViewerComponent }]
            }] }
];
/** @nocollapse */
E5coreUiE5AttachmentViewerComponent.ctorParameters = () => [
    { type: E5ConfigurationService },
    { type: ConfigurationScopeService },
    { type: ChangeDetectorRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWeburiAttachmentViewerComponent extends E5coreUiAttachmentViewerBaseComponent {
    /**
     * @param {?} e5ConfigurationService
     * @param {?} changeDetectorRef
     */
    constructor(e5ConfigurationService, changeDetectorRef) {
        super(e5ConfigurationService, changeDetectorRef);
        this.e5ConfigurationService = e5ConfigurationService;
        this.changeDetectorRef = changeDetectorRef;
        this.forceInline = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    showPopViewer(viewerModel) {
        this.forceInline = false;
        /** @type {?} */
        var fileName = (viewerModel.name != null) ? viewerModel.name.toLowerCase().trim() : viewerModel.fullUrl.toLowerCase().trim();
        if (fileName.endsWith(".doc") || fileName.endsWith(".docx") ||
            fileName.endsWith(".xls") || fileName.endsWith(".xlsx") ||
            fileName.endsWith(".ppt") || fileName.endsWith(".pptx")) {
            /** @type {?} */
            var filePrefix = "";
            if (fileName.endsWith(".doc") || fileName.endsWith(".docx")) {
                filePrefix = "ms-word:nft|u|";
            }
            if (fileName.endsWith(".xls") || fileName.endsWith(".xlsx")) {
                filePrefix = "ms-excel:nft|u|";
            }
            if (fileName.endsWith(".ppt") || fileName.endsWith(".pptx")) {
                filePrefix = "ms-powerpoint:nft|u|";
            }
            viewerModel.fullUrl = filePrefix + viewerModel.fullUrl;
            this.forceInline = true;
            this.showInlineViewer(viewerModel);
            return;
        }
        this.constructViewerUrl(viewerModel, (vm, url) => this.performWindowPopup(vm, url));
    }
    /**
     * @param {?} viewerModel
     * @param {?} nextFunction
     * @return {?}
     */
    constructViewerUrl(viewerModel, nextFunction) {
        this.attachmentUrl = viewerModel.fullUrl;
        if (nextFunction)
            nextFunction(viewerModel, this.attachmentUrl);
    }
    /**
     * @param {?} viewerModel
     * @return {?}
     */
    raiseEvent(viewerModel) {
        this.viewerDisplayedEvent.emit({ workId: viewerModel.workId, type: "WebUrl", attachmentId: null, fullUrl: viewerModel.fullUrl, name: null });
    }
}
E5coreUiWeburiAttachmentViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-weburi-attachment-viewer',
                template: `

    <span *ngIf="1==+behaviourType || forceInline">
        <iframe *ngIf="!(attachmentUrl == '')" [src]="attachmentUrl | safe" style="width:0;height:0;border:0; border:none; position: absolute;"></iframe>
    </span>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{ provide: E5coreUiAttachmentViewerBaseComponent, useExisting: E5coreUiWeburiAttachmentViewerComponent }]
            }] }
];
/** @nocollapse */
E5coreUiWeburiAttachmentViewerComponent.ctorParameters = () => [
    { type: E5ConfigurationService },
    { type: ChangeDetectorRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DocumentDataSourceService {
    /**
     * @param {?} uiDocumentService
     */
    constructor(uiDocumentService) {
        this.uiDocumentService = uiDocumentService;
        this.folderName = "";
        this.fieldsToShow = null;
        this.searchOptions = {};
    }
    /**
     * @return {?}
     */
    defaultOptions() {
        return (this.searchOptions);
    }
    /**
     * @param {?} options
     * @return {?}
     */
    setDefaultOptions(options) {
        this.searchOptions = Object.assign({}, options); // clone
    }
    /**
     * @param {?} libraryId
     * @param {?} folderName
     * @param {?} includeSelect
     * @param {?} fieldsToShow
     * @param {?} searchText
     * @return {?}
     */
    setLibrary(libraryId, folderName, includeSelect, fieldsToShow, searchText) {
        this.libraryId = libraryId;
        this.folderName = folderName;
        this.includeSelect = includeSelect;
        this.fieldsToShow = fieldsToShow;
        this.searchText = searchText;
        return (this);
    }
    /**
     * @return {?}
     */
    columns() {
        /** @type {?} */
        let columns = this.fieldsToShow.filter(f => f.display).map(sf => (/** @type {?} */ ({
            code: sf.fieldCode,
            label: sf.name,
            type: "Input",
            status: DataSourceColumnStatus.Selected
        })));
        columns = this.addOptionalColumns(columns);
        return of(columns);
    }
    /**
     * @private
     * @param {?} columns
     * @return {?}
     */
    addOptionalColumns(columns) {
        if (this.includeSelect)
            // Add to start
            columns.unshift((/** @type {?} */ ({
                label: "",
                code: "ActionSelect",
                type: "ActionSelect",
                status: DataSourceColumnStatus.Selected
            })));
        return (columns);
    }
    /**
     * @param {?} page
     * @param {?} pageSize
     * @param {?} optionsIn
     * @return {?}
     */
    read(page, pageSize, optionsIn) {
        /** @type {?} */
        let options = Object.assign({}, this.searchOptions, optionsIn);
        /** @type {?} */
        var returnFields = "";
        if (this.fieldsToShow && typeof (this.fieldsToShow) !== 'undefined') {
            //var fieldsToRetrieve = fieldsToShow.reduce((fid, fs) => [ ...fid, ...fs.fieldId ], <string[]> []);
            //.join(",")
            /** @type {?} */
            var fieldsToRetrieve = this.fieldsToShow.filter(f => f.display).reduce(function (a, b) { return [a, b.fieldId]; }, []).toString();
            if (fieldsToRetrieve.length > 0)
                fieldsToRetrieve = fieldsToRetrieve.substring(1);
            returnFields = fieldsToRetrieve;
        }
        /** @type {?} */
        var orderBy = (options && options.orderBy) ? options.orderBy : "";
        pageSize = (pageSize) ? pageSize : 10;
        //return this.uiDocumentService.getAll(this.libraryId, returnFields, page, pageSize, "", this.searchText, orderBy)
        return this.uiDocumentService.getAll(this.libraryId, {
            returnFields: returnFields,
            page: page,
            pageSize: pageSize,
            orderBy: "",
            searchBy: this.searchText,
            filter: "",
            folderName: ""
        })
            .pipe(map(results => {
            return {
                total: results.length,
                data: this.mapResults(results)
            };
        }));
    }
    /**
     * @private
     * @param {?} result
     * @return {?}
     */
    mapResults(result) {
        /** @type {?} */
        let results = [];
        if (result && result.length > 0) {
            for (var r = 0; r < result.length; r++) {
                /** @type {?} */
                let dataRow = result[r];
                /** @type {?} */
                let objectRow = {};
                for (var c = 0; c < this.fieldsToShow.length; c++) {
                    /** @type {?} */
                    let field = this.fieldsToShow[c];
                    objectRow[field.fieldCode] = dataRow.fields[field.fieldCode];
                }
                results[results.length] = objectRow;
            }
        }
        return results;
    }
    // In order to use the foundation service we need to map the DataSourceQuery into 
    //	the underlying foundation query
    // 	{
    // 		"filters": [
    // 	  		{
    // 				"field": "string",
    // 				"operator": "string",
    // 				"value": "string"
    // 	  		}
    // 		],
    // 		"logic": "string"
    // 	}
    /**
     * @private
     * @param {?} query
     * @return {?}
     */
    mapQueryToFilterBy(query) {
        /** @type {?} */
        let filterBy = {};
        if (query && query.Expressions && query.Expressions.length > 0) {
            /** @type {?} */
            let filters = query.Expressions
                .filter(e => e.Value)
                .map(e => {
                return {
                    field: e.Field,
                    value: e.Value
                };
            });
            filterBy = {
                filters: filters
            };
        }
        return (filterBy);
    }
}
DocumentDataSourceService.decorators = [
    { type: Injectable, args: [{
                providedIn: null //'root'
            },] }
];
/** @nocollapse */
DocumentDataSourceService.ctorParameters = () => [
    { type: UiDocumentService }
];
/** @nocollapse */ DocumentDataSourceService.ngInjectableDef = defineInjectable({ factory: function DocumentDataSourceService_Factory() { return new DocumentDataSourceService(inject(UiDocumentService)); }, token: DocumentDataSourceService, providedIn: null });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSelectFromListBaseComponent {
    constructor() {
        this.listItemViewEvent = new EventEmitter();
        this.listItemSelectEvent = new EventEmitter();
        this.searchEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     *  Pass the open work item event on to any listener.
     * @param {?} data the row of data, including the "Id" from the table.
     * @return {?}
     */
    onOpen(data) {
        this.listItemViewEvent.emit({ event: event, element: data });
    }
    /**
     *  Pass the open link on to any listener.
     * @param {?} data the row of data, including the "Id" from the table.
     * @return {?}
     */
    onSelect(data) {
        this.listItemSelectEvent.emit({ event: event, element: data });
    }
    /**
     *  Pass the open link on to any listener.
     * @param {?} link
     * @return {?}
     */
    onLink(link) {
        this.listItemViewEvent.emit({ event: event, element: link });
    }
    /**
     * Execute a search with the required search expression values.
     * @return {?}
     */
    search() {
        if (this.searchText)
            this.searchEvent.emit(this.searchText);
    }
    /**
     * Clear the search results.
     * @return {?}
     */
    reset() {
    }
    /**
     * Refresh the search results at the current page.
     * @return {?}
     */
    refresh() {
    }
}
E5coreUiSelectFromListBaseComponent.propDecorators = {
    datasource: [{ type: Input }],
    query: [{ type: Input }],
    autoSearch: [{ type: Input }],
    pagesizes: [{ type: Input }],
    error: [{ type: Input }],
    listItemViewEvent: [{ type: Output }],
    listItemSelectEvent: [{ type: Output }],
    searchEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSelectFromListMaterialComponent extends E5coreUiSelectFromListBaseComponent {
    constructor() {
        super();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiSelectFromListMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-select-from-list-material',
                template: "<div class=\"e5core-ui-work-attachments\">\n\n  <div>\n      <mat-form-field class='e5-work-field-type-list'>\n          <input\n          matInput\n          placeholder=\"Search term\"\n          type=\"text\"\n          [(ngModel)]=\"searchText\"\n        />\n      </mat-form-field>\n      <button mat-raised-button (click)=\"search()\">Search</button>\n    </div>\n\n  <span *ngIf=\"!error\">\n    <e5core-ui-datagrid #SearchResults\n      [datasource]='datasource'  [query]='query' [autoSearch]='autoSearch' [pagesizes]=\"pagesizes\"\n      (open)='onOpen($event)' (link)='onLink($event)' (select)='onSelect($event)'>\n    </e5core-ui-datagrid>\n  </span>\n  <div *ngIf=\"error\" class=\"e5core-component-error\">{{error}}</div>\n  \n</div>",
                styles: ["table.e5core-ui-work-attachments{width:100%}table.e5core-ui-work-attachments tr th:nth-child(1),table.e5core-ui-work-attachments tr th:nth-child(2){width:50pt}.e5core-ui-work-attachments .mat-spinner-holder{width:100%;padding:20pt;position:relative;top:30px;height:1px}.e5core-ui-work-attachments .mat-paginator{margin-top:0;background:0 0}"]
            }] }
];
/** @nocollapse */
E5coreUiSelectFromListMaterialComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiSelectFromListComponent {
    /**
     * @param {?} config
     * @param {?} style
     * @param {?} datasource
     */
    constructor(config, style$$1, datasource) {
        this.config = config;
        this.style = style$$1;
        this.datasource = datasource;
        this.folderName = "";
        this.fieldsToShow = null; //Refer to http://blog.softartisans.com/2009/12/08/list-of-internal-names-for-sharepoint-fields
        //Refer to http://blog.softartisans.com/2009/12/08/list-of-internal-names-for-sharepoint-fields
        this.includeSelect = true;
        this.query = null;
        this.pagesizes = [5, 10, 25, 50];
        this.autoSearch = true;
        this.readonly = false;
        this.listItemViewEvent = new EventEmitter();
        this.listItemSelectEvent = new EventEmitter();
        this.searchEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.workItem$ == 'undefined') {
            console.error('e5core-ui-select-from-list [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (typeof this.workItem$ != 'undefined') {
            this.workItem$.subscribe(w => {
                this.updateData();
            });
        }
        if (this.libraryId == null) {
            this.error = 'e5core-ui-search-results [searchDefinitionId] must be specified';
            console.error(this.error);
            return;
        }
        this.datasource.setLibrary(this.libraryId, this.folderName, this.includeSelect, this.fieldsToShow, this.searchText);
        /** @type {?} */
        let options = this.datasource.defaultOptions();
        this.datasource.setDefaultOptions(options);
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @return {?}
     */
    refresh() {
        this.selectFromListMaterialComponent.refresh();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onListItemViewEvent(event) {
        this.listItemViewEvent.emit({ workId: null, type: "E5SharepointAttachment", attachmentId: null, fullUrl: event.element.fullUrl, name: event.element.fullUrl });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onListItemSelectEvent(event) {
        this.listItemSelectEvent.emit(event);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onSearchEvent(event) {
        debugger;
        this.searchText = event;
        this.datasource.setLibrary(this.libraryId, this.folderName, this.includeSelect, this.fieldsToShow, this.searchText);
    }
    /**
     * @private
     * @return {?}
     */
    updateData() {
    }
}
E5coreUiSelectFromListComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-select-from-list',
                template: `
  <span *ngIf="workItem$" [ngSwitch]="style.current()">
    <e5core-ui-select-from-list-material *ngSwitchCase='2' [datasource]='datasource' [pagesizes]="pagesizes"  [query]='query' [autoSearch]='autoSearch' (listItemViewEvent)='onListItemViewEvent($event)' (listItemSelectEvent)='onListItemSelectEvent($event)' (searchEvent)='onSearchEvent($event)'></e5core-ui-select-from-list-material>
  </span>
  <div *ngIf="!(workItem$)" class="e5core-component-error">&lt;e5core-ui-select-from-list&gt; [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                //changeDetection: ChangeDetectionStrategy.OnPush
                providers: [
                    DocumentDataSourceService
                ]
            }] }
];
/** @nocollapse */
E5coreUiSelectFromListComponent.ctorParameters = () => [
    { type: E5ConfigurationService },
    { type: UiStyleService },
    { type: DocumentDataSourceService }
];
E5coreUiSelectFromListComponent.propDecorators = {
    workItem$: [{ type: Input }],
    libraryId: [{ type: Input }],
    folderName: [{ type: Input }],
    fieldsToShow: [{ type: Input }],
    includeSelect: [{ type: Input }],
    query: [{ type: Input }],
    pagesizes: [{ type: Input }],
    autoSearch: [{ type: Input }],
    readonly: [{ type: Input }],
    listItemViewEvent: [{ type: Output }],
    listItemSelectEvent: [{ type: Output }],
    searchEvent: [{ type: Output }],
    selectFromListMaterialComponent: [{ type: ViewChild, args: [E5coreUiSelectFromListMaterialComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkRelatedItemsBaseComponent {
    constructor() {
        this.workItemSelectEvent = new EventEmitter();
        this.pageEvent = new EventEmitter();
        this.attachmentSelectEvent = new EventEmitter();
        this.categorisationChangeEvent = new EventEmitter();
        this.createChildWorkItemEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} treeTableDataModel
     * @return {?}
     */
    onWorkItemSelect(treeTableDataModel) {
        this.workItemSelectEvent.emit({ workId: treeTableDataModel.id, reference: null, type: "related" });
    }
    /**
     * @param {?} treeTableDataModel
     * @return {?}
     */
    onAttachmentSelect(treeTableDataModel) {
        this.attachmentSelectEvent.emit({ workId: treeTableDataModel.id, type: "E5SharepointAttachment", attachmentId: null, fullUrl: null, name: null });
    }
    /**
     * @return {?}
     */
    createChildWorkItem() {
        this.createChildWorkItemEvent.emit();
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onCategorizationChange($event) {
        if ($event.category1Id > 0 && $event.category2Id > 0 && $event.category3Id > 0)
            this.categorisationChangeEvent.emit($event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    selectChildCategory($event) {
        this.categorisationChangeEvent.emit({ category1Id: $event.value.category1Id, category2Id: $event.value.category2Id, category3Id: $event.value.category3Id });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onPageEvent(event) {
        this.pageEvent.emit(event);
    }
}
E5coreUiWorkRelatedItemsBaseComponent.propDecorators = {
    treeData: [{ type: Input }],
    length: [{ type: Input }],
    labels: [{ type: Input }],
    pagesizes: [{ type: Input }],
    readonly: [{ type: Input }],
    childWorkItemCategories: [{ type: Input }],
    createButtonText: [{ type: Input }],
    showCreateChildButton: [{ type: Input }],
    showDefinedChildrenOnly: [{ type: Input }],
    workItemSelectEvent: [{ type: Output }],
    pageEvent: [{ type: Output }],
    attachmentSelectEvent: [{ type: Output }],
    categorisationChangeEvent: [{ type: Output }],
    createChildWorkItemEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PrimeTreeTableModel {
    constructor() {
        this.data = new TreeTableDataModel();
        this.children = [];
    }
}
class TreeTableDataModel {
    constructor() {
        this.fieldValues = [];
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class KeyValuePair {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkRelatedItemsComponent {
    /**
     * @param {?} workItemService
     * @param {?} fieldDefinitonServices
     * @param {?} changeDetectorRef
     */
    constructor(workItemService, fieldDefinitonServices, changeDetectorRef) {
        this.workItemService = workItemService;
        this.fieldDefinitonServices = fieldDefinitonServices;
        this.changeDetectorRef = changeDetectorRef;
        this.findId = 0;
        this.createButtonText = "Create";
        this.fieldsToShow = null;
        this.showCreateChildButton = true;
        this.showDefinedChildrenOnly = true;
        this.workItemSelectEvent = new EventEmitter();
        this.attachmentSelectEvent = new EventEmitter();
        this.categorisationChangeEvent = new EventEmitter();
        this.createChildWorkItemEvent = new EventEmitter();
        this.labels = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.workItem$ == 'undefined') {
            console.error('e5core-ui-work-related-items [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (this.fieldsToShow) {
            this.fieldsToShow.forEach(element => {
                this.setLabel(element);
            });
        }
        if (typeof this.workItem$ != 'undefined') {
            this.workItem$.subscribe(wim => {
                if (wim.workId != null && wim.workId != Guid.EMPTY) {
                    this.workId = wim.workId;
                    this.populateWorkRelatedItems(this.workId);
                    if (this.showDefinedChildrenOnly)
                        this.populateWorkClassChildren(wim.workId.toString());
                }
            });
        }
    }
    /**
     * @private
     * @param {?} findField
     * @return {?}
     */
    setLabel(findField) {
        if (findField.value == "") {
            /** @type {?} */
            var index = this.labels.length;
            this.labels[this.labels.length] = "";
            this.fieldDefinitonServices.get(findField.key).subscribe(fd => {
                this.labels[index] = fd.label;
                this.changeDetectorRef.detectChanges();
            });
        }
        else {
            this.labels[this.labels.length] = findField.value;
        }
    }
    /**
     * @private
     * @param {?} wid
     * @return {?}
     */
    populateWorkClassChildren(wid) {
        this.workItemService.getWorkWorkClassChildren(wid).subscribe(s => {
            this.workRelatedItemsComponents.forEach(element => {
                element.childWorkItemCategories = s;
            });
        }, error => {
            console.error(error);
        });
    }
    /**
     * @private
     * @param {?} wid
     * @return {?}
     */
    populateWorkRelatedItems(wid) {
        this.workItemService.getWorkRelatedItems(wid, {
            findId: this.findId,
            pageSize: this.selectedPage.pageSize,
            pageNo: this.selectedPage.pageIndex,
            doSearchFromRoot: true
        }).subscribe(s => {
            /** @type {?} */
            var rootModel = this.convertToUiModel(s.relatedItems);
            this.workRelatedItemsComponents.forEach(element => {
                element.length = s.total;
                element.treeData = (/** @type {?} */ ([rootModel]));
                this.changeDetectorRef.detectChanges();
            });
            this.changeDetectorRef.detectChanges();
        }, error => {
            console.error(error);
        });
    }
    /**
     * @private
     * @param {?} apiModels
     * @return {?}
     */
    convertToUiModel(apiModels) {
        if (!apiModels)
            return; // Nothing to do
        // Nothing to do
        /** @type {?} */
        var current = apiModels.filter(u => u.id == this.workId);
        if (current.length == 0)
            return;
        /** @type {?} */
        var parent = apiModels.filter(u => u.id == current[0].parentId);
        if (current[0].parentId == Guid.EMPTY)
            parent = current;
        /** @type {?} */
        var children = apiModels.filter(u => u.parentId == this.workId);
        /** @type {?} */
        var rootModel = new PrimeTreeTableModel();
        rootModel.data.id = parent[0].id;
        rootModel.data.attachmentCount = parent[0].attachmentCount;
        rootModel.data.parentId = parent[0].parentId;
        rootModel.expanded = true;
        this.populateDataFields(rootModel.data, parent[0]);
        this.processChildren(rootModel, children, apiModels);
        return rootModel;
    }
    /**
     * @private
     * @param {?} parent
     * @param {?} children
     * @param {?} apiModels
     * @return {?}
     */
    processChildren(parent, children, apiModels) {
        for (let i = 0; i < children.length; i++) {
            /** @type {?} */
            var child = children[i];
            /** @type {?} */
            var model = new PrimeTreeTableModel();
            model.data.id = child.id;
            model.data.attachmentCount = child.attachmentCount;
            model.data.parentId = child.parentId;
            this.populateDataFields(model.data, child);
            parent.children[parent.children.length] = model;
            /** @type {?} */
            var moreChildren = apiModels.filter(u => u.parentId == child.id);
            if (moreChildren.length > 0) {
                this.processChildren(model, moreChildren, apiModels);
            }
        }
    }
    /**
     * @private
     * @param {?} modelData
     * @param {?} child
     * @return {?}
     */
    populateDataFields(modelData, child) {
        if (!this.fieldsToShow) {
            modelData.fieldValues = [];
        }
        else {
            for (var i = 0; i < this.fieldsToShow.length; i++) {
                /** @type {?} */
                var findField = this.fieldsToShow[i];
                /** @type {?} */
                var field = child.fieldValues.filter(u => u.key == findField.key);
                if (field == null || field.length == 0) {
                    field = [{ key: findField.key, value: "" }];
                }
                /** @type {?} */
                var keyValuePair = new KeyValuePair();
                keyValuePair.key = field[0].key;
                keyValuePair.value = field[0].value;
                modelData.fieldValues[modelData.fieldValues.length] = keyValuePair;
            }
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
    /**
     * @param {?} selectedCategory
     * @return {?}
     */
    CreateChildWorkItem(selectedCategory) {
        if (!this.workId) {
            console.error("e5core-ui-work-related-items has no work item.");
            return;
        }
        /** @type {?} */
        var workItemCreateModel = {
            category1Id: selectedCategory.category1Id,
            category2Id: selectedCategory.category2Id,
            category3Id: selectedCategory.category3Id,
            workItemFields: [
                {
                    fieldId: "Parent_id",
                    fieldValue: this.workId,
                    fieldType: "Guid"
                }
            ]
        };
        this.workItemService.create(workItemCreateModel).subscribe(s => {
            this.createChildWorkItemEvent.emit({ workId: s.id, reference: s.reference, type: "related" });
            this.populateWorkRelatedItems(this.workId);
        }, error => {
            console.error(error);
        });
    }
    /**
     * @return {?}
     */
    onCreateChildWorkItem() {
        this.CreateChildWorkItem(this.selectedCategory);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onCategorizationChange($event) {
        this.selectedCategory = $event;
        this.categorisationChangeEvent.emit($event);
    }
    /**
     * @param {?} openWorkEvent
     * @return {?}
     */
    onWorkItemSelect(openWorkEvent) {
        this.workItemSelectEvent.emit(openWorkEvent);
    }
    /**
     * @param {?} viewerDisplayEvent
     * @return {?}
     */
    onAttachmentSelect(viewerDisplayEvent) {
        this.attachmentSelectEvent.emit(viewerDisplayEvent);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onPageEvent(event) {
        this.selectedPage = event;
        if (typeof this.workId != 'undefined' && this.workId != Guid.EMPTY) {
            this.populateWorkRelatedItems(this.workId);
        }
    }
}
E5coreUiWorkRelatedItemsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-related-items',
                template: `
  <span *ngIf="workItem$">
    <e5core-ui-work-related-items-prime [labels]="labels" [showCreateChildButton]="showCreateChildButton" [createButtonText]="createButtonText" [showDefinedChildrenOnly]="showDefinedChildrenOnly" [readonly]="readonly" (workItemSelectEvent)="onWorkItemSelect($event)" (attachmentSelectEvent)="onAttachmentSelect($event)" (categorisationChangeEvent)="onCategorizationChange($event)" (createChildWorkItemEvent)="onCreateChildWorkItem()" (pageEvent)="onPageEvent($event)"></e5core-ui-work-related-items-prime>
  </span>
  <div *ngIf="!(workItem$)" class="e5core-component-error">&lt;e5core-ui-work-related-items&gt; [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiWorkRelatedItemsComponent.ctorParameters = () => [
    { type: WorkItemService },
    { type: TaxonomyFieldDefinitionService },
    { type: ChangeDetectorRef }
];
E5coreUiWorkRelatedItemsComponent.propDecorators = {
    workItem$: [{ type: Input }],
    findId: [{ type: Input }],
    createButtonText: [{ type: Input }],
    fieldsToShow: [{ type: Input }],
    readonly: [{ type: Input }],
    pagesizes: [{ type: Input }],
    showCreateChildButton: [{ type: Input }],
    showDefinedChildrenOnly: [{ type: Input }],
    workItemSelectEvent: [{ type: Output }],
    attachmentSelectEvent: [{ type: Output }],
    categorisationChangeEvent: [{ type: Output }],
    createChildWorkItemEvent: [{ type: Output }],
    workRelatedItemsComponents: [{ type: ViewChildren, args: [E5coreUiWorkRelatedItemsBaseComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkRelatedItemsPrimeComponent extends E5coreUiWorkRelatedItemsBaseComponent {
    constructor() {
        super(...arguments);
        this.pageSize = 10;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.pageSizeOptions = (this.pagesizes && this.pagesizes.length > 0) ? this.pagesizes : [5, 10, 25, 50];
        this.pageEvent.emit({ pageSize: this.pageSize, pageIndex: 0 });
    }
}
E5coreUiWorkRelatedItemsPrimeComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-related-items-prime',
                template: "<div class=\"e5core-ui-work-related-items\">\n\n    <div *ngIf=\"!readonly\">\n        <mat-form-field class='e5-work-field-type-list' *ngIf=\"showDefinedChildrenOnly\">\n            <mat-select placeholder=\"Child Category\" (selectionChange)=\"selectChildCategory($event)\">\n                <mat-option *ngFor=\"let childWorkItemCategory of childWorkItemCategories\" [value]=childWorkItemCategory>{{childWorkItemCategory.name}}</mat-option>\n            </mat-select>\n        </mat-form-field>\n        <e5core-ui-categorization *ngIf=\"!showDefinedChildrenOnly\" (categorizationChange)=\"onCategorizationChange($event)\"></e5core-ui-categorization>\n    </div>\n    <button *ngIf=\"showCreateChildButton\" mat-raised-button (click)=\"createChildWorkItem()\">{{createButtonText}}</button>\n\n    <p-treeTable [value]=\"treeData\">\n      <ng-template pTemplate=\"header\">\n          <tr>\n              <th></th>\n              <th *ngFor=\"let label of labels\">{{ label }}</th>\n          </tr>\n      </ng-template>\n      <ng-template pTemplate=\"body\" let-rowNode let-rowData=\"rowData\">\n          <tr>\n              <td>\n                  <p-treeTableToggler [rowNode]=\"rowNode\"></p-treeTableToggler>\n                  <button mat-icon-button (click)=\"onWorkItemSelect(rowData)\">\n                    <mat-icon>filter_none</mat-icon>\n                  </button>\n                  <span *ngIf=\"rowData.attachmentCount > 0\">\n                    <button mat-icon-button (click)=\"onAttachmentSelect(rowData)\">\n                            <mat-icon>attach_file</mat-icon>\n                    </button>\n                    {{rowData.attachmentCount}}\n                  </span>\n              </td>\n              <td *ngFor=\"let fieldValue of rowData.fieldValues\">{{ fieldValue.value }}</td>\n          </tr>\n      </ng-template>\n    </p-treeTable>\n\n    <mat-paginator [length]=\"length\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"pageSizeOptions\" (page)=\"onPageEvent($event)\" showFirstLastButtons></mat-paginator>\n</div>",
                providers: [{ provide: E5coreUiWorkRelatedItemsBaseComponent, useExisting: E5coreUiWorkRelatedItemsPrimeComponent }],
                animations: [
                    trigger('detailExpand', [
                        state('collapsed', style({ height: '0px', minHeight: '0', display: 'none' })),
                        state('expanded', style({ height: '*' })),
                        transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
                    ]),
                ],
                styles: ["table.e5core-ui-work-related-items{width:100%}.e5core-ui-work-related-items .mat-spinner-holder{width:100%;padding:20pt;position:relative;top:30px;height:1px}.e5core-ui-work-related-items .mat-paginator{margin-top:0;background:0 0}.darken{background:rgba(0,0,0,.05)}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiAssignUserBaseComponent {
    constructor() {
        this.loading = false;
        this.selectUserEvent = new EventEmitter();
        this.assignUserEvent = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} event
     * @return {?}
     */
    selectUser(event) {
        this.selectUserEvent.emit(event);
    }
    /**
     * @return {?}
     */
    assignUser() {
        this.assignUserEvent.emit(event);
    }
    /**
     * @return {?}
     */
    get isReadOnly() {
        return (this.readonly);
    }
}
E5coreUiAssignUserBaseComponent.propDecorators = {
    users: [{ type: Input }],
    showAssignButton: [{ type: Input }],
    readonly: [{ type: Input }],
    loading: [{ type: Input }],
    selectUserEvent: [{ type: Output }],
    assignUserEvent: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiAssignUserBootstrapComponent extends E5coreUiAssignUserBaseComponent {
}
E5coreUiAssignUserBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-assign-user-bootstrap',
                template: "<div class='e5-component'>\n  <div class='e5-content'>\n\n    <div class='form-group'>\n      <label for='assignUser'>Assign to User</label>\n      <input\n        *ngIf=\"isReadOnly\"\n        [readonly]='true'\n        name=\"assignUser\"\n        type=\"text\"/>\n\n      <select name=\"assignUser\" *ngIf=\"!isReadOnly\" (onchange)=\"selectUser($event)\">\n        <option *ngFor=\"let user of users\" [value]=user>{{user.name}}</option>\n      </select>\n    </div>\n    <button *ngIf=\"showAssignButton\" (click)=\"assignUser()\">Assign</button>\n</div>\n",
                providers: [{ provide: E5coreUiAssignUserBaseComponent, useExisting: E5coreUiAssignUserBootstrapComponent }],
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiAssignUserBoxComponent extends E5coreUiAssignUserBaseComponent {
}
E5coreUiAssignUserBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-assign-user-box',
                template: "<div class='e5-component'>\n  <div class='e5-title'>e5core-ui-work-assign-user</div>\n  <div class='e5-content'>    \n    <div>\n      Assign to User\n      <input *ngIf=\"isReadOnly\"\n        [readonly]='true'\n        name=\"template\"\n        type=\"text\"\n      />\n      <select *ngIf=\"!isReadOnly\" (onchange)=\"selectUser($event)\">\n        <option *ngFor=\"let user of users\" [value]=user>{{user.name}}</option>\n      </select>\n    </div>\n    <button *ngIf=\"showAssignButton\" (click)=\"assignUser()\">Assign</button>\n</div>",
                providers: [{ provide: E5coreUiAssignUserBaseComponent, useExisting: E5coreUiAssignUserBoxComponent }],
                styles: [""]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiAssignUserMaterialComponent extends E5coreUiAssignUserBaseComponent {
}
E5coreUiAssignUserMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-assign-user-material',
                template: "<div class=\"e5core-ui-assign-user\" [ngClass]=\"{'loading': loading}\">\n\n  <div *ngIf=\"loading\" class=\"e5core-loader\">\n    <mat-spinner></mat-spinner>\n  </div>\n\n  <div>\n    <mat-form-field class='e5-work-field-type-list' *ngIf=\"isReadOnly\">\n      <input\n        [readonly]='true'\n        matInput\n        placeholder=\"Assign to User\"\n        name=\"template\"\n        type=\"text\"\n      />\n    </mat-form-field>\n    <mat-form-field class='e5-work-field-type-list' *ngIf=\"!isReadOnly\">\n      <mat-select placeholder=\"Assign to User\" (selectionChange)=\"selectUser($event)\">\n        <mat-option *ngFor=\"let user of users\" [value]=user>{{user.name}}</mat-option>\n      </mat-select>\n    </mat-form-field>\n  </div>\n  <button *ngIf=\"showAssignButton\" mat-raised-button (click)=\"assignUser()\">Assign</button>\n</div>",
                providers: [{ provide: E5coreUiAssignUserBaseComponent, useExisting: E5coreUiAssignUserMaterialComponent }],
                styles: [".e5core-ui-assign-user.loading{background-color:rgba(.1,.1,.1,.1)}.e5core-ui-assign-user.loading select{background-color:transparent}.e5core-ui-assign-user .e5core-loader{position:absolute;margin-left:50%;margin-right:50%}.e5core-ui-assign-user .e5core-loader mat-spinner{top:0;left:-55pt}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiAssignUserComponent {
    /**
     * @param {?} style
     * @param {?} workItemFoundationService
     * @param {?} changeDetectorRef
     */
    constructor(style$$1, workItemFoundationService, changeDetectorRef) {
        this.style = style$$1;
        this.workItemFoundationService = workItemFoundationService;
        this.changeDetectorRef = changeDetectorRef;
        this.showAssignButton = true;
        this.readonly = false;
        this.assignUserEvent = new EventEmitter();
        this.selectUserEvent = new EventEmitter();
        this.loading = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.workItem$ == 'undefined') {
            console.error('e5core-ui-work-assign-user [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (typeof this.workItem$ != 'undefined') {
            this.workItem$.subscribe(wim => {
                if (wim.workId && wim.workId != Guid.EMPTY) {
                    this.populateAssignableUsers(wim.workId);
                }
            });
        }
    }
    /**
     * @param {?} wid
     * @return {?}
     */
    populateAssignableUsers(wid) {
        this.loading = true;
        this.changeDetectorRef.detectChanges();
        this.workItemFoundationService.getAssignableUsers(wid).subscribe(s => {
            this.assignUserComponents.forEach(element => {
                element.users = s;
                this.loading = false;
                this.changeDetectorRef.detectChanges();
            });
        }, error => {
            console.error(error);
        });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    selectUser(event) {
        this.selectedUser = event.value;
        /** @type {?} */
        var wid = this.workItem$.getValue().workId;
        this.selectUserEvent.emit({ workId: wid, id: this.selectedUser.id, login: this.selectedUser.userName, name: this.selectedUser.name, email: this.selectedUser.email });
    }
    /**
     * @param {?} event
     * @return {?}
     */
    assignUser(event) {
        if (this.selectedUser) {
            /** @type {?} */
            var assignUserJson = {
                AssignedUser: this.selectedUser.userName
            };
            /** @type {?} */
            var wid = this.workItem$.getValue().workId;
            this.workItemFoundationService.update(wid, assignUserJson).subscribe(s => {
                if (typeof this.workItem$ != "undefined") {
                    this.workItem$.next(this.workItem$.getValue());
                }
                this.assignUserEvent.emit({ workId: wid, id: this.selectedUser.id, login: this.selectedUser.userName, name: this.selectedUser.name, email: this.selectedUser.email });
            }, error => {
                console.error(error);
                throw error;
            });
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
    }
}
E5coreUiAssignUserComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-assign-user',
                template: `
  <span *ngIf="workItem$" [ngSwitch]="style.current()">
  <e5core-ui-work-assign-user-box *ngSwitchCase='0' [showAssignButton]='showAssignButton' [loading]='loading' [readonly]='readonly' (selectUserEvent)='selectUser($event)' (assignUserEvent)='assignUser($event)'></e5core-ui-work-assign-user-box>
  <e5core-ui-work-assign-user-bootstrap *ngSwitchCase='1' [showAssignButton]='showAssignButton' [loading]='loading' [readonly]='readonly' (selectUserEvent)='selectUser($event)' (assignUserEvent)='assignUser($event)'></e5core-ui-work-assign-user-bootstrap>
  <e5core-ui-work-assign-user-material *ngSwitchCase='2' [showAssignButton]='showAssignButton' [loading]='loading' [readonly]='readonly' (selectUserEvent)='selectUser($event)' (assignUserEvent)='assignUser($event)'></e5core-ui-work-assign-user-material>
  </span>
  <div *ngIf="!(workItem$)" class="e5core-component-error">&lt;e5core-ui-work-assign-user&gt; [workItem$] must have a BehaviorSubject&lt;WorkItemModel&gt;</div>`,
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
E5coreUiAssignUserComponent.ctorParameters = () => [
    { type: UiStyleService },
    { type: WorkItemFoundationService },
    { type: ChangeDetectorRef }
];
E5coreUiAssignUserComponent.propDecorators = {
    workItem$: [{ type: Input }],
    showAssignButton: [{ type: Input }],
    readonly: [{ type: Input }],
    assignUserEvent: [{ type: Output }],
    selectUserEvent: [{ type: Output }],
    assignUserComponents: [{ type: ViewChildren, args: [E5coreUiAssignUserBaseComponent,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiMonitorSlaComponent {
    constructor() {
        this.slaRange = 24;
        this.slaInDays = false;
        this.categoryChange = new EventEmitter();
        this.slaSelect = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onCategoryChange($event) {
        this.categoryChange.emit($event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onSlaSelect($event) {
        this.slaSelect.emit($event);
    }
}
E5coreUiMonitorSlaComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla',
                template: `<e5core-ui-monitor-sla-highcharts 
      [categorisation]="categorisation" 
      [statuses]="statuses" 
      [slaRange]="slaRange" 
      [slaInDays]="slaInDays"
      (categoryChange)="onCategoryChange($event)"
      (slaSelect)="onSlaSelect($event)">
    </e5core-ui-monitor-sla-highcharts>`
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaComponent.ctorParameters = () => [];
E5coreUiMonitorSlaComponent.propDecorators = {
    categorisation: [{ type: Input }],
    statuses: [{ type: Input }],
    slaRange: [{ type: Input }],
    slaInDays: [{ type: Input }],
    categoryChange: [{ type: Output }],
    slaSelect: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiMonitorSlaHighchartsComponent {
    /**
     * @param {?} monitorService
     */
    constructor(monitorService) {
        this.monitorService = monitorService;
        this.slaRange = 24;
        this.slaInDays = false;
        this.categoryChange = new EventEmitter();
        this.slaSelect = new EventEmitter();
        this.clickMessage = '';
        this.Highcharts = Highcharts; // required
        // required
        this.chartConstructor = 'chart'; // optional string, defaults to 'chart'
        // optional string, defaults to 'chart'
        this.chartOptions = this.createChartOptions();
        this.chartCallback = null; // optional function, defaults to null
        // optional function, defaults to null
        this.updateFlag = false; // optional boolean
        // optional boolean
        this.oneToOneFlag = true; // optional boolean, defaults to false
        // optional boolean, defaults to false
        this.runOutsideAngularFlag = false;
        this.changeFlag = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        let cat1Id = (this.categorisation && this.categorisation.length >= 1) ? this.categorisation[0] : 0;
        /** @type {?} */
        let cat2Id = (this.categorisation && this.categorisation.length >= 2) ? this.categorisation[1] : 0;
        /** @type {?} */
        let cat3Id = (this.categorisation && this.categorisation.length >= 3) ? this.categorisation[2] : 0;
        /** @type {?} */
        let categoryActivityId = (this.categorisation && this.categorisation.length >= 4) ? this.categorisation[3] : 0;
        this.approachingSLARange = (this.slaRange == 0) ? 24 : this.slaRange;
        this.approachingSLAInDays = this.slaInDays;
        this.workStatuses = (!this.statuses || this.statuses.length == 0) ? "1,2,3" : this.statuses.join(',');
        this.LoadChartObject(cat1Id, cat2Id, cat3Id, categoryActivityId, this.approachingSLARange, this.approachingSLAInDays, this.workStatuses);
    }
    /**
     * @param {?} category1Id
     * @param {?} category2Id
     * @param {?} category3Id
     * @param {?} categoryActivityId
     * @param {?} slaRange
     * @param {?} slaInHours
     * @param {?} workStatus
     * @return {?}
     */
    LoadChartObject(category1Id, category2Id, category3Id, categoryActivityId, slaRange, slaInHours, workStatus) {
        this.monitorService.getSlaMonitorWorkCounts(category1Id, category2Id, category3Id, categoryActivityId, { approachingSLARange: slaRange, isApproachingSLAInHours: slaInHours, statuses: workStatus }).subscribe(model => {
            this.chartOptions = Object.assign({}, this.chartOptions, { xAxis: this.extractXAxis(model), series: this.extractSeries(model) // series: [{name:'InSLA',color:'#00cc99',data:[4,1]},{name:'Approaching', color:'#feb236', data:[8,3]},{name:'Expired', color:'#cc3300', data:[10,3]}]
             });
            this.model = model;
        });
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    extractXAxis(model) {
        /** @type {?} */
        var output = {
            categories: model.data.map(i => i.slaCategoryName),
            title: { rotation: -45 },
            labels: {
                format: "<b class='xAxisLabel'>{value}</b>"
            }
        };
        return (output);
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    extractSeries(model) {
        /** @type {?} */
        var series = [];
        /** @type {?} */
        var inSlaWorkCount = [];
        /** @type {?} */
        var approachingSlaWorkCount = [];
        /** @type {?} */
        var expiredWorkCount = [];
        for (let i = 0; i < model.data.length; i++) {
            inSlaWorkCount.push(model.data[i].inSlaWorkCount);
            approachingSlaWorkCount.push(model.data[i].approachingSlaWorkCount);
            expiredWorkCount.push(model.data[i].expiredWorkCount);
        }
        series.push({ name: 'InSLA', color: '#00cc99', data: inSlaWorkCount, drilldown: true });
        series.push({ name: 'Approaching', color: '#feb236', data: approachingSlaWorkCount, drilldown: true });
        series.push({ name: 'Expired', color: '#cc3300', data: expiredWorkCount, drilldown: true });
        return (series);
    }
    /**
     * @param {?} categoryName
     * @return {?}
     */
    GetSelectedCategorisation(categoryName) {
        /** @type {?} */
        let selectedCategorisation = [];
        /** @type {?} */
        let clickedCategory;
        /** @type {?} */
        let navigatorCount = 1;
        /** @type {?} */
        let category1Id = 0;
        /** @type {?} */
        let category2Id = 0;
        /** @type {?} */
        let category3Id = 0;
        /** @type {?} */
        let activityId = 0;
        navigatorCount = this.model.selectedCategories.length;
        clickedCategory = this.model.data.filter(item => item.slaCategoryName === categoryName);
        switch (navigatorCount) {
            case 1: {
                if (clickedCategory.length == 1) {
                    category1Id = clickedCategory[0].slaCategoryId;
                }
                category2Id = 0;
                category3Id = 0;
                activityId = 0;
                break;
            }
            case 2: {
                if (clickedCategory.length == 1) {
                    category2Id = clickedCategory[0].slaCategoryId;
                }
                category1Id = this.model.selectedCategories[1].categoryId;
                category3Id = 0;
                activityId = 0;
                break;
            }
            case 3: {
                if (clickedCategory.length == 1) {
                    category3Id = clickedCategory[0].slaCategoryId;
                }
                category1Id = this.model.selectedCategories[1].categoryId;
                category2Id = this.model.selectedCategories[2].categoryId;
                activityId = 0;
                break;
            }
            case 4: {
                if (clickedCategory.length == 1) {
                    activityId = clickedCategory[0].slaCategoryId;
                }
                category1Id = this.model.selectedCategories[1].categoryId;
                category2Id = this.model.selectedCategories[2].categoryId;
                category3Id = this.model.selectedCategories[3].categoryId;
                break;
            }
            default: {
                category1Id = 0;
                category2Id = 0;
                category3Id = 0;
                activityId = 0;
            }
        }
        selectedCategorisation.push(category1Id);
        selectedCategorisation.push(category2Id);
        selectedCategorisation.push(category3Id);
        selectedCategorisation.push(activityId);
        return selectedCategorisation;
    }
    /**
     * @param {?} categoryName
     * @return {?}
     */
    ConstructCategorisation(categoryName) {
        /** @type {?} */
        let selectedCategorisation = [];
        /** @type {?} */
        let category1Id = 0;
        /** @type {?} */
        let category2Id = 0;
        /** @type {?} */
        let category3Id = 0;
        /** @type {?} */
        let activityId = 0;
        /** @type {?} */
        let clickedCategoryIndex = 0;
        /** @type {?} */
        let categoryNames = this.model.selectedCategories.map(item => item.categoryName);
        clickedCategoryIndex = categoryNames.indexOf(categoryName);
        switch (clickedCategoryIndex) {
            case 1: {
                category1Id = this.model.selectedCategories[1].categoryId;
                category2Id = 0;
                category3Id = 0;
                activityId = 0;
                break;
            }
            case 2: {
                category1Id = this.model.selectedCategories[1].categoryId;
                category2Id = this.model.selectedCategories[2].categoryId;
                category3Id = 0;
                activityId = 0;
                break;
            }
            case 3: {
                category1Id = this.model.selectedCategories[1].categoryId;
                category2Id = this.model.selectedCategories[2].categoryId;
                category3Id = this.model.selectedCategories[3].categoryId;
                activityId = 0;
                break;
            }
            case 4: {
                category1Id = this.model.selectedCategories[1].categoryId;
                category2Id = this.model.selectedCategories[2].categoryId;
                category3Id = this.model.selectedCategories[3].categoryId;
                activityId = this.model.selectedCategories[4].categoryId;
                break;
            }
            case 0: {
                category1Id = 0;
                category2Id = 0;
                category3Id = 0;
                activityId = 0;
                break;
            }
            default: {
                category1Id = 0;
                category2Id = 0;
                category3Id = 0;
                activityId = 0;
            }
        }
        selectedCategorisation.push(category1Id);
        selectedCategorisation.push(category2Id);
        selectedCategorisation.push(category3Id);
        selectedCategorisation.push(activityId);
        return selectedCategorisation;
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    drillDown(event) {
        alert(event);
    }
    /**
     * @return {?}
     */
    createChartOptions() {
        /** @type {?} */
        let _this = this;
        return {
            chart: {
                type: 'column',
                events: {}
            },
            title: {
                text: 'Work SLA Monitor',
                style: {
                    "fontSize": "16px",
                    "font-weight": "bold"
                }
            },
            xAxis: {
                categories: [],
                title: { rotation: -45 }
            },
            yAxis: {
                min: 0,
                title: {
                    text: 'Work Item Count',
                },
                labels: { x: -15 },
                stackLabels: {
                    enabled: false,
                    style: {
                        fontWeight: 'bold',
                        color: 'gray'
                    }
                }
            },
            legend: {
                align: 'right',
                x: -30,
                verticalAlign: 'top',
                y: 25,
                floating: true,
                backgroundColor: 'white',
                borderColor: '#CCC',
                borderWidth: 1,
                shadow: false,
                itemStyle: {
                    fontSize: '12px',
                    font: '12pt',
                }
            },
            tooltip: {
                headerFormat: '<b>{point.x}</b><br/>',
                pointFormat: '{series.name}: {point.y}<br/>Total: {point.stackTotal}'
            },
            plotOptions: {
                series: {
                    stacking: 'normal',
                    dataLabels: {
                        enabled: true,
                        align: 'center',
                        color: '#FFFFFF'
                    },
                    animation: {
                        duration: 2000
                    },
                    cursor: 'pointer',
                    point: {
                        events: {
                            click: function (event) {
                                _this.onClickBar(this, event);
                                // let categorisation = _this.GetSelectedCategorisation(this.category);
                                // if (categorisation.length == 3) {
                                // 	_this.LoadChartObject(categorisation[0], categorisation[1], categorisation[2], 0, _this.approachingSLARange, _this.approachingSLAInDays, _this.workStatuses);
                                // }
                                // else {
                                // 	_this.LoadChartObject(0, 0, 0, 0, 24, true, "1,2,3");
                                // }
                            }
                        }
                    }
                }
            },
            series: [{ name: 'InSLA', color: '#00cc99', data: [] }, { name: 'Approaching', color: '#feb236', data: [] }, { name: 'Expired', color: '#C62828', data: [] }],
            drilldown: {
                series: []
            }
        }; // required
    }
    //------Documentation on SlaChartCallback : assign the *chartCallback like so, chartCallback = SlaChartCallback()--------------
    // public slaChartCallback(changeFlag,category,monitorService)
    // {
    //   if(changeFlag==true)
    //   {
    //     alert("Click Event : slachartCallback invoked!");
    //     changeFlag = false;
    //   }
    //   else
    //   { 
    //     alert("slachartCallback invoked!"); 
    //   }
    // }
    /**
     * @param {?} categoryName
     * @return {?}
     */
    onNavigationCategoryClick(categoryName) {
        /** @type {?} */
        let categorisation = this.ConstructCategorisation(categoryName);
        if (categorisation.length == 4) {
            this.LoadChartObject(categorisation[0], categorisation[1], categorisation[2], 0, this.approachingSLARange, this.approachingSLAInDays, this.workStatuses);
        }
        else {
            this.LoadChartObject(0, 0, 0, 0, 24, true, '1,2,3');
        }
    }
    /**
     * @param {?} eventThis
     * @param {?} eventData
     * @return {?}
     */
    onClickBar(eventThis, eventData) {
        /** @type {?} */
        let series = eventThis.series ? eventThis.series.name : "";
        /** @type {?} */
        let category = eventThis.category || "";
        if (series && category) {
            console.log(`Select ${category}/${series}`);
            /** @type {?} */
            let cat = this.GetSelectedCategorisation(category);
            //let cat = this.GetSelectedCategorisation(category);
            if (cat.length == 4) {
                // console.log(`Bar ${cat[0]}/${cat[1]}/${cat[2]}/${cat[3]}/${series}`) ;
                this.slaSelect.emit({
                    event: eventThis,
                    category1Id: cat[0],
                    category2Id: cat[1],
                    category3Id: cat[2],
                    activityId: cat[3],
                    slaGroup: series
                });
                eventData.stopPropagation();
            }
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onClickAnywhere($event) {
        if ($event.srcElement) {
            // Determine if we clicked on a xaxis label
            // this is a HACK!!!!
            /** @type {?} */
            let element = $event.srcElement;
            /** @type {?} */
            let svg = element.className;
            /** @type {?} */
            let className = svg ? svg.baseVal : undefined;
            if (className && className.indexOf("xAxisLabel") >= 0) {
                /** @type {?} */
                let label = element.textContent;
                /** @type {?} */
                let cat = this.GetSelectedCategorisation(label);
                if (cat && cat.length == 4) {
                    // console.log(`Label ${cat[0]}/${cat[1]}/${cat[2]}/${cat[3]}/${label}`) ;
                    this.categoryChange.emit({
                        event: $event,
                        category1Id: cat[0],
                        category2Id: cat[1],
                        category3Id: cat[2],
                        activityId: cat[3]
                    });
                    if (cat[3] == 0)
                        this.LoadChartObject(cat[0], cat[1], cat[2], cat[3], this.approachingSLARange, this.approachingSLAInDays, this.workStatuses);
                }
                $event.stopPropagation();
            }
        }
    }
}
E5coreUiMonitorSlaHighchartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-highcharts',
                template: "<div   (click)=\"onClickAnywhere($event)\">\n    <mat-chip-list *ngIf=\"model\">\n        <mat-chip *ngFor=\"let item of model.selectedCategories;let firstElement = first; let lastElement = last\" (click)=\"onNavigationCategoryClick(item.categoryName)\">{{item.categoryName}}</mat-chip>        \n    </mat-chip-list>\n  \n  <highcharts-chart \n\n  [Highcharts]=\"Highcharts\"\n  [constructorType]=\"chartConstructor\"\n  [options]=\"chartOptions\"\n  [(update)]=\"updateFlag\"\n  [oneToOne]=\"oneToOneFlag\"\n  [runOutsideAngular]=\"runOutsideAngularFlag\"\n  style=\"width: 100%; height: 400px; display: block;\"></highcharts-chart>  \n</div>\n\n",
                styles: [".xAxisLabel{cursor:default}.xAxisLabel:hover{text-decoration:underline}"]
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaHighchartsComponent.ctorParameters = () => [
    { type: MonitorsSlaMonitorService }
];
E5coreUiMonitorSlaHighchartsComponent.propDecorators = {
    categorisation: [{ type: Input }],
    statuses: [{ type: Input }],
    slaRange: [{ type: Input }],
    slaInDays: [{ type: Input }],
    categoryChange: [{ type: Output }],
    slaSelect: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiDatagridComponent {
    /**
     * @param {?} style
     */
    constructor(style$$1) {
        this.style = style$$1;
        this.open = new EventEmitter();
        this.select = new EventEmitter();
        this.link = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     *  Pass the open work item event on to any listener.
     * @param {?} data the row of data, including the "Id" from the table.
     * @return {?}
     */
    onOpen(data) {
        this.open.emit(data);
    }
    /**
     *  Pass the select link on to any listener.
     * @param {?} data the row of data, including the "Id" from the table.
     * @return {?}
     */
    onSelect(data) {
        this.select.emit(data);
    }
    /**
     *  Pass the open link on to any listener.
     * @param {?} link
     * @return {?}
     */
    onLink(link) {
        this.link.emit(link);
    }
    /**
     * Execute a search with the required search expression values.
     * @param {?} query
     * @return {?}
     */
    search(query) {
        this.datagridChildren.forEach(c => c.search(query));
    }
    /**
     * Clear the search results.
     * @return {?}
     */
    reset() {
        this.datagridChildren.forEach(c => c.reset());
    }
    /**
     * Refresh the search results at the current page.
     * @return {?}
     */
    refresh() {
        this.datagridChildren.forEach(c => c.refresh());
    }
}
E5coreUiDatagridComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-datagrid',
                template: `<span *ngIf="!error" [ngSwitch]="style.current()">
			<e5core-ui-datagrid-material #SearchResults *ngSwitchCase='2' 
				[datasource]='datasource'  [query]='query' [autoSearch]='autoSearch'
				(open)='onOpen($event)' (link)='onLink($event)' (select)='onSelect($event)'>
				</e5core-ui-datagrid-material>
			</span>
		<div *ngIf="error" class="e5core-component-error">{{error}}</div>`
            }] }
];
/** @nocollapse */
E5coreUiDatagridComponent.ctorParameters = () => [
    { type: UiStyleService }
];
E5coreUiDatagridComponent.propDecorators = {
    datasource: [{ type: Input }],
    query: [{ type: Input }],
    autoSearch: [{ type: Input }],
    pagesizes: [{ type: Input }],
    open: [{ type: Output }],
    select: [{ type: Output }],
    link: [{ type: Output }],
    datagridChildren: [{ type: ViewChildren, args: ["SearchResults",] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiDatagridBase {
    constructor() {
        this.open = new EventEmitter();
        this.select = new EventEmitter();
        this.link = new EventEmitter();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set query(value) {
        this.search(value);
    }
    ;
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     *  Pass the open work item event on to any listener.
     * @param {?} data the row of data, including the "Id" from the table.
     * @return {?}
     */
    onOpen(data) {
        this.open.emit(data);
    }
    /**
     *  Pass the select link on to any listener.
     * @param {?} data the row of data, including the "Id" from the table.
     * @return {?}
     */
    onSelect(data) {
        this.select.emit(data);
    }
    /**
     *  Pass the open link on to any listener.
     * @param {?} link
     * @return {?}
     */
    onLink(link) {
        this.link.emit(link);
    }
    /**
     * Execute a search with the required search expression values.
     * @param {?} expression the fields and values required to perform the search.
     * @return {?}
     */
    search(expression) {
    }
    /**
     * Clear the search results.
     * @return {?}
     */
    reset() {
    }
    /**
     * Refresh the search results at the current page.
     * @return {?}
     */
    refresh() {
    }
}
E5coreUiDatagridBase.propDecorators = {
    datasource: [{ type: Input }],
    query: [{ type: Input }],
    autoSearch: [{ type: Input }],
    pagesizes: [{ type: Input }],
    open: [{ type: Output }],
    select: [{ type: Output }],
    link: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiDatagridBootstrapComponent extends E5coreUiDatagridBase {
    constructor() {
        super();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiDatagridBootstrapComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-datagrid-bootstrap',
                template: "<p>\n  e5core-ui-datagrid-bootstrap works!\n</p>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiDatagridBootstrapComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MaterialTableDataSource extends DataSource {
    /**
     * @param {?} datasource
     */
    constructor(datasource) {
        super();
        this.datasource = datasource;
        this.subject$ = new BehaviorSubject([]);
        this.loading$ = new BehaviorSubject(false);
        this.activeQuery = false;
        // this.refresh() ;
    }
    /**
     * @param {?} paginator
     * @return {?}
     */
    set paginator(paginator) {
        this._paginator = paginator;
        this._paginator.page.subscribe(x => {
            // {"previousPageIndex":0,"pageIndex":1,"pageSize":10,"length":100}
            if (this.activeQuery) { // Ignore until we have some data
                this.update(this.lastQuery);
            }
        });
    }
    /**
     * @param {?} sort
     * @return {?}
     */
    set sort(sort) {
        this._sort = sort;
        this._sort.sortChange.subscribe(ob => {
            // {active: "detail", direction: ""}
            this.orderby = ob;
            if (this.activeQuery) { // Ignore until we have some data
                this.update(this.lastQuery);
            }
        });
    }
    /**
     * @protected
     * @param {?} query
     * @return {?}
     */
    update(query) {
        /** @type {?} */
        const page = (this._paginator) ? this._paginator.pageIndex : 0;
        /** @type {?} */
        const pageSize = (this._paginator) ? this._paginator.pageSize : 10;
        /** @type {?} */
        const options = this.datasource.defaultOptions();
        // Setup orderby option if it's available
        /** @type {?} */
        const orderby = this.orderby;
        if (orderby && orderby.direction && orderby.active) {
            if (orderby.direction.toLowerCase() === 'desc') {
                options.orderBy = `-${orderby.active}`;
            }
            else {
                options.orderBy = `+${orderby.active}`;
            }
        }
        options.query = query;
        this.loading$.next(true);
        this.datasource.read(page, pageSize, options).subscribe(results => {
            this._paginator.length = results.total;
            this.subject$.next(results.data);
            this.activeQuery = true;
        }, error => { this.loading$.next(false); }, () => { this.loading$.next(false); });
        this.lastQuery = query;
    }
    /**
     * Subscribe to this observable if you want to be informed when the datasource is loading.
     * @return {?}
     */
    get loadingEvents() {
        return (this.loading$);
    }
    /**
     * @param {?} query
     * @return {?}
     */
    search(query) {
        this._paginator.pageIndex = 0;
        this.update(query);
    }
    /**
     * @return {?}
     */
    refresh() {
        this.update(this.lastQuery);
    }
    /**
     * @return {?}
     */
    reset() {
        this.clear();
    }
    /**
     * @return {?}
     */
    clear() {
        this._paginator.pageIndex = 0;
        this._paginator.length = 0;
        this.subject$.next([]);
    }
    /**
     * @return {?}
     */
    connect() {
        return (this.subject$);
    }
    /**
     * @return {?}
     */
    disconnect() { }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiDatagridMaterialComponent extends E5coreUiDatagridBase {
    constructor() {
        super();
        this.isEmpty = false;
        this.length = 0;
        this.pageSize = 10;
        this.loading = true;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.pageSizeOptions = (this.pagesizes && this.pagesizes.length > 0) ? this.pagesizes : [5, 10, 25, 50];
        // this.tableDataSource = new SearchMatTableDataSource(this.datasource); // this.history.getHistory(id, 0, 10) ;
        this.tableDataSource = new MaterialTableDataSource(this.datasource); // this.history.getHistory(id, 0, 10) ;
        this.tableDataSource.sort = this.sort;
        this.tableDataSource.paginator = this.paginator;
        this.tableDataSource.loadingEvents.subscribe(loading => {
            this.loading = loading;
        });
        // Load the columns
        this.loading = true;
        this.datasource.columns().subscribe(dsColumns => {
            this.headings = dsColumns;
            this.loading = false;
            if (this.delayedQuery || this.autoSearch) {
                this.search(this.delayedQuery);
            }
        }, error => { }, () => {
            this.loading = false;
        });
    }
    /**
     * @param {?} setPageSizeOptionsInput
     * @return {?}
     */
    setPageSizeOptions(setPageSizeOptionsInput) {
        this.pageSizeOptions = setPageSizeOptionsInput.split(',').map(str => +str);
    }
    /**
     * Return the list of columns available in the table.
     * @return {?}
     */
    columns() {
        if (this.headings) {
            /** @type {?} */
            const cols = (this.headings
                .filter(f => f.code !== 'Id') // Id is added at the beginning
                .map(f => (/** @type {?} */ ({
                label: f.label,
                name: f.code,
                type: f.type,
                status: f.status
            }))));
            return (cols);
        }
        return [];
    }
    /**
     * Return the list of column names that will be displayed in the table.
     * @return {?}
     */
    displayedColumns() {
        /** @type {?} */
        const cols = this.columns()
            .filter(f => f.status > 1) // Selected only
            .map(c => c.name);
        cols.unshift('Id');
        return (cols);
    }
    /**
     * @param {?} query
     * @return {?}
     */
    search(query) {
        if (this.tableDataSource) {
            this.tableDataSource.search(query);
        }
        else {
            this.delayedQuery = query;
        }
    }
    /**
     * @return {?}
     */
    reset() {
        this.tableDataSource.reset();
    }
    /**
     * @return {?}
     */
    refresh() {
        this.tableDataSource.refresh();
    }
}
E5coreUiDatagridMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-datagrid-material',
                template: "<mat-card class='e5core-ui-search-results' [ngClass]=\"{'loading': loading}\">\n\t<div class=\"e5core-content\"  [ngClass]=\"{'loading': loading}\">\n\n\t\t<div *ngIf=\"loading\" class=\"e5core-loader\">\n\t\t\t<mat-spinner></mat-spinner>\n\t\t</div>\n\n\t\t<table mat-table [dataSource]=\"tableDataSource\" matSort class=\"e5core-ui-search-results-sort\">\n\n\t\t\t<!-- <ng-container matColumnDef=\"CasenoteDate\">\n            <th mat-header-cell *matHeaderCellDef mat-sort-header> Date </th>\n            <td mat-cell *matCellDef=\"let element\"> {{element.CasenoteDate | date : 'd LLL yyyy h:mm aa' }} </td>\n          </ng-container> -->\n\n\t\t\t<ng-container matColumnDef=\"Id\">\n\t\t\t\t<th mat-header-cell *matHeaderCellDef class='e5core-ui-search-results-column-workid'></th>\n\t\t\t\t<td mat-cell *matCellDef=\"let element\" class='e5core-ui-search-results-column-workid'>\n\t\t\t\t\t<button mat-icon-button (click)='onOpen(element)'>\n\t\t\t\t\t\t<mat-icon aria-label=\"Open item\">folder</mat-icon>\n\t\t\t\t\t</button>\n\t\t\t\t</td>\n\t\t\t</ng-container>\n\n\t\t\t<ng-container *ngFor=\"let column of columns()\" matColumnDef=\"{{column.name}}\">\n\t\t\t\t<th mat-header-cell *matHeaderCellDef mat-sort-header>{{column.label}} </th>\n\t\t\t\t<td mat-cell *matCellDef=\"let element\">\n\t\t\t\t\t<!-- {{ formatCell(element, column) }}  {{column.type}} -->\n\t\t\t\t\t<span [ngSwitch]=\"column.type\">\n\n\t\t\t\t\t\t<span *ngSwitchCase=\"'ActionSelect'\">\n\t\t\t\t\t\t\t\t<button mat-icon-button (click)='onSelect(element)'>\n\t\t\t\t\t\t\t\t\t<mat-icon aria-label=\"Select item\">select_all</mat-icon>\n\t\t\t\t\t\t\t\t</button>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t\t\n\t\t\t\t\t\t<span *ngSwitchCase=\"'DateTime'\">{{ element[column.name] | date : 'short' }}</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'Date'\">{{ element[column.name] | date : 'shortDate' }}</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'Currency'\">{{element[column.name] | currency:'AUD'}}</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'Checkbox'\">\n\t\t\t\t\t\t\t<mat-checkbox [(ngModel)]='element[column.name]' [disabled]=\"1\"></mat-checkbox>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'Link'\">\n\t\t\t\t\t\t\t<button mat-icon-button (click)='onLink(element[column.name])'>\n\t\t\t\t\t\t\t\t<mat-icon aria-label=\"Open work item\">public</mat-icon>\n\t\t\t\t\t\t\t</button>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t\t<span *ngSwitchCase=\"'SLA'\">\n\t\t\t\t\t\t\t<mat-icon *ngIf=\"element[column.name] == 'expired'\" aria-label=\"Breached SLA\" color=\"warn\">report_problem</mat-icon>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t\t<span *ngSwitchDefault>{{element[column.name]}}</span>\n\t\t\t\t\t</span>\n\t\t\t\t</td>\n\t\t\t</ng-container>\n\n\t\t\t<tr mat-header-row *matHeaderRowDef=\"displayedColumns()\"></tr>\n\t\t\t<tr mat-row *matRowDef=\"let row; columns: displayedColumns();\"></tr>\n\t\t</table>\n\n\t\t<div *ngIf=\"paginator.length == 0\" class=\"empty\">\n\t\t\tNo Results\n\t\t</div>\n\n\t\t<mat-paginator [length]=\"length\" [pageSize]=\"pageSize\" [pageSizeOptions]=\"pageSizeOptions\" (page)=\"pageEvent = $event\"\n\t\t showFirstLastButtons></mat-paginator>\n\n\t</div>\n\n\t<!-- <div><code>headings = {{ headings | json }}</code></div>\n  <div><code>properties = {{ properties | json }}</code></div> -->\n\n</mat-card>\n",
                styles: ["table{width:100%}.mat-paginator{margin-top:0;background:0 0}.e5core-ui-search-results{margin:10pt}.empty{width:100%;text-align:center;padding:15pt}.e5core-ui-search-results-column-workid{width:50px}.e5core-content.loading{background-color:rgba(.1,.1,.1,.1)}.e5core-content.loading table{background-color:transparent}.e5core-content .e5core-loader{position:absolute;margin-left:50%;margin-right:50%}.e5core-content .e5core-loader mat-spinner{top:20pt;left:-55pt}"]
            }] }
];
/** @nocollapse */
E5coreUiDatagridMaterialComponent.ctorParameters = () => [];
E5coreUiDatagridMaterialComponent.propDecorators = {
    sort: [{ type: ViewChild, args: [MatSort,] }],
    paginator: [{ type: ViewChild, args: [MatPaginator,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiDatagridBoxComponent extends E5coreUiDatagridBase {
    constructor() {
        super();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiDatagridBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-datagrid-box',
                template: "<p>\n  e5core-ui-datagrid-box works!\n</p>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiDatagridBoxComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MockSlaCompletionService {
    /**
     * @return {?}
     */
    getMockedSlaCompletionCounts() {
        /** @type {?} */
        const incomingData = new Array();
        /** @type {?} */
        const model = new MonitorsSlaCompletionMonitorModel();
        incomingData.push({
            completionDate: new Date('2016-12-05T11:52:10.113Z'),
            completedInSla: 10,
            completedPropertyTotal: 38,
            completedTotal: 20,
            inSlaPropertyTotal: 24,
            movingAverage: 50,
            movingAverageWeekly: 50
        }, {
            completionDate: new Date('2016-12-06T11:55:10.113Z'),
            completedInSla: 9,
            completedPropertyTotal: 38,
            completedTotal: 10,
            inSlaPropertyTotal: 24,
            movingAverage: 90,
            movingAverageWeekly: 50
        }, {
            completionDate: new Date('2016-12-07T10:52:10.113Z'),
            completedInSla: 5,
            completedPropertyTotal: 38,
            completedTotal: 8,
            inSlaPropertyTotal: 24,
            movingAverage: 63,
            movingAverageWeekly: 50
        });
        model.data = incomingData;
        return of(model);
    }
}
class E5coreUiMonitorSlaCompletionHighchartsComponent {
    /**
     * @param {?} monitorService
     * @param {?} datePipe
     */
    constructor(monitorService, datePipe) {
        this.monitorService = monitorService;
        this.datePipe = datePipe;
        this.slaRangeInDays = 28; // Idea is to display completed work items every day over a period of time. 28 days forms exactly a month
        this.startDate = '2018-01-11T13:21:53.770Z';
        this.endDate = '2018-30-11T13:35:36.870Z';
        this.Highcharts = Highcharts;
        this.chartConstructor = 'chart';
        this.chartOptions = this.createChartOptions();
        this.chartCallback = null; // optional function, defaults to null
        // optional function, defaults to null
        this.updateFlag = false; // optional boolean
        // optional boolean
        this.oneToOneFlag = true; // optional boolean, defaults to false
        // optional boolean, defaults to false
        this.runOutsideAngularFlag = false;
        // Ready up mock service
        this.mockCompletionService = new MockSlaCompletionService();
        // Month drop-down variables
        this.currentDate = new Date();
        this.currentDateRange = {
            startDate: new Date(this.currentDate.getFullYear(), this.currentDate.getMonth(), 1),
            endDate: new Date(this.currentDate.getFullYear(), this.currentDate.getMonth() + 1, 0)
        };
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.isMocked = true; // Set to false in production
        this.LoadChartObject(this.startDate, this.endDate);
        this.selectedOptionMonth = {
            value: this.currentDateRange,
            viewValue: this.datePipe.transform(this.currentDateRange.startDate, 'MMMM yyyy')
        };
        this.selectedMonthViewValue = this.selectedOptionMonth.viewValue;
        this.instantiateOptionMonths();
    }
    /**
     * @private
     * @param {?} date
     * @param {?} months
     * @return {?}
     */
    addMonths(date, months) {
        /** @type {?} */
        const newDate = date;
        newDate.setMonth(newDate.getMonth() + months);
        return (newDate);
    }
    /**
     * @private
     * @param {?} startDate
     * @param {?} endDate
     * @param {?} negativeDirection
     * @return {?}
     */
    addToOptionMonths(startDate, endDate, negativeDirection) {
        /** @type {?} */
        let currentDate = new Date(startDate);
        if (!negativeDirection) {
            while (currentDate <= endDate) {
                this.optionMonths.push({
                    value: {
                        startDate: new Date(currentDate),
                        endDate: new Date(currentDate.getFullYear(), currentDate.getMonth() + 1, 0)
                    },
                    viewValue: this.datePipe.transform(currentDate, 'MMMM yyyy')
                });
                currentDate = this.addMonths(currentDate, 1);
            }
        }
    }
    /**
     * @private
     * @param {?} monthName
     * @return {?}
     */
    convertToMonthNumber(monthName) {
        /** @type {?} */
        const months = [
            'January',
            'February',
            'March',
            'April',
            'May',
            'June',
            'July',
            'August',
            'September',
            'October',
            'November',
            'December'
        ];
        return months.indexOf(monthName);
    }
    /**
     * @private
     * @param {?} viewValue
     * @return {?}
     */
    alterSelectedMonthOption(viewValue) {
        /** @type {?} */
        const selectedValue = this.optionMonths.filter(f => f.viewValue === viewValue);
        if (selectedValue.length === 0) {
            return;
        }
        this.selectedOptionMonth = {
            value: {
                startDate: selectedValue[0].value.startDate,
                endDate: selectedValue[0].value.endDate
            },
            viewValue: viewValue
        };
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    reloadChart($event) {
        this.alterSelectedMonthOption(this.selectedMonthViewValue);
        /** @type {?} */
        const selectedDateRange = this.selectedOptionMonth.value;
        this.instantiateOptionMonths();
        this.LoadChartObject(selectedDateRange.startDate, selectedDateRange.endDate);
    }
    /**
     * @private
     * @return {?}
     */
    instantiateOptionMonths() {
        this.optionMonths = [];
        /** @type {?} */
        const currentlySelectedDate = this.selectedOptionMonth.value.startDate;
        /** @type {?} */
        const startDate = new Date(currentlySelectedDate);
        /** @type {?} */
        const endDate = new Date(currentlySelectedDate);
        startDate.setMonth(startDate.getMonth() - 5);
        endDate.setMonth(endDate.getMonth() + 5);
        /** @type {?} */
        const today = new Date();
        if (endDate > today) {
            endDate.setMonth(today.getMonth());
        }
        this.addToOptionMonths(startDate, endDate, false);
    }
    /**
     * @param {?} startDate
     * @param {?} endDate
     * @param {?=} siteGroup
     * @param {?=} category1Id
     * @param {?=} category2Id
     * @param {?=} category3Id
     * @param {?=} archive
     * @param {?=} totalProperty
     * @return {?}
     */
    LoadChartObject(startDate, endDate, siteGroup, category1Id, category2Id, category3Id, archive, totalProperty) {
        if (this.isMocked) {
            this.mockCompletionService.getMockedSlaCompletionCounts().subscribe(model => {
                this.chartOptions = Object.assign({}, this.chartOptions, { xAxis: this.extractXAxis(model), series: this.extractSeries(model) });
                this.model = model;
            });
        }
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    extractXAxis(model) {
        // debugger;
        /** @type {?} */
        const output = {
            type: 'datetime',
            ordinal: false,
            mintickInterval: 24 * 3600 * 1000,
            // categories: model.data.map(i => this.datePipe.transform(i.completionDate, 'dd MMM yyyy')),
            title: { rotation: -45 },
            labels: {
                format: '<b class="xAxisLabel">{value: %e %b %y}</b>'
            }
        };
        return (output);
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    extractSeries(model) {
        // debugger;
        /** @type {?} */
        const series = [];
        // const completedWorkItems = [];
        /** @type {?} */
        const completedInSla = [];
        /** @type {?} */
        const breachedSla = [];
        /** @type {?} */
        const movingAverage = [];
        for (let i = 0; i < model.data.length; i++) {
            // completedWorkItems.push(model.data[i].completedTotal);
            //TODO :
            // completedInSla.push([model.data[i].completionDate.getTime(), model.data[i].completedInSla]);
            // breachedSla.push([model.data[i].completionDate.getTime(), model.data[i].completedTotal - model.data[i].completedInSla]);
            // movingAverage.push([model.data[i].completionDate.getTime(), model.data[i].movingAverage]);
            // completedTotal.push(model.data[i].completedTotal);
        }
        // series.push({ name: 'Completed Work Items', color: '#00cc99', data: completedWorkItems, drilldown: true });
        // series.push({ name: 'Total Work Completed', color: 'rgba(0, 0, 0, 0)', data: completedTotal, drilldown: true,
        // yAxis: 0, dataLabels: {enabled: true, align: 'center', color: '#000000'} });
        series.push({ name: 'Completed In Sla', color: '#00cc99', data: completedInSla, drilldown: true, yAxis: 0 });
        series.push({ name: 'Expired', color: '#cc3300', data: breachedSla, drilldown: true, yAxis: 0 });
        series.push({ name: 'Moving Average', color: '#FFA500', data: movingAverage, drilldown: true,
            type: 'spline', yAxis: 1, dataLabels: { enabled: false } });
        return (series);
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    drillDown(event) {
        alert(event);
    }
    /**
     * @return {?}
     */
    createChartOptions() {
        /** @type {?} */
        const _this = this;
        return {
            chart: {
                type: 'column',
                events: {
                    drilldown: function (event) {
                        _this.drillDown(event);
                    }
                }
            },
            title: {
                text: 'Work SLA Completion Monitor',
                style: {
                    'fontSize': '16px',
                    'font-weight': 'bold'
                }
            },
            xAxis: {
                categories: [],
                title: { rotation: -45 }
            },
            yAxis: [{
                    min: 0,
                    title: {
                        text: 'Work Item Count',
                    },
                    labels: { x: -15 },
                    stackLabels: {
                        enabled: true,
                        style: {
                            fontWeight: 'bold',
                            color: 'gray'
                        }
                    }
                }, {
                    min: 0,
                    title: {
                        text: 'Percentage of Completed Items In Sla',
                    },
                    opposite: false,
                    labels: { x: -15, format: '{value}%' },
                    stackLabels: {
                        enabled: false,
                        style: {
                            fontWeight: 'bold',
                            color: 'gray'
                        }
                    }
                }],
            legend: {
                align: 'right',
                x: -30,
                verticalAlign: 'top',
                y: 25,
                floating: true,
                backgroundColor: 'white',
                borderColor: '#CCC',
                borderWidth: 1,
                shadow: false,
                itemStyle: {
                    fontSize: '12px',
                    font: '12pt',
                }
            },
            tooltip: {
                headerFormat: '<b>{point.x: %e %b %y}</b><br/>',
                pointFormat: '{series.name}: {point.y}<br/>Total: {point.stackTotal}'
            },
            plotOptions: {
                series: {
                    stacking: 'normal',
                    dataLabels: {
                        enabled: true,
                        align: 'center',
                        color: '#FFFFFF'
                    },
                }
            },
            series: [
                {
                    name: 'Work Items Completed',
                    color: '#00cc99',
                    data: []
                }
            ],
            drilldown: {
                series: []
            }
        };
    }
    /**
     * @param {?} startDate
     * @param {?} endDate
     * @return {?}
     */
    injectMockInformation(startDate, endDate) {
    }
    /**
     * @param {?} categoryName
     * @return {?}
     */
    onNavigationCategoryClick(categoryName) {
    }
}
E5coreUiMonitorSlaCompletionHighchartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-completion-highcharts',
                template: "<div>\n    <mat-chip-list *ngIf=\"model\">\n        <!--<mat-chip *ngFor=\"let item of model.selectedCategories;let firstElement = first; let lastElement = last\" (click)=\"onNavigationCategoryClick(item.categoryName)\">{{item.categoryName}}</mat-chip>-->\n    </mat-chip-list>\n\n    <mat-form-field>\n      <mat-select placeholder=\"Select Month\" [(value)]=\"selectedMonthViewValue\" (selectionChange)=\"reloadChart($event)\">\n        <mat-option *ngFor=\"let optionMonth of optionMonths\" [value]=\"optionMonth.viewValue\">\n          {{optionMonth.viewValue}}\n        </mat-option>\n      </mat-select>\n    </mat-form-field>\n\n    <highcharts-chart\n    [Highcharts]=\"Highcharts\"\n    [constructorType]=\"chartConstructor\"\n    [options]=\"chartOptions\"\n    [(update)]=\"updateFlag\"\n    [oneToOne]=\"oneToOneFlag\"\n    [runOutsideAngular]=\"runOutsideAngularFlag\"\n    style=\"width: 100%; height: 400px; display: block;\"></highcharts-chart>\n\n    <!--<table>\n      <tr>\n        <td>CompletionDate</td>\n        <td>CompletedInSla</td>\n        <td>CompletedPropetyTotal</td>\n        <td>CompletedTotal</td>\n        <td>InSlaPropertyTotal</td>\n        <td>MovingAverage</td>\n        <td>MovingAverageWeekly</td>\n      </tr>\n      <tr *ngFor=\"let dataRow in model.data\">\n        <td>{{dataRow.completionDate}}</td>\n        <td>{{dataRow.completedInSla}}</td>\n        <td>{{dataRow.completedPropertyTotal}}</td>\n        <td>{{dataRow.completedTotal}}</td>\n        <td>{{dataRow.inSlaPropertyTotal}}</td>\n        <td>{{dataRow.movingAverage}}</td>\n        <td>{{dataRow.movingAverageWeekly}}</td>\n      </tr>\n    </table>-->\n</div>\n\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaCompletionHighchartsComponent.ctorParameters = () => [
    { type: MonitorsSlaCompletionMonitorService },
    { type: DatePipe }
];
E5coreUiMonitorSlaCompletionHighchartsComponent.propDecorators = {
    slaRangeInDays: [{ type: Input }],
    categorisation: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiMonitorSlaCompletionComponent {
    // Drop down menu for start date
    constructor() {
        this.slaRangeInDays = 28; // number
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiMonitorSlaCompletionComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-completion',
                template: `
    <e5core-ui-monitor-sla-completion-highcharts (slaRangeInDays)="slaRangeInDays">
    </e5core-ui-monitor-sla-completion-highcharts>
  `
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaCompletionComponent.ctorParameters = () => [];
E5coreUiMonitorSlaCompletionComponent.propDecorators = {
    slaRangeInDays: [{ type: Input }],
    startDate: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiMonitorSlaInflowsComponent {
    // Drop down menu for start date
    constructor() {
        this.slaRangeInDays = 28; // number
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiMonitorSlaInflowsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-inflows',
                template: `
    <e5core-ui-monitor-sla-inflows-highcharts (slaRangeInDays)="slaRangeInDays">
    </e5core-ui-monitor-sla-inflows-highcharts>
  `
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaInflowsComponent.ctorParameters = () => [];
E5coreUiMonitorSlaInflowsComponent.propDecorators = {
    slaRangeInDays: [{ type: Input }],
    startDate: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MockInflowsService {
    /**
     * @return {?}
     */
    getMockedSlaInflowCounts() {
        /** @type {?} */
        const incomingData = new Array();
        /** @type {?} */
        const model = new MonitorsSlaInflowsMonitorModel();
        incomingData.push({
            creationDate: new Date('2016-12-05T11:52:10.113Z'),
            activeWorkItemCount: 5,
            completeWorkItemCount: 4,
            diarisedWorkItemCount: 2,
            launchWorkItemCount: 3,
            rejectedWorkItemCount: 1,
            qaWorkItemCount: 2
        }, {
            creationDate: new Date('2016-12-06T11:52:10.113Z'),
            activeWorkItemCount: 8,
            completeWorkItemCount: 6,
            diarisedWorkItemCount: 4,
            launchWorkItemCount: 5,
            rejectedWorkItemCount: 3,
            qaWorkItemCount: 4
        }, {
            creationDate: new Date('2016-12-07T11:52:10.113Z'),
            activeWorkItemCount: 7,
            completeWorkItemCount: 5,
            diarisedWorkItemCount: 3,
            launchWorkItemCount: 4,
            rejectedWorkItemCount: 2,
            qaWorkItemCount: 3
        });
        model.data = incomingData;
        return of(model);
    }
}
class E5coreUiMonitorSlaInflowsHighchartsComponent {
    /**
     * @param {?} monitorService
     * @param {?} datePipe
     */
    constructor(monitorService, datePipe) {
        this.monitorService = monitorService;
        this.datePipe = datePipe;
        this.slaRangeInDays = 28; // Idea is to display completed work items every day over a period of time. 28 days forms exactly a month
        this.startDate = '2018-01-11T13:21:53.770Z';
        this.endDate = '2018-30-11T13:35:36.870Z';
        this.Highcharts = Highcharts;
        this.chartConstructor = 'chart';
        this.chartOptions = this.createChartOptions();
        this.chartCallback = null; // optional function, defaults to null
        // optional function, defaults to null
        this.updateFlag = false; // optional boolean
        // optional boolean
        this.oneToOneFlag = true; // optional boolean, defaults to false
        // optional boolean, defaults to false
        this.runOutsideAngularFlag = false;
        // Ready up Mock Service
        this.mockInflowsService = new MockInflowsService();
        // Month drop-down variables
        this.currentDate = new Date();
        this.currentDateRange = {
            startDate: new Date(this.currentDate.getFullYear(), this.currentDate.getMonth(), 1),
            endDate: new Date(this.currentDate.getFullYear(), this.currentDate.getMonth() + 1, 0)
        };
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.isMocked = true; // Set to false in production
        this.LoadChartObject(this.startDate, this.endDate);
        this.selectedOptionMonth = {
            value: this.currentDateRange,
            viewValue: this.datePipe.transform(this.currentDateRange.startDate, 'MMMM yyyy')
        };
        this.selectedMonthViewValue = this.selectedOptionMonth.viewValue;
        this.instantiateOptionMonths();
    }
    /**
     * @private
     * @param {?} date
     * @param {?} months
     * @return {?}
     */
    addMonths(date, months) {
        /** @type {?} */
        const newDate = date;
        newDate.setMonth(newDate.getMonth() + months);
        return (newDate);
    }
    /**
     * @private
     * @param {?} startDate
     * @param {?} endDate
     * @param {?} negativeDirection
     * @return {?}
     */
    addToOptionMonths(startDate, endDate, negativeDirection) {
        /** @type {?} */
        let currentDate = new Date(startDate);
        if (!negativeDirection) {
            while (currentDate <= endDate) {
                this.optionMonths.push({
                    value: {
                        startDate: new Date(currentDate),
                        endDate: new Date(currentDate.getFullYear(), currentDate.getMonth() + 1, 0)
                    },
                    viewValue: this.datePipe.transform(currentDate, 'MMMM yyyy')
                });
                currentDate = this.addMonths(currentDate, 1);
            }
        }
    }
    /**
     * @private
     * @param {?} monthName
     * @return {?}
     */
    convertToMonthNumber(monthName) {
        /** @type {?} */
        const months = [
            'January',
            'February',
            'March',
            'April',
            'May',
            'June',
            'July',
            'August',
            'September',
            'October',
            'November',
            'December'
        ];
        return months.indexOf(monthName);
    }
    /**
     * @private
     * @param {?} viewValue
     * @return {?}
     */
    alterSelectedMonthOption(viewValue) {
        /** @type {?} */
        const selectedValue = this.optionMonths.filter(f => f.viewValue === viewValue);
        if (selectedValue.length === 0) {
            return;
        }
        this.selectedOptionMonth = {
            value: {
                startDate: selectedValue[0].value.startDate,
                endDate: selectedValue[0].value.endDate
            },
            viewValue: viewValue
        };
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    reloadChart($event) {
        this.alterSelectedMonthOption(this.selectedMonthViewValue);
        /** @type {?} */
        const selectedDateRange = this.selectedOptionMonth.value;
        this.instantiateOptionMonths();
        this.LoadChartObject(selectedDateRange.startDate, selectedDateRange.endDate);
    }
    /**
     * @private
     * @return {?}
     */
    instantiateOptionMonths() {
        this.optionMonths = [];
        /** @type {?} */
        const currentlySelectedDate = this.selectedOptionMonth.value.startDate;
        /** @type {?} */
        const startDate = new Date(currentlySelectedDate);
        /** @type {?} */
        const endDate = new Date(currentlySelectedDate);
        startDate.setMonth(startDate.getMonth() - 5);
        endDate.setMonth(endDate.getMonth() + 5);
        /** @type {?} */
        const today = new Date();
        if (endDate > today) {
            endDate.setMonth(today.getMonth());
        }
        this.addToOptionMonths(startDate, endDate, false);
    }
    /**
     * @param {?} startDate
     * @param {?} endDate
     * @param {?=} siteGroup
     * @param {?=} category1Id
     * @param {?=} category2Id
     * @param {?=} category3Id
     * @param {?=} archive
     * @param {?=} totalProperty
     * @return {?}
     */
    LoadChartObject(startDate, endDate, siteGroup, category1Id, category2Id, category3Id, archive, totalProperty) {
        if (this.isMocked) {
            this.mockInflowsService.getMockedSlaInflowCounts().subscribe(model => {
                this.chartOptions = Object.assign({}, this.chartOptions, { xAxis: this.extractXAxis(model), series: this.extractSeries(model) });
                this.model = model;
            });
        }
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    extractXAxis(model) {
        // debugger;
        /** @type {?} */
        const output = {
            type: 'datetime',
            ordinal: false,
            mintickInterval: 24 * 3600 * 1000,
            // categories: model.data.map(i => this.datePipe.transform(i.creationDate, 'dd MMM yyyy')),
            title: { rotation: -45 },
            labels: {
                format: '<b class="xAxisLabel">{value: %e %b %y}</b>'
            }
        };
        return (output);
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    extractSeries(model) {
        // debugger;
        /** @type {?} */
        const series = [];
        // const completedWorkItems = [];
        /** @type {?} */
        const activeItems = [];
        /** @type {?} */
        const completedItems = [];
        /** @type {?} */
        const diarisedItems = [];
        /** @type {?} */
        const launchedItems = [];
        /** @type {?} */
        const rejectedItems = [];
        /** @type {?} */
        const qaItems = [];
        for (let i = 0; i < model.data.length; i++) {
            //TODO
            //   activeItems.push([model.data[i].creationDate.getTime(), model.data[i].activeWorkItemCount]);
            //   completedItems.push([model.data[i].creationDate.getTime(), model.data[i].completeWorkItemCount]);
            //   diarisedItems.push([model.data[i].creationDate.getTime(), model.data[i].diarisedWorkItemCount]);
            //   launchedItems.push([model.data[i].creationDate.getTime(), model.data[i].launchWorkItemCount]);
            //   rejectedItems.push([model.data[i].creationDate.getTime(), model.data[i].rejectedWorkItemCount]);
            //   qaItems.push([model.data[i].creationDate.getTime(), model.data[i].qaWorkItemCount]);
        }
        series.push({ name: 'Active', color: '#add8e6', data: activeItems, drilldown: true, yAxis: 0 });
        series.push({ name: 'Completed', color: '#228b22', data: completedItems, drilldown: true, yAxis: 0 });
        series.push({ name: 'Diarised', color: '#a52a2a', data: diarisedItems, drilldown: true, yAxis: 0 });
        series.push({ name: 'Launched', color: '#ffff00', data: launchedItems, drilldown: true, yAxis: 0 });
        series.push({ name: 'Rejected', color: '#ff0000', data: rejectedItems, drilldown: true, yAxis: 0 });
        series.push({ name: 'QA', color: '#ffa500', data: qaItems, drilldown: true, yAxis: 0 });
        return (series);
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    drillDown(event) {
        alert(event);
    }
    /**
     * @return {?}
     */
    createChartOptions() {
        /** @type {?} */
        const _this = this;
        return {
            chart: {
                type: 'column',
                events: {
                    drilldown: function (event) {
                        _this.drillDown(event);
                    }
                }
            },
            title: {
                text: 'Work SLA Inflows Monitor',
                style: {
                    'fontSize': '16px',
                    'font-weight': 'bold'
                }
            },
            xAxis: {
                categories: [],
                title: { rotation: -45 }
            },
            yAxis: [{
                    min: 0,
                    title: {
                        text: 'Work Item Count',
                    },
                    labels: { x: -15 },
                    stackLabels: {
                        enabled: true,
                        style: {
                            fontWeight: 'bold',
                            color: 'gray'
                        }
                    }
                }],
            legend: {
                align: 'right',
                x: -30,
                verticalAlign: 'top',
                y: 25,
                floating: true,
                backgroundColor: 'white',
                borderColor: '#CCC',
                borderWidth: 1,
                shadow: false,
                itemStyle: {
                    fontSize: '12px',
                    font: '12pt',
                }
            },
            tooltip: {
                headerFormat: '<b>{point.x: %e %b %y}</b><br/>',
                pointFormat: '{series.name}: {point.y}<br/>Total: {point.stackTotal}'
            },
            plotOptions: {
                series: {
                    stacking: 'normal',
                    dataLabels: {
                        enabled: true,
                        align: 'center',
                        color: '#FFFFFF'
                    },
                }
            },
            series: [
                {
                    name: 'Work Items Completed',
                    color: '#00cc99',
                    data: []
                }
            ],
            drilldown: {
                series: []
            }
        };
    }
    /**
     * @param {?} startDate
     * @param {?} endDate
     * @return {?}
     */
    injectMockInformation(startDate, endDate) {
    }
    /**
     * @param {?} categoryName
     * @return {?}
     */
    onNavigationCategoryClick(categoryName) {
    }
}
E5coreUiMonitorSlaInflowsHighchartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-inflows-highcharts',
                template: "<div>\n    <mat-chip-list *ngIf=\"model\">\n        <!--<mat-chip *ngFor=\"let item of model.selectedCategories;let firstElement = first; let lastElement = last\" (click)=\"onNavigationCategoryClick(item.categoryName)\">{{item.categoryName}}</mat-chip>-->\n    </mat-chip-list>\n\n    <mat-form-field>\n      <mat-select placeholder=\"Select Month\" [(value)]=\"selectedMonthViewValue\" (selectionChange)=\"reloadChart($event)\">\n        <mat-option *ngFor=\"let optionMonth of optionMonths\" [value]=\"optionMonth.viewValue\">\n          {{optionMonth.viewValue}}\n        </mat-option>\n      </mat-select>\n    </mat-form-field>\n\n    <highcharts-chart\n    [Highcharts]=\"Highcharts\"\n    [constructorType]=\"chartConstructor\"\n    [options]=\"chartOptions\"\n    [(update)]=\"updateFlag\"\n    [oneToOne]=\"oneToOneFlag\"\n    [runOutsideAngular]=\"runOutsideAngularFlag\"\n    style=\"width: 100%; height: 400px; display: block;\"></highcharts-chart>\n\n    <!--<table>\n      <tr>\n        <td>CompletionDate</td>\n        <td>CompletedInSla</td>\n        <td>CompletedPropetyTotal</td>\n        <td>CompletedTotal</td>\n        <td>InSlaPropertyTotal</td>\n        <td>MovingAverage</td>\n        <td>MovingAverageWeekly</td>\n      </tr>\n      <tr *ngFor=\"let dataRow in model.data\">\n        <td>{{dataRow.completionDate}}</td>\n        <td>{{dataRow.completedInSla}}</td>\n        <td>{{dataRow.completedPropertyTotal}}</td>\n        <td>{{dataRow.completedTotal}}</td>\n        <td>{{dataRow.inSlaPropertyTotal}}</td>\n        <td>{{dataRow.movingAverage}}</td>\n        <td>{{dataRow.movingAverageWeekly}}</td>\n      </tr>\n    </table>-->\n</div>\n\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaInflowsHighchartsComponent.ctorParameters = () => [
    { type: MonitorsSlaInflowsMonitorService },
    { type: DatePipe }
];
E5coreUiMonitorSlaInflowsHighchartsComponent.propDecorators = {
    slaRangeInDays: [{ type: Input }],
    categorisation: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiMonitorSlaInventoryComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiMonitorSlaInventoryComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-inventory',
                template: `
    <e5core-ui-monitor-sla-inventory-highcharts>
    </e5core-ui-monitor-sla-inventory-highcharts>
  `
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaInventoryComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MockInventoryService {
    /**
     * @return {?}
     */
    getMockedSlaInventoryCounts() {
        /** @type {?} */
        const incomingData = new Array();
        /** @type {?} */
        const model = new MonitorsSlaInventoryMonitorModel();
        incomingData.push({
            interval: new Date('2018-12-05T11:52:10.113Z'),
            totalCount: 10,
            statusZeroCount: 4,
            statusOneCount: 3,
            statusTwoCount: 2,
            statusThreeCount: 1
        }, {
            interval: new Date('2018-12-06T11:52:10.113Z'),
            totalCount: 15,
            statusZeroCount: 5,
            statusOneCount: 5,
            statusTwoCount: 3,
            statusThreeCount: 2
        }, {
            interval: new Date('2018-12-07T11:52:10.113Z'),
            totalCount: 20,
            statusZeroCount: 6,
            statusOneCount: 6,
            statusTwoCount: 4,
            statusThreeCount: 3
        });
        model.data = incomingData;
        return of(model);
    }
}
class E5coreUiMonitorSlaInventoryHighchartsComponent {
    /**
     * @param {?} monitorService
     * @param {?} datePipe
     */
    constructor(monitorService, datePipe) {
        this.monitorService = monitorService;
        this.datePipe = datePipe;
        this.startDate = '2018-01-11T13:21:53.770Z';
        this.endDate = '2018-30-11T13:35:36.870Z';
        this.Highcharts = Highcharts;
        this.chartConstructor = 'chart';
        this.chartOptions = this.createChartOptions();
        this.chartCallback = null; // optional function, defaults to null
        // optional function, defaults to null
        this.updateFlag = false; // optional boolean
        // optional boolean
        this.oneToOneFlag = true; // optional boolean, defaults to false
        // optional boolean, defaults to false
        this.runOutsideAngularFlag = false;
        // Ready up Mock Service
        this.mockInventoryService = new MockInventoryService();
        // Month drop-down variables
        this.currentDate = new Date();
        this.currentDateRange = {
            startDate: new Date(this.currentDate.getFullYear(), this.currentDate.getMonth(), 1),
            endDate: new Date(this.currentDate.getFullYear(), this.currentDate.getMonth() + 1, 0, 23, 59, 59, 999)
        };
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.isMocked = true; // Set to false for production
        this.LoadChartObject(this.startDate, this.endDate);
        this.selectedOptionMonth = {
            value: this.currentDateRange,
            viewValue: this.datePipe.transform(this.currentDateRange.startDate, 'MMMM yyyy')
        };
        this.selectedMonthViewValue = this.selectedOptionMonth.viewValue;
        this.instantiateOptionMonths();
    }
    /**
     * @private
     * @param {?} date
     * @param {?} months
     * @return {?}
     */
    addMonths(date, months) {
        /** @type {?} */
        const newDate = date;
        newDate.setMonth(newDate.getMonth() + months);
        return (newDate);
    }
    /**
     * @private
     * @param {?} startDate
     * @param {?} endDate
     * @param {?} negativeDirection
     * @return {?}
     */
    addToOptionMonths(startDate, endDate, negativeDirection) {
        /** @type {?} */
        let currentDate = new Date(startDate);
        if (!negativeDirection) {
            while (currentDate <= endDate) {
                this.optionMonths.push({
                    value: {
                        startDate: new Date(currentDate),
                        endDate: new Date(currentDate.getFullYear(), currentDate.getMonth() + 1, 0)
                    },
                    viewValue: this.datePipe.transform(currentDate, 'MMMM yyyy')
                });
                currentDate = this.addMonths(currentDate, 1);
            }
        }
    }
    /**
     * @private
     * @param {?} viewValue
     * @return {?}
     */
    alterSelectedMonthOption(viewValue) {
        /** @type {?} */
        const selectedValue = this.optionMonths.filter(f => f.viewValue === viewValue);
        if (selectedValue.length === 0) {
            return;
        }
        this.selectedOptionMonth = {
            value: {
                startDate: selectedValue[0].value.startDate,
                endDate: selectedValue[0].value.endDate
            },
            viewValue: viewValue
        };
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    reloadChart($event) {
        this.alterSelectedMonthOption(this.selectedMonthViewValue);
        /** @type {?} */
        const selectedDateRange = this.selectedOptionMonth.value;
        this.instantiateOptionMonths();
        this.LoadChartObject(selectedDateRange.startDate, selectedDateRange.endDate);
    }
    /**
     * @private
     * @return {?}
     */
    instantiateOptionMonths() {
        this.optionMonths = [];
        /** @type {?} */
        const currentlySelectedDate = this.selectedOptionMonth.value.startDate;
        /** @type {?} */
        const startDate = new Date(currentlySelectedDate);
        /** @type {?} */
        const endDate = new Date(currentlySelectedDate);
        startDate.setMonth(startDate.getMonth() - 5);
        endDate.setMonth(endDate.getMonth() + 5);
        /** @type {?} */
        const today = new Date();
        if (endDate > today) {
            endDate.setMonth(today.getMonth());
        }
        this.addToOptionMonths(startDate, endDate, false);
    }
    // isMocked if set to true will return mock data rather than true data, please set to false for production unless testing
    /**
     * @param {?} startDate
     * @param {?} endDate
     * @param {?=} siteGroup
     * @param {?=} category1Id
     * @param {?=} category2Id
     * @param {?=} category3Id
     * @param {?=} archive
     * @param {?=} totalProperty
     * @return {?}
     */
    LoadChartObject(startDate, endDate, siteGroup, category1Id, category2Id, category3Id, archive, totalProperty) {
        if (this.isMocked) {
            this.mockInventoryService.getMockedSlaInventoryCounts().subscribe(model => {
                this.chartOptions = Object.assign({}, this.chartOptions, { xAxis: this.extractXAxis(model), series: this.extractSeries(model) });
                this.model = model;
            });
        }
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    extractXAxis(model) {
        // debugger;
        /** @type {?} */
        const output = {
            // categories: model.data.map(i => this.datePipe.transform(i.interval, 'dd MMM yyyy')),
            type: 'datetime',
            ordinal: false,
            mintickInterval: 24 * 3600 * 1000,
            title: { rotation: -45 },
            labels: {
                format: '<b class="xAxisLabel">{value: %e %b %y}</b>'
            }
        };
        return (output);
    }
    /**
     * @private
     * @param {?} model
     * @return {?}
     */
    extractSeries(model) {
        /** @type {?} */
        const series = [];
        /** @type {?} */
        const activeItems = [];
        /** @type {?} */
        const diarisedItems = [];
        /** @type {?} */
        const launchedItems = [];
        /** @type {?} */
        const qaItems = [];
        for (let i = 0; i < model.data.length; i++) {
            //TODO
            // launchedItems.push([model.data[i].interval.getTime(), model.data[i].statusZeroCount]);
            // activeItems.push([model.data[i].interval.getTime(), model.data[i].statusOneCount]);
            // diarisedItems.push([model.data[i].interval.getTime(), model.data[i].statusTwoCount]);
            // qaItems.push([model.data[i].interval.getTime(), model.data[i].statusThreeCount]);
        }
        series.push({ name: 'Active', color: '#add8e6', data: activeItems, drilldown: true, yAxis: 0 });
        series.push({ name: 'Diarised', color: '#a52a2a', data: diarisedItems, drilldown: true, yAxis: 0 });
        series.push({ name: 'Launched', color: '#ffff00', data: launchedItems, drilldown: true, yAxis: 0 });
        series.push({ name: 'QA', color: '#ffa500', data: qaItems, drilldown: true, yAxis: 0 });
        return (series);
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    drillDown(event) {
        alert(event);
    }
    /**
     * @return {?}
     */
    createChartOptions() {
        /** @type {?} */
        const _this = this;
        return {
            chart: {
                type: 'column',
                events: {
                    drilldown: function (event) {
                        _this.drillDown(event);
                    }
                }
            },
            title: {
                text: 'Work Inventory Monitor',
                style: {
                    'fontSize': '16px',
                    'font-weight': 'bold'
                }
            },
            xAxis: {
                categories: [],
                title: { rotation: -45 }
            },
            yAxis: [{
                    min: 0,
                    title: {
                        text: 'Work Item Count',
                    },
                    labels: { x: -15 },
                    stackLabels: {
                        enabled: true,
                        style: {
                            fontWeight: 'bold',
                            color: 'gray'
                        }
                    }
                }],
            legend: {
                align: 'right',
                x: -30,
                verticalAlign: 'top',
                y: 25,
                floating: true,
                backgroundColor: 'white',
                borderColor: '#CCC',
                borderWidth: 1,
                shadow: false,
                itemStyle: {
                    fontSize: '12px',
                    font: '12pt',
                }
            },
            tooltip: {
                headerFormat: '<b>{point.x: %e %b %y}</b><br/>',
                pointFormat: '{series.name}: {point.y}<br/>Total: {point.stackTotal}'
            },
            plotOptions: {
                series: {
                    stacking: 'normal',
                    dataLabels: {
                        enabled: true,
                        align: 'center',
                        color: '#FFFFFF'
                    },
                }
            },
            series: [
                {
                    name: 'Work Items Completed',
                    color: '#00cc99',
                    data: []
                }
            ],
            drilldown: {
                series: []
            }
        };
    }
    /**
     * @param {?} startDate
     * @param {?} endDate
     * @return {?}
     */
    injectMockInformation(startDate, endDate) {
    }
    /**
     * @param {?} categoryName
     * @return {?}
     */
    onNavigationCategoryClick(categoryName) {
    }
}
E5coreUiMonitorSlaInventoryHighchartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-inventory-highcharts',
                template: "<div>\n    <mat-chip-list *ngIf=\"model\">\n        <!--<mat-chip *ngFor=\"let item of model.selectedCategories;let firstElement = first; let lastElement = last\" (click)=\"onNavigationCategoryClick(item.categoryName)\">{{item.categoryName}}</mat-chip>-->\n    </mat-chip-list>\n\n    <mat-form-field>\n      <mat-select placeholder=\"Select Month\" [(value)]=\"selectedMonthViewValue\" (selectionChange)=\"reloadChart($event)\">\n        <mat-option *ngFor=\"let optionMonth of optionMonths\" [value]=\"optionMonth.viewValue\">\n          {{optionMonth.viewValue}}\n        </mat-option>\n      </mat-select>\n    </mat-form-field>\n\n    <highcharts-chart\n    [Highcharts]=\"Highcharts\"\n    [constructorType]=\"chartConstructor\"\n    [options]=\"chartOptions\"\n    [(update)]=\"updateFlag\"\n    [oneToOne]=\"oneToOneFlag\"\n    [runOutsideAngular]=\"runOutsideAngularFlag\"\n    style=\"width: 100%; height: 400px; display: block;\"></highcharts-chart>\n\n    <!--<table>\n      <tr>\n        <td>CompletionDate</td>\n        <td>CompletedInSla</td>\n        <td>CompletedPropetyTotal</td>\n        <td>CompletedTotal</td>\n        <td>InSlaPropertyTotal</td>\n        <td>MovingAverage</td>\n        <td>MovingAverageWeekly</td>\n      </tr>\n      <tr *ngFor=\"let dataRow in model.data\">\n        <td>{{dataRow.completionDate}}</td>\n        <td>{{dataRow.completedInSla}}</td>\n        <td>{{dataRow.completedPropertyTotal}}</td>\n        <td>{{dataRow.completedTotal}}</td>\n        <td>{{dataRow.inSlaPropertyTotal}}</td>\n        <td>{{dataRow.movingAverage}}</td>\n        <td>{{dataRow.movingAverageWeekly}}</td>\n      </tr>\n    </table>-->\n</div>\n\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaInventoryHighchartsComponent.ctorParameters = () => [
    { type: MonitorsSlaInventoryMonitorService },
    { type: DatePipe }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiMonitorSlaTeamProductivityComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
E5coreUiMonitorSlaTeamProductivityComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-team-productivity',
                template: `
    <e5core-ui-monitor-sla-team-productivity-highcharts>
    </e5core-ui-monitor-sla-team-productivity-highcharts>
  `
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaTeamProductivityComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MockCompletionService {
    /**
     * @return {?}
     */
    getMockedSlaTeamProductivityCompletionCounts() {
        /** @type {?} */
        const incomingData = new Array();
        /** @type {?} */
        const model = new MonitorsSlaTeamProductivityCompletionMonitorModel();
        incomingData.push({
            interval: new Date('2018-12-05T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 10
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 15
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 20
                }
            ],
            totalCount: 45
        }, {
            interval: new Date('2018-12-06T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 12
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 14
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 17
                }
            ],
            totalCount: 43
        }, {
            interval: new Date('2018-12-07T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 15
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 20
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 25
                }
            ],
            totalCount: 60
        }, {
            interval: new Date('2018-12-08T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 20
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 25
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 30
                }
            ],
            totalCount: 75
        }, {
            interval: new Date('2018-12-09T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 20
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 25
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 25
                }
            ],
            totalCount: 70
        }, {
            interval: new Date('2018-12-10T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 18
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 25
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 27
                }
            ],
            totalCount: 70
        }, {
            interval: new Date('2018-12-11T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 20
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 25
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 30
                }
            ],
            totalCount: 75
        }, {
            interval: new Date('2018-12-12T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 10
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 20
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 21
                }
            ],
            totalCount: 51
        }, {
            interval: new Date('2018-12-13T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 20
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 25
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 30
                }
            ],
            totalCount: 75
        }, {
            interval: new Date('2018-12-14T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 10
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 15
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 20
                }
            ],
            totalCount: 45
        }, {
            interval: new Date('2018-12-15T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 10
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 15
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 20
                }
            ],
            totalCount: 45
        }, {
            interval: new Date('2018-12-16T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 12
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 14
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 17
                }
            ],
            totalCount: 43
        }, {
            interval: new Date('2018-12-17T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 15
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 20
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 25
                }
            ],
            totalCount: 60
        }, {
            interval: new Date('2018-12-18T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 20
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 25
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 30
                }
            ],
            totalCount: 75
        }, {
            interval: new Date('2018-12-19T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 10
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 20
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 21
                }
            ],
            totalCount: 51
        }, {
            interval: new Date('2018-12-20T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 18
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 20
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 19
                }
            ],
            totalCount: 57
        }, {
            interval: new Date('2018-12-21T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 20
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 25
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 30
                }
            ],
            totalCount: 75
        }, {
            interval: new Date('2018-12-22T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 10
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 15
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 20
                }
            ],
            totalCount: 45
        }, {
            interval: new Date('2018-12-23T11:52:10.113Z'),
            userWorkCounts: [
                {
                    userName: 'Rias Gremory',
                    completionCount: 10
                },
                {
                    userName: 'Mikoto Misaka',
                    completionCount: 15
                },
                {
                    userName: 'Tohka Yatogami',
                    completionCount: 20
                }
            ],
            totalCount: 45
        });
        model.data = incomingData;
        return of(model);
    }
}
class MockFaceTimeService {
    /**
     * @return {?}
     */
    getMockedSlaTeamProductivityFacetimeCounts() {
        /** @type {?} */
        const incomingData = new Array();
        /** @type {?} */
        const model = new MonitorsSlaTeamProductivityFacetimeMonitorModel();
        incomingData.push({
            interval: new Date('2018-12-05T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 50
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 40
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 30
                }
            ],
            totalCount: 120
        }, {
            interval: new Date('2018-12-06T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 126
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 70
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 50
                }
            ],
            totalCount: 246
        }, {
            interval: new Date('2018-12-07T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 86
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 101
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 154
                }
            ],
            totalCount: 341
        }, {
            interval: new Date('2018-12-08T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 62
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 84
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 93
                }
            ],
            totalCount: 239
        }, {
            interval: new Date('2018-12-09T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 110
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 120
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 150
                }
            ],
            totalCount: 380
        }, {
            interval: new Date('2018-12-10T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 80
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 190
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 200
                }
            ],
            totalCount: 470
        }, {
            interval: new Date('2018-12-11T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 190
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 170
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 140
                }
            ],
            totalCount: 500
        }, {
            interval: new Date('2018-12-12T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 100
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 90
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 62
                }
            ],
            totalCount: 252
        }, {
            interval: new Date('2018-12-13T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 80
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 190
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 200
                }
            ],
            totalCount: 470
        }, {
            interval: new Date('2018-12-14T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 60
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 80
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 90
                }
            ],
            totalCount: 230
        }, {
            interval: new Date('2018-12-15T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 50
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 40
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 30
                }
            ],
            totalCount: 120
        }, {
            interval: new Date('2018-12-16T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 126
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 70
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 50
                }
            ],
            totalCount: 246
        }, {
            interval: new Date('2018-12-17T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 86
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 101
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 154
                }
            ],
            totalCount: 341
        }, {
            interval: new Date('2018-12-18T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 190
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 170
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 140
                }
            ],
            totalCount: 500
        }, {
            interval: new Date('2018-12-19T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 100
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 90
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 62
                }
            ],
            totalCount: 252
        }, {
            interval: new Date('2018-12-20T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 105
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 110
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 115
                }
            ],
            totalCount: 330
        }, {
            interval: new Date('2018-12-21T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 86
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 101
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 154
                }
            ],
            totalCount: 341
        }, {
            interval: new Date('2018-12-22T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 62
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 84
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 93
                }
            ],
            totalCount: 239
        }, {
            interval: new Date('2018-12-23T11:52:10.113Z'),
            userFacetimeCounts: [
                {
                    userName: 'Rias Gremory',
                    faceTimeCount: 110
                },
                {
                    userName: 'Mikoto Misaka',
                    faceTimeCount: 120
                },
                {
                    userName: 'Tohka Yatogami',
                    faceTimeCount: 150
                }
            ],
            totalCount: 380
        });
        model.data = incomingData;
        return of(model);
    }
}
class E5coreUiMonitorSlaTeamProductivityHighchartsComponent {
    /**
     * @param {?} monitorCompletionService
     * @param {?} monitorFacetimeService
     * @param {?} datePipe
     */
    constructor(monitorCompletionService, monitorFacetimeService, datePipe) {
        this.monitorCompletionService = monitorCompletionService;
        this.monitorFacetimeService = monitorFacetimeService;
        this.datePipe = datePipe;
        // Ready up mock services
        this.mockCompletionService = new MockCompletionService();
        this.mockFaceTimeService = new MockFaceTimeService();
        this.finalModel = this.mergeServiceCalls(true);
        this.Highcharts = Highcharts;
        this.chartConstructor = 'chart';
        this.chartOptions = this.createChartOptions();
        this.chartCallback = null; // optional function, defaults to null
        // optional function, defaults to null
        this.updateFlag = false; // optional boolean
        // optional boolean
        this.oneToOneFlag = true; // optional boolean, defaults to false
        // optional boolean, defaults to false
        this.runOutsideAngularFlag = false;
        // Month drop-down variables
        this.currentDate = new Date();
        this.currentDateRange = {
            startDate: new Date(this.currentDate.getFullYear(), this.currentDate.getMonth(), 1),
            endDate: new Date(this.currentDate.getFullYear(), this.currentDate.getMonth() + 1, 0, 23, 59, 59, 999)
        };
        this.groupingUnits = [
            [
                'week',
                [1] // allowed multiples
            ],
            [
                'month',
                [1]
            ]
        ];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.selectedOptionMonth = {
            value: this.currentDateRange,
            viewValue: this.datePipe.transform(this.currentDateRange.startDate, 'MMMM yyyy')
        };
        /** @type {?} */
        const selectedDateRange = this.selectedOptionMonth.value;
        this.selectedMonthViewValue = this.selectedOptionMonth.viewValue;
        this.instantiateOptionMonths();
        this.LoadChartObject(selectedDateRange.startDate, selectedDateRange.endDate);
    }
    /**
     * @private
     * @param {?} date
     * @param {?} months
     * @return {?}
     */
    addMonths(date, months) {
        /** @type {?} */
        const newDate = date;
        newDate.setMonth(newDate.getMonth() + months);
        return (newDate);
    }
    /**
     * @private
     * @param {?} startDate
     * @param {?} endDate
     * @param {?} negativeDirection
     * @return {?}
     */
    addToOptionMonths(startDate, endDate, negativeDirection) {
        /** @type {?} */
        let currentDate = new Date(startDate);
        if (!negativeDirection) {
            while (currentDate <= endDate) {
                this.optionMonths.push({
                    value: {
                        startDate: new Date(currentDate),
                        endDate: new Date(currentDate.getFullYear(), currentDate.getMonth() + 1, 0, 23, 59, 59, 999)
                    },
                    viewValue: this.datePipe.transform(currentDate, 'MMMM yyyy')
                });
                currentDate = this.addMonths(currentDate, 1);
            }
        }
    }
    /**
     * @private
     * @param {?} viewValue
     * @return {?}
     */
    alterSelectedMonthOption(viewValue) {
        /** @type {?} */
        const selectedValue = this.optionMonths.filter(f => f.viewValue === viewValue);
        if (selectedValue.length === 0) {
            return;
        }
        this.selectedOptionMonth = {
            value: {
                startDate: selectedValue[0].value.startDate,
                endDate: selectedValue[0].value.endDate
            },
            viewValue: viewValue
        };
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    reloadChart($event) {
        this.alterSelectedMonthOption(this.selectedMonthViewValue);
        /** @type {?} */
        const selectedDateRange = this.selectedOptionMonth.value;
        this.instantiateOptionMonths();
        this.LoadChartObject(selectedDateRange.startDate, selectedDateRange.endDate);
    }
    /**
     * @private
     * @return {?}
     */
    instantiateOptionMonths() {
        this.optionMonths = [];
        /** @type {?} */
        const currentlySelectedDate = this.selectedOptionMonth.value.startDate;
        /** @type {?} */
        const startDate = new Date(currentlySelectedDate);
        /** @type {?} */
        const endDate = new Date(currentlySelectedDate);
        startDate.setMonth(startDate.getMonth() - 5);
        endDate.setMonth(endDate.getMonth() + 5);
        /** @type {?} */
        const today = new Date();
        if (endDate > today) {
            endDate.setMonth(today.getMonth());
        }
        this.addToOptionMonths(startDate, endDate, false);
    }
    /**
     * @private
     * @param {?} isMocked
     * @param {?=} startDate
     * @param {?=} endDate
     * @param {?=} category1Id
     * @param {?=} category2Id
     * @param {?=} category3Id
     * @param {?=} statuses
     * @param {?=} calculatedIntervals
     * @param {?=} userGroupsId
     * @param {?=} concatPivotFields
     * @param {?=} debug
     * @return {?}
     */
    mergeServiceCalls(isMocked, startDate, endDate, category1Id, category2Id, category3Id, statuses, calculatedIntervals, userGroupsId, concatPivotFields, debug) {
        /** @type {?} */
        let compeltionModel;
        /** @type {?} */
        let faceTimeModel;
        /** @type {?} */
        const options = {
            category1Id: category1Id,
            category2Id: category2Id,
            category3Id: category3Id,
            statuses: statuses,
            calculatedIntervals: calculatedIntervals,
            userGroupsId: userGroupsId,
            concatPivotFields: concatPivotFields,
            debug: debug
        };
        if (isMocked) {
            this.mockCompletionService.getMockedSlaTeamProductivityCompletionCounts().subscribe(x => {
                compeltionModel = x;
            });
            this.mockFaceTimeService.getMockedSlaTeamProductivityFacetimeCounts().subscribe(x => {
                faceTimeModel = x;
            });
        }
        else {
            this.monitorCompletionService.getTeamProductivityCompletionSlaMonitorWorkCounts(startDate, endDate, options).subscribe(x => {
                compeltionModel = x;
            });
            this.monitorFacetimeService.getTeamProductivityFacetimeSlaMonitorWorkCounts(startDate, endDate, options).subscribe(x => {
                faceTimeModel = x;
            });
        }
        /** @type {?} */
        const finalModel = {
            completionModel: compeltionModel,
            faceTimeModel: faceTimeModel
        };
        return of(finalModel);
    }
    /**
     * @param {?} startDate
     * @param {?} endDate
     * @param {?=} category1Id
     * @param {?=} category2Id
     * @param {?=} category3Id
     * @param {?=} statuses
     * @param {?=} calculatedIntervals
     * @param {?=} userGroupsId
     * @param {?=} concatPivotFields
     * @param {?=} debug
     * @return {?}
     */
    LoadChartObject(startDate, endDate, category1Id, category2Id, category3Id, statuses, calculatedIntervals, userGroupsId, concatPivotFields, debug) {
        this.finalModel.subscribe(model => {
            this.chartOptions = Object.assign({}, this.chartOptions, { xAxis: this.extractXAxis(), series: this.extractSeries(model.completionModel, model.faceTimeModel) });
            this.model = model;
        });
    }
    /**
     * @private
     * @return {?}
     */
    extractXAxis() {
        /** @type {?} */
        const output = {
            id: 'dateaxis',
            type: 'datetime',
            ordinal: false,
            mintickInterval: 24 * 3600 * 1000,
            title: { rotation: -45 },
            labels: {
                format: '<b class="xAxisLabel">{value:%e %b %y}</b>'
            }
        };
        return output;
    }
    /**
     * @private
     * @param {?} completionModel
     * @param {?} facetimeModel
     * @return {?}
     */
    extractSeries(completionModel, facetimeModel) {
        /** @type {?} */
        const series = [];
        /** @type {?} */
        let userSerieses = new Array();
        /** @type {?} */
        const users = [];
        if (typeof (facetimeModel) !== 'undefined') {
            facetimeModel.data.forEach(element => {
                element.userFacetimeCounts.forEach(x => {
                    if (!users.includes(x.userName)) {
                        users.push(x.userName);
                    }
                });
            });
            //TODO:
            // users.forEach(element => {
            //   facetimeModel.data.forEach(x => {
            //     const interval = x.interval.getTime();
            //     x.userFacetimeCounts.forEach(y => {
            //       if (y.userName === element) {
            //         dataSeries.push([interval, y.faceTimeCount]);
            //       }
            //     });
            //   });
            //   userSerieses.push({
            //     userName: element,
            //     valueSeries: dataSeries
            //   });
            //   dataSeries = [];
            // });
            userSerieses.forEach(x => {
                series.push({
                    id: users.length + userSerieses.indexOf(x) + 1 + '',
                    name: x.userName,
                    color: this.determineColorFromIndex(userSerieses.indexOf(x)),
                    data: x.valueSeries,
                    drilldown: true,
                    type: 'line',
                    yAxis: 0,
                    linkedTo: users.indexOf(x.userName) + '',
                    stack: 'faceTime',
                    dataGrouping: {
                        units: this.groupingUnits
                    },
                    showInNavigator: true
                });
            });
        }
        userSerieses = [];
        if (typeof (completionModel) !== 'undefined') {
            completionModel.data.forEach(element => {
                element.userWorkCounts.forEach(x => {
                    if (!users.includes(x.userName)) {
                        users.push(x.userName);
                    }
                });
            });
            // users.forEach(element => {
            //   completionModel.data.forEach(x => {
            //     const interval = x.interval.getTime();
            //     x.userWorkCounts.forEach(y => {
            //       if (y.userName === element) {
            //         dataSeries.push([interval, y.completionCount]);
            //       }
            //     });
            //   });
            //   userSerieses.push({
            //     userName: element,
            //     valueSeries: dataSeries
            //   });
            //   dataSeries = [];
            // });
            userSerieses.forEach(x => {
                series.push({
                    id: userSerieses.indexOf(x) + '',
                    name: x.userName,
                    color: this.determineColorFromIndex(userSerieses.indexOf(x)),
                    data: x.valueSeries,
                    drilldown: true,
                    type: 'column',
                    yAxis: 1,
                    stack: 'completion',
                    dataGrouping: {
                        units: this.groupingUnits
                    }
                });
            });
        }
        return (series);
    }
    /**
     * @private
     * @param {?} index
     * @return {?}
     */
    determineColorFromIndex(index) {
        /** @type {?} */
        const greyLight = '#92A8CD';
        /** @type {?} */
        const blueLight = '#3D96AE';
        /** @type {?} */
        const blueDark = '#5F8BC0';
        /** @type {?} */
        const purpleDark = '#80699B';
        /** @type {?} */
        const orangeDark = '#FF7300';
        /** @type {?} */
        const greenLight = '#B5CA92';
        /** @type {?} */
        const greenDark = '#89A54E';
        /** @type {?} */
        const redDark = '#AA4643';
        /** @type {?} */
        const brownLight = '#A47D7C';
        /** @type {?} */
        const pinkLight = '#CC92CC';
        /** @type {?} */
        const colourList = [blueDark, redDark, greenDark, purpleDark, blueLight, orangeDark, greyLight, greenLight, brownLight, pinkLight];
        return colourList[index % 10];
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    drillDown(event) {
        alert(event);
    }
    /**
     * @return {?}
     */
    createChartOptions() {
        /** @type {?} */
        const _this = this;
        return {
            chart: {
                alignTicks: false,
                events: {
                    drilldown: function (event) {
                        _this.drillDown(event);
                    }
                }
            },
            exporting: {
                enabled: false
            },
            title: {
                text: 'Team Productivity',
                style: {
                    'fontSize': '16px',
                    'font-weight': 'bold'
                }
            },
            xAxis: {
                categories: [],
                title: { rotation: -45 },
            },
            yAxis: [{
                    min: 0,
                    title: {
                        text: 'Work FaceTime Count',
                    },
                    labels: {
                        enabled: false
                    },
                    height: 150,
                    stackLabels: {
                        enabled: false,
                        style: {
                            fontWeight: 'bold',
                            color: 'gray'
                        }
                    }
                },
                {
                    min: 0,
                    title: {
                        text: 'Work Completed',
                    },
                    height: 95,
                    top: 200,
                    opposite: false,
                    labels: {
                        enabled: false
                    },
                    stackLabels: {
                        enabled: false,
                        style: {
                            fontWeight: 'bold',
                            color: 'gray'
                        }
                    }
                }],
            legend: {
                align: 'center',
                x: -30,
                verticalAlign: 'top',
                y: 25,
                floating: true,
                backgroundColor: 'white',
                borderColor: '#CCC',
                borderWidth: 1,
                shadow: false,
                itemStyle: {
                    fontSize: '12px',
                    font: '12pt',
                }
            },
            navigator: {
                adaptToUpdatedData: false,
                enabled: true,
                xAxis: {
                    id: 'dateaxis',
                    type: 'datetime',
                    ordinal: false,
                    labels: {
                        format: '{value:%e %b %y}'
                    },
                    minTickInterval: 24 * 3600 * 1000
                },
                series: {
                    marker: true
                }
            },
            rangeSelector: {
                enabled: true,
                allButtonsEnabled: true,
                verticalAlign: 'top',
                buttons: [
                    {
                        type: 'week',
                        count: 1,
                        text: '1W'
                    },
                    {
                        type: 'all',
                        text: 'All'
                    }
                ],
                selected: 2,
                inputEnabled: true
            },
            tooltip: {
                shared: true,
                useHTML: true,
                formatter: function () {
                    return _this.formatterFunction(this);
                }
            },
            plotOptions: {
                column: {
                    stacking: 'normal'
                },
                series: {
                    // stacking: 'normal',
                    dataLabels: {
                        enabled: true,
                        align: 'center',
                        color: '#FFFFFF'
                    },
                    dataGrouping: {
                        units: this.groupingUnits
                    },
                    events: {
                        legendItemClick: function (event) {
                            _this.onClick(this, event);
                        }
                    }
                }
            },
            series: [{
                    name: 'test',
                    type: 'line',
                    data: [0]
                }]
        };
    }
    /**
     * @param {?} eventThis
     * @param {?} eventData
     * @return {?}
     */
    onClick(eventThis, eventData) {
        /** @type {?} */
        const chart = eventThis.chart;
        /** @type {?} */
        const series = chart.series;
        /** @type {?} */
        const display = eventThis.visible ? false : true;
        eventThis.setVisible(display, false);
        eventThis.linkedSeries.setVisible(display, false);
        chart.redraw(true); // "false" forces redraw without animations
        eventThis.preventDefault();
    }
    /**
     * @param {?} value
     * @param {?} timeType
     * @param {?} fullTextLabels
     * @param {?} showMiddleZeroes
     * @param {?} precisionName
     * @param {?} showZeros
     * @return {?}
     */
    userFriendlyTime(value, timeType, fullTextLabels, showMiddleZeroes, precisionName, showZeros) {
        /** @type {?} */
        let seconds = 0;
        // convert initial units into seconds
        switch (timeType) {
            case 'seconds':
                seconds = value;
                break;
            case 'minutes':
                seconds = value * 60;
                break;
            case 'hours':
                seconds = value * 60 * 60;
                break;
            case 'days':
                seconds = value * 60 * 60 * 24;
                break;
            default:
                throw new Error('Unsupported time type');
        }
        // define available units
        /** @type {?} */
        const units = {
            'year': { seconds: 24 * 60 * 60 * 365, shortName: 'y' },
            'month': { seconds: 24 * 60 * 60 * 30, shortName: 'mth' },
            'week': { seconds: 24 * 60 * 60 * 7, shortName: 'w' },
            'day': { seconds: 24 * 60 * 60, shortName: 'd' },
            'hour': { seconds: 60 * 60, shortName: 'h' },
            'minute': { seconds: 60, shortName: 'm' },
            'second': { seconds: 1, shortName: 's' }
        };
        /** @type {?} */
        const result = [];
        for (const name of Object.keys(units)) {
            /** @type {?} */
            const unitObj = units[name];
            /** @type {?} */
            const p = Math.floor(seconds / unitObj.seconds);
            if (fullTextLabels) {
                if (p === 1) {
                    result.push(p + ' ' + name);
                }
                else if (p >= 2) {
                    result.push(p + ' ' + name + 's');
                }
                else if (showMiddleZeroes && p === 0 && result.length > 0) {
                    result.push(0 + ' ' + name + 's');
                }
            }
            else if (p >= 1) {
                result.push(p + unitObj.shortName);
            }
            else if (showMiddleZeroes && p === 0 && result.length > 0) {
                result.push(0 + unitObj.shortName);
            }
            seconds %= unitObj.seconds;
            if (precisionName && precisionName === name) {
                break;
            }
            // if (p > 0) console.log(result[result.length - 1]);
        }
        /** @type {?} */
        let resultStr = result.join(' ');
        if (!resultStr && showZeros) {
            if (precisionName) {
                if (fullTextLabels) {
                    resultStr = '0' + ' ' + precisionName + 's';
                }
                else {
                    resultStr = '0' + units[precisionName].shortName;
                }
            }
            else {
                resultStr = '-';
            }
        }
        return resultStr;
    }
    /**
     * @param {?} eventThis
     * @return {?}
     */
    formatterFunction(eventThis) {
        /** @type {?} */
        const workCompletion = [];
        /** @type {?} */
        const faceTime = [];
        eventThis.points.forEach(x => {
            if (x.point.series.options.stack === 'completion') {
                workCompletion.push(x);
            }
            else {
                faceTime.push(x);
            }
        });
        /** @type {?} */
        const headerString = `<b>${this.datePipe.transform(eventThis.x, 'dd MMM yyyy')}</b>
    `;
        /** @type {?} */
        const headerRow = `<table>
      <tr>
        <td style="text-align: center;">User</td>
        <td style="text-align: center;">FaceTime</td>
        <td style="text-align: center;">Completion</td>
      </tr>`;
        /** @type {?} */
        let seriesStrings = '';
        for (let i = 0; i < workCompletion.length; i++) {
            /** @type {?} */
            const seriesString = `<tr>
        <td>
          <span style="text-align: center; color: ${this.determineColorFromIndex(i)};">${workCompletion[i].series.name}</span>
        </td>
        <td>
          <span style="text-align: center;">${this.userFriendlyTime(faceTime[i].y, 'seconds', false, false, 'second', true)}</span>
        </td>
        <td>
          <span style="text-align: center;">${workCompletion[i].y}</span>
        </td>
      </tr>`;
            seriesStrings = seriesStrings + seriesString;
        }
        return headerString + headerRow + seriesStrings + '</table>';
    }
    /**
     * @param {?} startDate
     * @param {?} endDate
     * @return {?}
     */
    injectMockInformation(startDate, endDate) {
    }
    /**
     * @param {?} categoryName
     * @return {?}
     */
    onNavigationCategoryClick(categoryName) {
    }
}
E5coreUiMonitorSlaTeamProductivityHighchartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-monitor-sla-team-productivity-highcharts',
                template: "<div>\n    <mat-form-field>\n      <mat-select placeholder=\"Select Month\" [(value)]=\"selectedMonthViewValue\" (selectionChange)=\"reloadChart($event)\">\n        <mat-option *ngFor=\"let optionMonth of optionMonths\" [value]=\"optionMonth.viewValue\">\n          {{optionMonth.viewValue}}\n        </mat-option>\n      </mat-select>\n    </mat-form-field>\n\n    <highcharts-chart\n    [Highcharts]=\"Highcharts\"\n    [constructorType]=\"chartConstructor\"\n    [options]=\"chartOptions\"\n    [(update)]=\"updateFlag\"\n    [oneToOne]=\"oneToOneFlag\"\n    [runOutsideAngular]=\"runOutsideAngularFlag\"\n    style=\"width: 100%; height: 400px; display: block;\"></highcharts-chart>\n\n    <!--<highcharts-chart\n    [Highcharts]=\"completionHighcharts\"\n    [constructorType]=\"completionChartConstructor\"\n    [options]=\"completionChartOptions\"\n    [(update)]=\"completionChartUpdateFlag\"\n    [oneToOne]=\"completionChartOneToOneFlag\"\n    [runOutsideAngular]=\"completionChartRunOutsideAngularFlag\"\n    style=\"width: 100%; height: 400px; display: block;\"></highcharts-chart>\n\n    <highcharts-chart\n    [Highcharts]=\"faceTimeHighcharts\"\n    [constructorType]=\"faceTimeChartConstructor\"\n    [options]=\"faceTimeChartOptions\"\n    [(update)]=\"faceTimeChartUpdateFlag\"\n    [oneToOne]=\"faceTimeChartOneToOneFlag\"\n    [runOutsideAngular]=\"faceTimeChartRunOutsideAngularFlag\"\n    style=\"width: 100%; height: 400px; display: block;\"></highcharts-chart>-->\n\n    <!--<table>\n      <tr>\n        <td>CompletionDate</td>\n        <td>CompletedInSla</td>\n        <td>CompletedPropetyTotal</td>\n        <td>CompletedTotal</td>\n        <td>InSlaPropertyTotal</td>\n        <td>MovingAverage</td>\n        <td>MovingAverageWeekly</td>\n      </tr>\n      <tr *ngFor=\"let dataRow in model.data\">\n        <td>{{dataRow.completionDate}}</td>\n        <td>{{dataRow.completedInSla}}</td>\n        <td>{{dataRow.completedPropertyTotal}}</td>\n        <td>{{dataRow.completedTotal}}</td>\n        <td>{{dataRow.inSlaPropertyTotal}}</td>\n        <td>{{dataRow.movingAverage}}</td>\n        <td>{{dataRow.movingAverageWeekly}}</td>\n      </tr>\n    </table>-->\n</div>\n\n",
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiMonitorSlaTeamProductivityHighchartsComponent.ctorParameters = () => [
    { type: MonitorsSlaTeamProductivityCompletionMonitorService },
    { type: MonitorsSlaTeamProductivityFacetimeMonitorService },
    { type: DatePipe }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const DiariseUnit = {
    Days: 1,
    Weeks: 2,
    Months: 3,
    Year: 4,
    Tomorrow: 5,
};
DiariseUnit[DiariseUnit.Days] = 'Days';
DiariseUnit[DiariseUnit.Weeks] = 'Weeks';
DiariseUnit[DiariseUnit.Months] = 'Months';
DiariseUnit[DiariseUnit.Year] = 'Year';
DiariseUnit[DiariseUnit.Tomorrow] = 'Tomorrow';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DiariseReasonModel {
    /**
     * @param {?} item
     */
    constructor(item) {
        this.id = item.id;
        this.code = item.code;
        this.reason = item.reason;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkDiariseComponent {
    /**
     * @param {?} workItemFoundationService
     * @param {?} workMenuItemService
     * @param {?} locale
     * @param {?} datePipe
     */
    constructor(workItemFoundationService, workMenuItemService, locale, datePipe) {
        this.workItemFoundationService = workItemFoundationService;
        this.workMenuItemService = workMenuItemService;
        this.locale = locale;
        this.datePipe = datePipe;
        this.dateChange = new EventEmitter();
        this.reasonTextChange = new EventEmitter();
        this.reasonChange = new EventEmitter();
        this.diariseWork = new EventEmitter();
        this.timeChange = new EventEmitter();
        this.diariseReasonOption = '';
        this.showDiariseTime = true;
        this.showDiariseButton = true;
        this.showDiariseReasonDropdown = true;
    }
    /**
     * @return {?}
     */
    get diariseDate() {
        return this._diariseDate;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set diariseDate(value) {
        this._diariseDate = value;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.workItem$ === 'undefined') {
            console.error('e5core-ui-work-diarise [workItem$] must have a BehaviorSubject<WorkItemModel>');
            return;
        }
        if (this.displayedTime == null) {
            /** @type {?} */
            const currentTime = this.formatAMPM(new Date());
            this.displayedTime = currentTime;
        }
        if (this.displayedDate == null) {
            this.displayedDate = new Date();
        }
        if (typeof this.workItem$ != null) {
            this.workItem$.subscribe(w => {
                this.workId = w.workId;
                if (this.showDiariseReasonDropdown) {
                    this.reasons = new Array();
                    if (this.workId !== '00000000-0000-0000-0000-000000000000') {
                        this.GetDiariseReasons();
                    }
                }
            });
        }
    }
    /**
     * @private
     * @param {?} clickedDiariseOption
     * @return {?}
     */
    calculateDiariseDate(clickedDiariseOption) {
        /** @type {?} */
        const unit = parseInt(DiariseUnit[clickedDiariseOption.diariseUnit], 10);
        /** @type {?} */
        const increment = parseInt(clickedDiariseOption.value.toString(), 10);
        this.diariseDate = new Date();
        switch (unit) {
            case DiariseUnit.Tomorrow:
                {
                    this.diariseDate.setDate(this.diariseDate.getDate() + 1);
                    break;
                }
            case DiariseUnit.Days:
                {
                    this.diariseDate.setDate(this.diariseDate.getDate() + increment);
                    break;
                }
            case DiariseUnit.Months:
                {
                    this.diariseDate.setMonth(this.diariseDate.getMonth() + increment);
                    break;
                }
            case DiariseUnit.Weeks:
                {
                    this.diariseDate.setDate(this.diariseDate.getDate() + increment * 7);
                    break;
                }
            case DiariseUnit.Year:
                {
                    this.diariseDate.setFullYear(this.diariseDate.getFullYear() + increment);
                    break;
                }
        }
    }
    /**
     * @private
     * @return {?}
     */
    setDatePickerDate() {
        // for(let datePicker of this.datePickerComponents.toArray()){
        //   datePicker.displayedDate = this.diariseDate;
        this.displayedDate = this.diariseDate;
    }
    /**
     * @private
     * @param {?} tempDate
     * @return {?}
     */
    formatAMPM(tempDate) {
        /** @type {?} */
        let minuteString;
        /** @type {?} */
        let hours = tempDate.getHours();
        /** @type {?} */
        const minutes = tempDate.getMinutes();
        /** @type {?} */
        const ampm = hours >= 12 ? 'pm' : 'am';
        hours = hours % 12;
        hours = hours ? hours : 12; // the hour '0' should be '12'
        minuteString = minutes < 10 ? '0' + minutes.toString() : minutes.toString();
        /** @type {?} */
        const strTime = hours.toString() + ':' + minuteString + ' ' + ampm;
        return strTime;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiarisePeriodOptionClick($event) {
        this.calculateDiariseDate($event.diariseOption);
        this.setDatePickerDate();
        this.diarisePeriodOption = $event.diariseOption;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseButtonClick($event) {
        //  ---Working Code------------------------------------------
        // 	let temp = {"AssessmentExplanationcode":"This is a test"};
        //   let menuData = {
        // 	"WorkItemChanges": WorkItemChanges,
        // 	"TaskChanges": null,
        // 	"AdditionalProperties": {
        // 		"result": "ok",
        // 		"DiariseReason": this.diariseReasonOption,
        // 		"DiariseUntilDate": formattedDiariseUntilDate,
        // 		"DiariseUntilHours": diariseHours,
        // 		"DiariseUntilMinutes": diariseMinutes
        // 	}
        // }
        //  _let diariseEvent : WorkDiariseEvent = {diariseOption:this.diarisePeriodOption,
        //  diariseUntilDate:diariseUntilDate, diariseUntilHours : diariseHours,
        //  diariseUntilMinutes : diariseMinutes, diariseTextReason : this.diariseReasonTextValue,
        //  diariseReasonOption : this.diariseReasonOption, menuData:menuData, source:"button"} ;
        //  ---Working Code------------------------------------------
        this.diariseWorkEvent = this.ConstructWorkDiariseEvent('button');
        this.DiariseWorkItem();
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseDateChange($event) {
        this.displayedDate = $event;
        this.diariseWorkEvent = this.ConstructWorkDiariseEvent('date');
        this.dateChange.emit(this.diariseWorkEvent);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseReasonTextChange($event) {
        this.diariseReasonTextValue = $event;
        this.diariseReasonOption = $event;
        this.diariseWorkEvent = this.ConstructWorkDiariseEvent('reasonText');
        this.reasonTextChange.emit(this.diariseWorkEvent);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseReasonChange($event) {
        this.diariseReasonOption = $event.value;
        this.diariseWorkEvent = this.ConstructWorkDiariseEvent('reasonDropdown');
        this.reasonChange.emit(this.diariseWorkEvent);
    }
    /**
     * @param {?} time
     * @return {?}
     */
    onTimeChange(time) {
        this.displayedTime = time;
        /** @type {?} */
        const diariseWorkEvent = this.ConstructWorkDiariseEvent('time');
        this.timeChange.emit(diariseWorkEvent);
    }
    /**
     * @return {?}
     */
    GetDiariseReasons() {
        this.workItemFoundationService.getDiariseReasons(this.workId).subscribe(s => {
            /** @type {?} */
            const tempReasons = s.map(item => new DiariseReasonModel(item));
            this.reasons = tempReasons;
        }, error => {
            console.error(error);
        });
    }
    /**
     * @return {?}
     */
    DiariseWorkItem() {
        this.diariseWorkEvent = this.ConstructWorkDiariseEvent('diariseWorkItem');
        /** @type {?} */
        var options = { menuItemCode: "diarise" };
        this.workMenuItemService.invokeMenuItem(this.workId, -1, this.diariseWorkEvent.menuData, options).subscribe(s => {
            this.diariseWork.emit(this.diariseWorkEvent);
        }, error => {
            console.error(error);
        });
    }
    /**
     * @param {?} eventSource
     * @return {?}
     */
    ConstructWorkDiariseEvent(eventSource) {
        /** @type {?} */
        const WorkItemChanges = {};
        if (this.diariseReasonPropertyId != null && this.diariseReasonTextValue != null) {
            WorkItemChanges[this.diariseReasonPropertyId] = this.diariseReasonTextValue;
        }
        /** @type {?} */
        const diariseUntilTime = this.ConvertTime12to24(this.displayedTime).split(':');
        /** @type {?} */
        const diariseHours = parseInt(diariseUntilTime[0], 10);
        /** @type {?} */
        const diariseMinutes = parseInt(diariseUntilTime[1], 10);
        /** @type {?} */
        const diariseUntilDate = this.datePipe.transform(this.displayedDate, 'dd/MM/yyyy');
        /** @type {?} */
        const additionalProperties = {
            result: 'ok',
            DiariseReason: this.diariseReasonOption,
            DiariseUntilDate: diariseUntilDate,
            DiaiseUntilHours: diariseHours,
            DiariseUntilMinutes: diariseMinutes
        };
        /** @type {?} */
        const menuData = {
            'WorkItemChanges': WorkItemChanges,
            'TaskChanges': null,
            'AdditionalProperties': {
                'result': 'ok',
                'DiariseReason': this.diariseReasonOption,
                'DiariseUntilDate': diariseUntilDate,
                'DiariseUntilHours': diariseHours,
                'DiariseUntilMinutes': diariseMinutes
            }
        };
        // let additionalProperties: AdditionalProperties = {result:"ok", DiariseReason:this.diariseReasonOption,
        //  DiariseUntilDate:formattedDiariseUntilDate,DiaiseUntilHours:diariseHours, DiariseUntilMinutes:diariseMinutes};
        // let menuData:DiariseMenuDataModel = {WorkItemChanges: WorkItemChanges, TaskChanges : null,
        //  AdditionalProperties:additionalProperties };
        /** @type {?} */
        const diariseEvent = {
            diariseOption: this.diarisePeriodOption,
            diariseUntilDate: diariseUntilDate,
            diariseUntilHours: diariseHours,
            diariseUntilMinutes: diariseMinutes,
            diariseTextReason: this.diariseReasonTextValue,
            diariseReasonOption: this.diariseReasonOption,
            menuData: menuData,
            source: eventSource
        };
        return diariseEvent;
    }
    /**
     * @param {?} time12h
     * @return {?}
     */
    ConvertTime12to24(time12h) {
        const [time, modifier] = time12h.split(' ');
        // tslint:disable-next-line:prefer-const
        let [hours, minutes] = time.split(':');
        if (hours === '12') {
            hours = '00';
        }
        if (modifier.toUpperCase() === 'PM') {
            hours = parseInt(hours, 10) + 12;
        }
        return hours + ':' + minutes;
    }
}
E5coreUiWorkDiariseComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-diarise',
                template: `<e5core-ui-work-diarise-material
               [periodOptions]='periodOptions'
               [reasons]='reasons'
               [displayedDate] ='displayedDate'
               [displayedTime] = 'displayedTime'
               [diariseReasonPropertyId] ='diariseReasonPropertyId'
               [diariseReasonPlaceHolder] ='diariseReasonPlaceHolder'
               [diariseReasonTextValue]='diariseReasonTextValue'
               [showDiariseButton]='showDiariseButton'
               [showDiariseTime]='showDiariseTime'
               (diariseWork)='onDiariseButtonClick($event)'
               (reasonTextChange)='onDiariseReasonTextChange($event)'
               (reasonChange)='onDiariseReasonChange($event)'
               (dateChange)='onDiariseDateChange($event)'
               (timeChange)="onTimeChange($event)"
               (periodChange)="onDiarisePeriodOptionClick($event)"
               [showDiariseReasonDropdown]='showDiariseReasonDropdown'
              >
             </e5core-ui-work-diarise-material>`
            }] }
];
/** @nocollapse */
E5coreUiWorkDiariseComponent.ctorParameters = () => [
    { type: WorkItemFoundationService },
    { type: WorkMenuItemFoundationService },
    { type: String, decorators: [{ type: Inject, args: [LOCALE_ID,] }] },
    { type: DatePipe }
];
E5coreUiWorkDiariseComponent.propDecorators = {
    workItem$: [{ type: Input }],
    diariseReasons$: [{ type: Input }],
    dateChange: [{ type: Output }],
    reasonTextChange: [{ type: Output }],
    reasonChange: [{ type: Output }],
    diariseWork: [{ type: Output }],
    timeChange: [{ type: Output }],
    periodOptions: [{ type: Input }],
    reasons: [{ type: Input }],
    diariseReasonPropertyId: [{ type: Input }],
    displayedDate: [{ type: Input }],
    displayedTime: [{ type: Input }],
    diariseReasonPlaceHolder: [{ type: Input }],
    diariseReasonTextValue: [{ type: Input }],
    diariseReasonOption: [{ type: Input }],
    showDiariseTime: [{ type: Input }],
    showDiariseButton: [{ type: Input }],
    showDiariseReasonDropdown: [{ type: Input }],
    datePickerComponents: [{ type: ViewChildren, args: ['datepicker',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiDatepickerComponent {
    /**
     * @param {?} _changeDetectorRef
     */
    constructor(_changeDetectorRef) {
        this._changeDetectorRef = _changeDetectorRef;
        this.isRequired = false;
        this.dateChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} event
     * @return {?}
     */
    updateDate(event) {
        console.log(event);
        this.displayedDate = event.target.value;
        this.dateChange.emit(this.displayedDate);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKey(event) {
        /** @type {?} */
        const inputDate = event.target.value;
        if (inputDate.length === 8 && inputDate.indexOf('/') === -1) {
            /** @type {?} */
            const year = inputDate.substring(4);
            /** @type {?} */
            const month = Number(inputDate.substring(2, 4)) - 1;
            /** @type {?} */
            const day = inputDate.substring(0, 2);
            this.displayedDate = new Date(year, month, day);
            this.dateChange.emit(this.displayedDate);
        }
        else if (inputDate.length === 10 && inputDate.indexOf('/') >= 0) {
            /** @type {?} */
            const dateSplit = inputDate.split('/');
            if (dateSplit.length >= 3) {
                /** @type {?} */
                const day = dateSplit[0];
                /** @type {?} */
                const month = Number(dateSplit[1]) - 1;
                /** @type {?} */
                const year = dateSplit[2];
                this.displayedDate = new Date(year, month, day);
                this.dateChange.emit(this.displayedDate);
            }
        }
    }
}
E5coreUiDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-datepicker',
                template: "<mat-form-field>\n  <input (keyup)=\"onKey($event)\" matInput required placeholder=\"{{placeHolder}}\" [disabled]=\"isDisabled\" [matDatepicker]=\"picker\" name=\"picker\" id=\"picker\" [(ngModel)]=\"displayedDate\" (dateChange)=\"updateDate($event)\">\n  <mat-datepicker-toggle matSuffix [for]=\"picker\"></mat-datepicker-toggle>\n  <mat-datepicker (selectedChanged)=\"updateDate($event)\" #picker></mat-datepicker>\n</mat-form-field>\n",
                providers: [
                    { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => E5coreUiDatepickerComponent), multi: true },
                ],
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [""]
            }] }
];
/** @nocollapse */
E5coreUiDatepickerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
E5coreUiDatepickerComponent.propDecorators = {
    displayedDate: [{ type: Input }],
    isDisabled: [{ type: Input }],
    placeHolder: [{ type: Input }],
    isRequired: [{ type: Input }],
    dateChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DiariseOptionClickEvent {
    /**
     * @param {?} _diariseOption
     */
    constructor(_diariseOption) {
        this.diariseOption = _diariseOption;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkDiariseBaseComponent {
    /**
     * @param {?} locale
     */
    constructor(locale) {
        this.locale = locale;
        this.periodChange = new EventEmitter();
        this.diariseWork = new EventEmitter();
        this.reasonTextChange = new EventEmitter();
        this.reasonChange = new EventEmitter();
        this.dateChange = new EventEmitter();
        this.timeChange = new EventEmitter();
        this.diariseReasonPlaceHolder = "Enter diarise reason here";
        this.showDiariseTime = true;
        this.showDiariseButton = true;
        this.showDiariseReasonDropdown = true;
        this.showDiariseReasonText = true;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} diarisePeriodOption
     * @return {?}
     */
    onDiarisePeriodOptionClick(diarisePeriodOption) {
        /** @type {?} */
        let optionClickEvent = new DiariseOptionClickEvent(diarisePeriodOption);
        this.diarisePeriod = diarisePeriodOption;
        this.periodChange.emit(optionClickEvent);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseReasonTextChange($event) {
        this.diariseReasonTextValue = $event;
        this.reasonTextChange.emit($event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseReasonChange($event) {
        this.diariseReasonOption = $event;
        this.reasonChange.emit($event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDiariseButtonClick($event) {
        this.diariseWork.emit($event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onDateChange($event) {
        this.dateChange.emit($event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onTimeChange($event) {
        this.displayedTime = $event;
        this.timeChange.emit($event);
    }
}
/** @nocollapse */
E5coreUiWorkDiariseBaseComponent.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: [LOCALE_ID,] }] }
];
E5coreUiWorkDiariseBaseComponent.propDecorators = {
    periodChange: [{ type: Output }],
    diariseWork: [{ type: Output }],
    reasonTextChange: [{ type: Output }],
    reasonChange: [{ type: Output }],
    dateChange: [{ type: Output }],
    timeChange: [{ type: Output }],
    reasons: [{ type: Input }],
    periodOptions: [{ type: Input }],
    displayedDate: [{ type: Input }],
    displayedTime: [{ type: Input }],
    diariseReasonPropertyId: [{ type: Input }],
    diariseReasonTextValue: [{ type: Input }],
    diariseReasonPlaceHolder: [{ type: Input }],
    diariseReasonOption: [{ type: Input }],
    showDiariseTime: [{ type: Input }],
    showDiariseButton: [{ type: Input }],
    showDiariseReasonDropdown: [{ type: Input }],
    showDiariseReasonText: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiWorkDiariseMaterialComponent extends E5coreUiWorkDiariseBaseComponent {
}
E5coreUiWorkDiariseMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-work-diarise-material',
                template: "<mat-chip-list *ngIf=\"periodOptions\" class=\"e5core-ui-work-diarise-period\">\n  <mat-chip *ngFor=\"let item of periodOptions\" (click)=\"onDiarisePeriodOptionClick(item)\">{{item.label}}</mat-chip>        \n</mat-chip-list>\n<e5core-ui-datepicker [displayedDate]=\"displayedDate\" class=\"e5core-ui-work-diarise-datepicker\" (dateChange)=\"onDateChange($event)\"  placeholder=\"Date\"></e5core-ui-datepicker>   \n<e5core-ui-timepicker-material *ngIf=\"showDiariseTime\" [displayedTime]=\"displayedTime\" class=\"e5core-ui-work-diarise-timepicker\" (timeChange)=\"onTimeChange($event)\"  placeholder=\"Time\"></e5core-ui-timepicker-material>\n<div *ngIf=\"diariseReasonPropertyId\">\n  <mat-form-field class=\"e5core-ui-work-diarise-reason\">\n    <textarea\n    matInput \n    name=\"{{diariseReasonPropertyId}}\"\n    placeholder=\"{{diariseReasonPlaceHolder}}\" \n    [ngModel]=\"diariseReasonTextValue\"\n    matTextareaAutosize matAutosizeMinRows=\"4\"\n    matAutosizeMaxRows=\"10\"\n    (ngModelChange)=\"onDiariseReasonTextChange($event)\"\n    >\n  </textarea>\n  </mat-form-field>\n</div>\n<div *ngIf=\"showDiariseReasonDropdown\">\n  <mat-form-field class=\"e5core-ui-work-diarise-reason-option\">\n    <mat-select placeholder=\"Select Reason\" (selectionChange)=\"onDiariseReasonChange($event)\">\n      <mat-option *ngFor=\"let item of reasons\" [value]=\"item.id\">\n        {{item.reason}}\n      </mat-option>\n    </mat-select>\n  </mat-form-field>\n</div>\n<button class=\"e5core-ui-work-diarise-button\" mat-raised-button *ngIf=\"showDiariseButton\" (click)=\"onDiariseButtonClick($event)\">Diarise</button>",
                encapsulation: ViewEncapsulation.None,
                styles: [".e5core-ui-work-diarise-datepicker{margin-right:10pt}.e5core-ui-work-diarise-period{margin-right:10pt;display:block}.e5core-ui-work-diarise-timepicker{margin-right:10pt}.e5core-ui-work-diarise-reason-option{margin-right:10pt;display:block}.e5core-ui-work-diarise-reason{margin-right:10pt;display:block;width:100%}.e5core-ui-work-diarise-button{margin-right:10pt;display:block}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiTimepickerComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeyUp(event) {
        this.timeChange.emit(event.target.value);
    }
}
E5coreUiTimepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-timepicker',
                template: `<e5core-ui-timepicker-material [displayedTime]="displayedTime" (keyup)="onKeyUp($event)"></e5core-ui-timepicker-material>`
            }] }
];
/** @nocollapse */
E5coreUiTimepickerComponent.ctorParameters = () => [];
E5coreUiTimepickerComponent.propDecorators = {
    displayedTime: [{ type: Input }],
    timeChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiTimePickerBaseComponent {
    constructor() {
        this.timeChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} time
     * @return {?}
     */
    onTimeChange(time) {
        this.timeChange.emit(time);
    }
}
E5coreUiTimePickerBaseComponent.propDecorators = {
    timeChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreUiTimepickerMaterialComponent extends E5coreUiTimePickerBaseComponent {
}
E5coreUiTimepickerMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'e5core-ui-timepicker-material',
                template: "<mat-form-field>\n<input matInput [ngxTimepicker]=\"picker\" (ngModelChange)=\"onTimeChange($event)\" [(ngModel)]=\"displayedTime\">\n  <ngx-material-timepicker #picker></ngx-material-timepicker>\n</mat-form-field>",
                styles: [""]
            }] }
];
E5coreUiTimepickerMaterialComponent.propDecorators = {
    displayedTime: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class E5coreAngularUiModule {
}
E5coreAngularUiModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    // BrowserAnimationsModule,
                    E5coreAngularServicesModule,
                    // Material
                    MatCardModule,
                    MatButtonModule,
                    MatMenuModule,
                    MatIconModule,
                    MatTabsModule,
                    MatFormFieldModule,
                    MatInputModule,
                    MatDatepickerModule,
                    MatNativeDateModule,
                    MatSelectModule,
                    MatBadgeModule,
                    MatCheckboxModule,
                    MatPaginatorModule,
                    MatTableModule,
                    MatSortModule,
                    MatProgressSpinnerModule,
                    MatChipsModule,
                    FileUploadModule,
                    HighchartsChartModule,
                    TreeTableModule,
                    NgxMaterialTimepickerModule
                ],
                declarations: [
                    E5coreAngularUiGetNextComponent,
                    E5coreUiWorkItemComponent,
                    E5coreUiWorkMenuComponent,
                    E5coreUiWorkTabComponent,
                    E5coreUiWorkFieldSetComponent,
                    E5coreUiWorkFieldComponent,
                    E5coreUiWorkHistoryComponent,
                    E5coreUiWorkTabSetComponent,
                    E5coreUiWorkAttachmentsComponent,
                    E5coreUiWorkAttachmentsMaterialComponent,
                    E5coreUiWorkMenuItemComponent,
                    E5coreUiWorkFieldTypeInputComponent,
                    E5coreUiWorkFieldTypeIntegerComponent,
                    E5CoreUiWorkItemBoxComponent,
                    E5CoreUiWorkItemBootstrapComponent,
                    E5CoreUiWorkItemMaterialComponent,
                    E5CoreUiWorkMenuMaterialComponent,
                    E5CoreUiWorkMenuBootstrapComponent,
                    E5CoreUiWorkMenuBoxComponent,
                    E5coreUiWorkMenuItemBoxComponent,
                    E5coreUiWorkMenuItemMaterialComponent,
                    E5coreUiWorkMenuItemBootstrapComponent,
                    E5coreUiWorkTabSetMaterialComponent,
                    E5coreUiWorkTabSetBoxComponent,
                    E5coreUiWorkTabSetBootstrapComponent,
                    E5coreUiWorkTabBootstrapComponent,
                    E5coreUiWorkTabBoxComponent,
                    E5coreUiWorkTabMaterialComponent,
                    E5coreUiWorkFieldSetBoxComponent,
                    E5coreUiWorkFieldSetMaterialComponent,
                    E5coreUiWorkFieldSetBootstrapComponent,
                    E5coreUiWorkFieldBootstrapComponent,
                    E5coreUiWorkFieldMaterialComponent,
                    E5coreUiWorkFieldBoxComponent,
                    E5coreUiWorkFieldTypeInputBoxComponent,
                    E5coreUiWorkFieldTypeInputMaterialComponent,
                    E5coreUiWorkFieldTypeInputBootstrapComponent,
                    E5coreUiWorkFieldTypeIntegerBootstrapComponent,
                    E5coreUiWorkFieldTypeIntegerMaterialComponent,
                    E5coreUiWorkFieldTypeIntegerBoxComponent,
                    E5coreUiWorkFieldTypeDateComponent,
                    E5coreUiWorkFieldTypeDateBoxComponent,
                    E5coreUiWorkFieldTypeDateMaterialComponent,
                    E5coreUiWorkFieldTypeDateBootstrapComponent,
                    E5coreUiWorkFieldTypeTextComponent,
                    E5coreUiWorkFieldTypeTextBoxComponent,
                    E5coreUiWorkFieldTypeTextMaterialComponent,
                    E5coreUiWorkFieldTypeTextBootstrapComponent,
                    E5coreUiWorkFieldTypeUserComponent,
                    E5coreUiWorkFieldTypeUserBoxComponent,
                    E5coreUiWorkFieldTypeUserMaterialComponent,
                    E5coreUiWorkFieldTypeUserBootstrapComponent,
                    E5coreUiWorkFieldSwitchComponent,
                    E5coreUiWorkFieldTypeCheckboxComponent,
                    E5coreUiWorkFieldTypeCheckboxBoxComponent,
                    E5coreUiWorkFieldTypeCheckboxBootstrapComponent,
                    E5coreUiWorkFieldTypeCheckboxMaterialComponent,
                    E5coreUiWorkFieldTypeListComponent,
                    E5coreUiWorkFieldTypeListMaterialComponent,
                    E5coreUiWorkFieldTypeListBoxComponent,
                    E5coreUiWorkFieldTypeListBootstrapComponent,
                    E5coreUiWorkFieldTypeCurrencyComponent,
                    E5coreUiWorkFieldTypeCurrencyBootstrapComponent,
                    E5coreUiWorkFieldTypeCurrencyBoxComponent,
                    E5coreUiWorkFieldTypeCurrencyMaterialComponent,
                    E5coreUiWorkHistoryComponent,
                    E5coreUiWorkHistoryMaterialComponent,
                    E5coreUiWorkHistoryBoxComponent,
                    E5coreUiWorkHistoryBootstrapComponent,
                    E5coreUiWorkCasenotesComponent,
                    E5coreUiWorkCasenotesBootstrapComponent,
                    E5coreUiWorkCasenotesMaterialComponent,
                    E5coreUiWorkCasenotesBoxComponent,
                    E5coreUiWorkDiariseComponent,
                    E5coreUiSearchFormComponent,
                    E5coreUiSearchFormBootstrapComponent,
                    E5coreUiSearchFormMaterialComponent,
                    E5coreUiSearchFormBoxComponent,
                    E5coreUiSearchResultsComponent,
                    E5coreUiSearchResultsBootstrapComponent,
                    E5coreUiSearchResultsMaterialComponent,
                    E5coreUiSearchResultsBoxComponent,
                    E5coreUiSearchMenuComponent,
                    E5coreUiSearchMenuBootstrapComponent,
                    E5coreUiSearchMenuMaterialComponent,
                    E5coreUiSearchMenuBoxComponent,
                    E5coreUiFileUploadComponent,
                    E5coreUiFileUploadPrimeComponent,
                    E5coreUiGenerateDocumentComponent,
                    E5coreUiGenerateDocumentMaterialComponent,
                    E5coreUiGenerateDocumentBoxComponent,
                    E5coreUiGenerateDocumentBootstrapComponent,
                    E5coreUiWorkAttachmentViewerComponent,
                    E5coreUiE5AttachmentViewerComponent,
                    E5coreUiWeburiAttachmentViewerComponent,
                    E5coreUiWebdavWeburiAttachmentViewerComponent,
                    E5coreUiConversationViewerComponent,
                    E5coreUiEmailConversationViewerComponent,
                    E5coreUiAssignUserComponent,
                    E5coreUiAssignUserMaterialComponent,
                    E5coreUiAssignUserBoxComponent,
                    E5coreUiAssignUserBootstrapComponent,
                    E5coreUiSelectFromListComponent,
                    E5coreUiSelectFromListMaterialComponent,
                    E5coreUiWorkRelatedItemsComponent,
                    E5coreUiWorkRelatedItemsPrimeComponent,
                    E5coreUiSafePipe,
                    E5coreUiCategorizationComponent,
                    E5coreUiCategorizationBootstrapComponent,
                    E5coreUiCategorizationBoxComponent,
                    E5coreUiCategorizationMaterialComponent,
                    E5coreUiMonitorSlaHighchartsComponent,
                    E5coreUiMonitorSlaComponent,
                    E5coreUiDatagridComponent,
                    E5coreUiDatagridBootstrapComponent,
                    E5coreUiDatagridMaterialComponent,
                    E5coreUiDatagridBoxComponent,
                    E5coreUiWorkDiariseComponent,
                    E5coreUiDatepickerComponent,
                    E5coreUiWorkDiariseMaterialComponent,
                    E5coreUiWorkDiariseComponent,
                    E5coreUiTimepickerComponent,
                    E5coreUiTimepickerMaterialComponent,
                    E5coreUiMonitorSlaComponent,
                    E5coreUiMonitorSlaCompletionComponent,
                    E5coreUiMonitorSlaCompletionHighchartsComponent,
                    E5coreUiMonitorSlaInflowsComponent,
                    E5coreUiMonitorSlaInflowsHighchartsComponent,
                    E5coreUiMonitorSlaInventoryComponent,
                    E5coreUiMonitorSlaInventoryHighchartsComponent,
                    E5coreUiMonitorSlaTeamProductivityComponent,
                    E5coreUiMonitorSlaTeamProductivityHighchartsComponent
                ],
                exports: [
                    E5coreAngularUiGetNextComponent,
                    E5coreUiWorkMenuComponent,
                    E5coreUiWorkItemComponent,
                    E5coreUiWorkTabSetComponent,
                    E5coreUiWorkFieldSetComponent,
                    E5coreUiWorkHistoryComponent,
                    E5coreUiWorkCasenotesComponent,
                    E5coreUiWorkDiariseComponent,
                    E5coreUiSearchResultsComponent,
                    E5coreUiSearchFormComponent,
                    E5coreUiSearchMenuComponent,
                    E5coreUiFileUploadComponent,
                    E5coreUiWorkAttachmentsComponent,
                    E5coreUiGenerateDocumentComponent,
                    E5coreUiWorkAttachmentViewerComponent,
                    E5coreUiConversationViewerComponent,
                    E5coreUiAssignUserComponent,
                    E5coreUiSelectFromListComponent,
                    E5coreUiWorkRelatedItemsComponent,
                    E5coreUiCategorizationComponent,
                    E5coreUiMonitorSlaComponent,
                    E5coreUiDatepickerComponent,
                    E5coreUiMonitorSlaCompletionComponent,
                    E5coreUiMonitorSlaCompletionHighchartsComponent,
                    E5coreUiMonitorSlaInflowsComponent,
                    E5coreUiMonitorSlaInflowsHighchartsComponent,
                    E5coreUiMonitorSlaInventoryComponent,
                    E5coreUiMonitorSlaInventoryHighchartsComponent,
                    E5coreUiMonitorSlaTeamProductivityComponent,
                    E5coreUiMonitorSlaTeamProductivityHighchartsComponent
                ],
                providers: [
                    CurrencyPipe,
                    DatePipe
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchFormModel {
}
/**
 * @return {?}
 */
function CreateBlankSearchForm() {
    /** @type {?} */
    let model = new SearchFormModel();
    model.ui = UiStyle.Material;
    return (model);
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SearchResultsModel {
}
/**
 * @return {?}
 */
function CreateBlankSearchResult() {
    /** @type {?} */
    let model = new SearchResultsModel();
    model.ui = UiStyle.Material;
    return (model);
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkAttachmentModel {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkCaseNoteModel {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This class is used to map an event comming out of the SLA monitor into a Query
 * that can be passed into e5core-search-results component.
 */
class CreateSlaQuery {
    /**
     * @param {?} event
     * @return {?}
     */
    static fromMonitorSlaChangeEvent(event) {
        /** @type {?} */
        let query = new DataSourceQuery();
        query.Expressions = [
            { Field: "Category1_Id", Value: event.category1Id.toString() },
            { Field: "Category2_Id", Value: event.category2Id.toString() },
            { Field: "Category3_Id", Value: event.category3Id.toString() },
            { Field: "CategoryActivity_Id", Value: "0" },
            { Field: "Statuses", Value: "1,2,3" },
            { Field: "SLAType", Value: "0" },
            { Field: "IsHours", Value: "true" },
            { Field: "ApproachingIncrement", Value: "24" }
        ];
        return (query);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    static fromMonitorSlaSelectEvent(event) {
        /** @type {?} */
        let query = new DataSourceQuery();
        /** @type {?} */
        let slaType = "0";
        if (event.slaGroup) {
            /** @type {?} */
            let group = event.slaGroup.toLocaleLowerCase();
            /** @type {?} */
            let map$$1 = { insla: "1", approaching: "2", expired: "3" };
            slaType = map$$1[group] || "0";
        }
        query.Expressions = [
            { Field: "Category1_Id", Value: event.category1Id.toString() },
            { Field: "Category2_Id", Value: event.category2Id.toString() },
            { Field: "Category3_Id", Value: event.category3Id.toString() },
            { Field: "CategoryActivity_Id", Value: event.activityId.toString() },
            { Field: "Statuses", Value: "1,2,3" },
            { Field: "SLAType", Value: slaType },
            { Field: "IsHours", Value: "true" },
            { Field: "ApproachingIncrement", Value: "24" }
        ];
        return (query);
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DataSourceResults {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CategorizationChangeEvent {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class OpenWorkEvent {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ViewerDisplayEvent {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkAttachmentAddEvent {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WorkUserEvent {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MonitorSlaChangeEvent {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MonitorSlaSelectEvent {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DiariseWorkEvent {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { E5coreAngularUiModule, CreateBlankFileUpload, FileUploadModel, CreateBlankSearchForm, SearchFormModel, CreateBlankSearchResult, SearchResultsModel, PrimeTreeTableModel, TreeTableDataModel, CreateBlankViewer, ViewerModel, WorkAttachmentModel, WorkCaseNoteModel, WorkHistoryFrameModel, WorkHistoryDtoModel, PropertyValue, FieldValue, ResolvedPropertyValue, ResolvedFieldValue, CreateBlankWorkItem, WorkItemModel, FieldDataType, UiStyle, WorkDeliveryService, SearchDeliveryService, CreateSlaQuery, DiariseUnit, KeyValuePair, QueryOperation, QueryBooleanOperation, QueryExpression, DataSourceQuery, DataSourceColumnStatus, DataSourceColumn, DataSourceResults, E5coreUiSearchResultsComponent, E5coreUiSearchFormComponent, E5coreUiConversationViewerComponent, E5coreUiAssignUserComponent, E5coreUiWorkAttachmentViewerComponent, E5coreUiGenerateDocumentComponent, E5coreUiWorkAttachmentsComponent, E5coreUiWorkRelatedItemsComponent, E5coreUiWorkDiariseComponent, CategorizationChangeEvent, OpenWorkEvent, ViewerDisplayEvent, WorkAttachmentAddEvent, WorkUserEvent, MonitorSlaChangeEvent, MonitorSlaSelectEvent, DiariseOptionClickEvent, DiariseWorkEvent, E5coreUiCategorizationBase as ɵez, E5coreUiCategorizationBootstrapComponent as ɵew, E5coreUiCategorizationBoxComponent as ɵex, E5coreUiCategorizationMaterialComponent as ɵey, E5coreUiCategorizationComponent as ɵev, E5coreUiEmailConversationViewerComponent as ɵu, E5coreUiDatagridBase as ɵfe, E5coreUiDatagridBootstrapComponent as ɵfd, E5coreUiDatagridBoxComponent as ɵfg, E5coreUiDatagridMaterialComponent as ɵff, E5coreUiDatagridComponent as ɵfc, E5coreUiDatepickerComponent as ɵfh, E5coreUiFileUploadPrimeComponent as ɵec, E5coreUiFileUploadComponent as ɵeb, E5coreUiGenerateDocumentBaseComponent as ɵed, E5coreUiGenerateDocumentBootstrapComponent as ɵeg, E5coreUiGenerateDocumentBoxComponent as ɵef, E5coreUiGenerateDocumentMaterialComponent as ɵee, E5coreAngularUiGetNextComponent as ɵa, E5coreUiMonitorSlaCompletionHighchartsComponent as ɵfo, E5coreUiMonitorSlaCompletionComponent as ɵfn, E5coreUiMonitorSlaInflowsHighchartsComponent as ɵfq, E5coreUiMonitorSlaInflowsComponent as ɵfp, E5coreUiMonitorSlaInventoryHighchartsComponent as ɵfs, E5coreUiMonitorSlaInventoryComponent as ɵfr, E5coreUiMonitorSlaTeamProductivityHighchartsComponent as ɵfu, E5coreUiMonitorSlaTeamProductivityComponent as ɵft, E5coreUiMonitorSlaHighchartsComponent as ɵfa, E5coreUiMonitorSlaComponent as ɵfb, E5coreUiSearchFormBaseComponent as ɵdo, E5coreUiSearchFormBootstrapComponent as ɵdn, E5coreUiSearchFormBoxComponent as ɵdq, E5coreUiSearchFormMaterialComponent as ɵdp, E5coreUiSearchMenuBase as ɵdy, E5coreUiSearchMenuBootstrapComponent as ɵdx, E5coreUiSearchMenuBoxComponent as ɵea, E5coreUiSearchMenuMaterialComponent as ɵdz, E5coreUiSearchMenuComponent as ɵdw, E5coreUiSearchResultsBaseComponent as ɵdt, E5coreUiSearchResultsBootstrapComponent as ɵds, E5coreUiSearchResultsBoxComponent as ɵdv, E5coreUiSearchResultsMaterialComponent as ɵdu, E5coreUiSelectFromListBaseComponent as ɵer, E5coreUiSelectFromListMaterialComponent as ɵeq, E5coreUiSelectFromListComponent as ɵeo, E5coreUiTimePickerBaseComponent as ɵfm, E5coreUiTimepickerMaterialComponent as ɵfl, E5coreUiTimepickerComponent as ɵfk, E5coreUiAssignUserBaseComponent as ɵek, E5coreUiAssignUserBootstrapComponent as ɵen, E5coreUiAssignUserBoxComponent as ɵem, E5coreUiAssignUserMaterialComponent as ɵel, E5coreUiAttachmentViewerBaseComponent as ɵt, E5coreUiE5AttachmentViewerComponent as ɵeh, E5coreUiWebdavWeburiAttachmentViewerComponent as ɵej, E5coreUiWeburiAttachmentViewerComponent as ɵei, E5coreUiWorkAttachmentsBaseComponent as ɵk, E5coreUiWorkAttachmentsMaterialComponent as ɵj, E5coreUiWorkCasenotesBaseComponent as ɵdj, E5coreUiWorkCasenotesBootstrapComponent as ɵdi, E5coreUiWorkCasenotesBoxComponent as ɵdm, E5coreUiWorkCasenotesMaterialComponent as ɵdk, E5coreUiWorkCasenotesComponent as ɵdh, E5coreUiWorkDiariseBaseComponent as ɵfj, E5coreUiWorkDiariseMaterialComponent as ɵfi, E5coreUiWorkFieldSetBootstrapComponent as ɵbk, E5coreUiWorkFieldSetBoxComponent as ɵbi, E5coreUiWorkFieldSetMaterialComponent as ɵbj, E5coreUiWorkFieldSetComponent as ɵf, E5coreUiWorkFieldTypeCheckboxBaseComponent as ɵco, E5coreUiWorkFieldTypeCheckboxBootstrapComponent as ɵcp, E5coreUiWorkFieldTypeCheckboxBoxComponent as ɵcn, E5coreUiWorkFieldTypeCheckboxMaterialComponent as ɵcq, E5coreUiWorkFieldTypeCheckboxComponent as ɵcm, E5coreUiWorkFieldTypeCurrencyBaseComponent as ɵcz, E5coreUiWorkFieldTypeCurrencyBootstrapComponent as ɵcy, E5coreUiWorkFieldTypeCurrencyBoxComponent as ɵda, E5coreUiWorkFieldTypeCurrencyMaterialComponent as ɵdb, E5coreUiWorkFieldTypeCurrencyComponent as ɵcx, E5coreUiWorkFieldTypeDateBaseComponent as ɵbz, E5coreUiWorkFieldTypeDateBootstrapComponent as ɵcb, E5coreUiWorkFieldTypeDateBoxComponent as ɵby, E5coreUiWorkFieldTypeDateMaterialComponent as ɵca, E5coreUiWorkFieldTypeDateComponent as ɵbx, E5coreUiWorkFieldTypeInputBaseComponent as ɵbp, E5coreUiWorkFieldTypeInputBootstrapComponent as ɵbs, E5coreUiWorkFieldTypeInputBoxComponent as ɵbo, E5coreUiWorkFieldTypeInputMaterialComponent as ɵbr, E5coreUiWorkFieldTypeInputComponent as ɵn, E5coreUiWorkFieldTypeIntegerBaseComponent as ɵbu, E5coreUiWorkFieldTypeIntegerBootstrapComponent as ɵbt, E5coreUiWorkFieldTypeIntegerBoxComponent as ɵbw, E5coreUiWorkFieldTypeIntegerMaterialComponent as ɵbv, E5coreUiWorkFieldTypeIntegerComponent as ɵp, E5coreUiWorkFieldTypeListBaseComponent as ɵcu, E5coreUiWorkFieldTypeListBootstrapComponent as ɵcw, E5coreUiWorkFieldTypeListBoxComponent as ɵcv, E5coreUiWorkFieldTypeListMaterialComponent as ɵct, E5coreUiWorkFieldTypeListComponent as ɵcr, E5coreUiWorkFieldTypeTextBaseComponent as ɵce, E5coreUiWorkFieldTypeTextBootstrapComponent as ɵcg, E5coreUiWorkFieldTypeTextBoxComponent as ɵcd, E5coreUiWorkFieldTypeTextMaterialComponent as ɵcf, E5coreUiWorkFieldTypeTextComponent as ɵcc, E5coreUiWorkFieldTypeUserBootstrapComponent as ɵck, E5coreUiWorkFieldTypeUserBoxComponent as ɵci, E5coreUiWorkFieldTypeUserMaterialComponent as ɵcj, E5coreUiWorkFieldTypeUserComponent as ɵch, E5coreUiWorkFieldBootstrapComponent as ɵbl, E5coreUiWorkFieldBoxComponent as ɵbn, E5coreUiWorkFieldMaterialComponent as ɵbm, E5coreUiWorkFieldSwitchComponent as ɵcl, E5coreUiWorkFieldTypeBase as ɵo, E5coreUiWorkFieldTypeComponentBase as ɵbq, E5coreUiWorkFieldComponent as ɵg, E5coreUiWorkHistoryBaseComponent as ɵdd, E5coreUiWorkHistoryBootstrapComponent as ɵdg, E5coreUiWorkHistoryBoxComponent as ɵdf, E5coreUiWorkHistoryMaterialComponent as ɵdc, E5coreUiWorkHistoryComponent as ɵh, E5CoreUiWorkItemBootstrapComponent as ɵr, E5CoreUiWorkItemBoxComponent as ɵq, E5CoreUiWorkItemMaterialComponent as ɵs, E5coreUiWorkItemComponent as ɵb, E5coreUiWorkMenuItemBootstrapComponent as ɵba, E5coreUiWorkMenuItemBoxComponent as ɵy, E5coreUiWorkMenuItemMaterialComponent as ɵz, E5coreUiWorkMenuItemComponent as ɵm, E5CoreUiWorkMenuBootstrapComponent as ɵw, E5CoreUiWorkMenuBoxComponent as ɵx, E5CoreUiWorkMenuMaterialComponent as ɵv, E5coreUiWorkMenuComponent as ɵd, E5coreUiWorkRelatedItemsBaseComponent as ɵes, E5coreUiWorkRelatedItemsPrimeComponent as ɵet, E5coreUiWorkTabSetBootstrapComponent as ɵbd, E5coreUiWorkTabSetBoxComponent as ɵbc, E5coreUiWorkTabSetMaterialComponent as ɵbb, E5coreUiWorkTabSetComponent as ɵi, E5coreUiWorkTabBaseComponent as ɵbf, E5coreUiWorkTabBootstrapComponent as ɵbe, E5coreUiWorkTabBoxComponent as ɵbg, E5coreUiWorkTabMaterialComponent as ɵbh, E5coreUiWorkTabComponent as ɵe, DocumentDataSourceService as ɵep, SearchDataSourceService as ɵdr, AttachmentsOdataService as ɵl, CachedListSearchService as ɵcs, CasenotesOdataService as ɵdl, HistoryOdataService as ɵde, UiStyleService as ɵc, E5coreUiSafePipe as ɵeu };

//# sourceMappingURL=e5core-angular-ui.js.map